"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const credential_providers_1 = require("@aws-sdk/credential-providers");
const constants_1 = __importDefault(require("../../utils/constants"));
const string_utils_1 = __importDefault(require("../../utils/string-utils"));
/**
 * Abstract Class for AWS Client
 */
class AbstractAwsClient {
    /**
     * Constructor
     * @param configuration aws client config
     */
    constructor(configuration) {
        const { awsProfile, awsRegion } = configuration;
        if (!string_utils_1.default.isNonBlankString(awsProfile) || !string_utils_1.default.isNonBlankString(awsRegion)) {
            throw new Error("Invalid awsProfile or Invalid awsRegion");
        }
        this.credentials =
            awsProfile === constants_1.default.PLACEHOLDER.ENVIRONMENT_VAR.AWS_CREDENTIALS
                ? (0, credential_providers_1.fromEnv)()
                : (0, credential_providers_1.fromIni)({
                    profile: awsProfile,
                });
        this.profile = awsProfile;
        this.region = awsRegion;
    }
}
exports.default = AbstractAwsClient;
