/**
 * Checks the version of acc against the latest npm version producing a warning if there is
 * a new patch/minor version or an error following by termination if there is a new major version
 * to prevent backend backwards imcompatible changes that might happen for major versions and inform
 * of improvemnts in minor/patch versions
 */
export declare class NPMPackageVersionCheck {
    /**
     * Performs the minor/patch and major patch checks mentioned in the class description
     * @param localAccVersion local @alexa/acdl version returned when we do acc --version
     */
    static Check(localAccVersion: string): Promise<void>;
    /**
     * Produces an error followed by termination if there is a newer major version
     * @param latestNpmVersion latest npm registry version of @alexa/acdl
     * @param localAccVersion local @alexa/acdl version returned when we do acc --version
     */
    private static checkMajorVersion;
    /**
     * Produces a warning if there is a newer minor/patch version
     * @param latestNpmVersion latest npm registry version of @alexa/acdl
     * @param localAccVersion local @alexa/acdl version returned when we do acc --version
     */
    private static checkMinorAndPatchVersion;
}
//# sourceMappingURL=NPMPackageVersionCheck.d.ts.map