/**
 * A Login With Amazon (LWA) profile.
 *
 * @see https://developer.amazon.com/en-US/docs/alexa/smapi/manage-credentials-with-ask-cli.html
 * @see https://developer.amazon.com/en-US/docs/alexa/smapi/get-access-token-smapi.html#get-lwa-credentials
 * @see https://developer.amazon.com/en-US/docs/alexa/smapi/get-access-token-smapi.html#configure-lwa-security-profile
 */
export interface LwaProfile {
    /**
     * LWA Token.
     */
    token: LwaToken;
    /**
     * Skill Vendor ID.
     */
    vendor_id: string;
    /**
     * Client ID of the Login With Amazon (LWA) Client.
     */
    client_id?: string;
    /**
     * Client Secret of the Login With Amazon (LWA) Client.
     */
    client_secret?: string;
}
/**
 * An access and refresh tolen for Login With Amazon (LWA).
 *
 * @see https://developer.amazon.com/en-US/docs/alexa/smapi/get-access-token-smapi.html
 */
export interface LwaToken {
    access_token: string;
    refresh_token: string;
    token_type: string;
    expires_in: number;
    expires_at: string;
}
/**
 * Shape of JSON data stored within the `cli_config` written by the ASK CLI.
 *
 * @see https://developer.amazon.com/en-US/docs/alexa/smapi/manage-credentials-with-ask-cli.html
 */
export interface AskCliConfigJson {
    /**
     * LWA profiles configured on this machine.
     */
    profiles?: {
        /**
         * A named profile.
         */
        [profileName: string]: LwaProfile;
    };
    machine_id?: string;
    share_usage?: string;
}
export declare class AskCliConfig {
    private askCliConfig;
    private cliConfigPath;
    private errorLoadingAskCliConfig;
    /**
     * Load the user's ASK CLI Config.
     *
     * @param path path of the cli_config - defaults to `~/.ask/cli_config`
     */
    constructor();
    hasConfig(): boolean;
    createMachineId(): string;
    getLwaProfile(profileName: string): LwaProfile;
    getShareUsage(): boolean;
    getMachineId(): string | undefined;
}
//# sourceMappingURL=ask-cli-config.d.ts.map