export declare namespace Constants {
    const DEFAULT_CONFIG_FILE_NAME = "ask.json";
    const RESERVED_PREFIXES: string[];
    const BINARY_OPERATOR_ACTIONS_SET: Set<string>;
    const OPERATOR_ACTIONS_SET: Set<string>;
    const FILE_ACCESS_ACTIONS_SET: Set<string>;
    /**
     * Name of the Skill Manifest at the root of a Skill Package.
     */
    const SkillManifestFileName = "skill.json";
    /**
     * Name of the Skill Package Folder.
     */
    const SkillPackageFolderName = "skill-package";
    /**
     * Name of the folder at the root of a Skill Package containing the Interaction Models.
     */
    const InteractionsModelFolderName = "interactionModels";
    /**
     * Name of the folder under ${InteractionsModelFolderName} containing the custom Interaction Model JSON Files.
     */
    const CustomFolderName = "custom";
    /**
     * Name of the folder inside the ${InteractionModelFolderName} containing the Alexa Conversations ASKIR files.
     */
    const ConversationsFolderName = "conversations";
    /**
     * Name of the folder containing Responses.
     */
    const ResponseFolderName = "response";
    /**
     * Name of the folder containing APL display responses.
     */
    const DisplayFolderName = "display";
    /**
     * Name of the folder containing APLA prompt responses.
     */
    const PromptsFolderName = "prompts";
    /**
     * Name of the folder containing Prompts.
     */
    const AssetsFolderName = "assets";
    /**
     * Name of the folder containing Data Store Packages.
     */
    const DataStorePackagesFolderName = "_dataStorePackages";
    /**
     * Name of the folder containing Prompts.
     */
    const TasksFolderName = "tasks";
    /**
     * Name of the folder containing the In Skill Product files.
     */
    const InSkillPurchaseFolderName = "isps";
    /**
     * File Extension for ACDL Files.
     */
    const ACDLExtension = "acdl";
    /**
     * File Extension for ASKIR JSON Files.
     */
    const ASKIRJsonExtension = "json";
    /**
     * Name of the NPM Package containing Alexa Schema.
     */
    const AlexaSchemaPackageName = "@alexa/schema";
    /**
     * Name of the NPM Package containing Alexa Conversations Core Library.
     */
    const ACCorePackageName = "@alexa/ac-core";
    /**
     * Name of the folder containing ASKIR Dependencies.
     */
    const DependenciesFolderName = "_dependencies";
    /**
     * Name of the folder containing Compiled ASKIR Files in a `_dependencies` folder.
     */
    const CompiledOutputFoldername = "compiled-output";
    /**
     * Name of the file for APLA and APL
     */
    const APLADocumentFileName = "document.json";
    /**
     * The maximum size of IR is 4mb
     */
    const MaximumFileSize: number;
    const BuiltinIntentPrefix = "AMAZON.";
}
/**
 * Enum of the allowed `type` field in an APL/A file.
 *
 * Both `APL-A` and `APLA` are allowed for APL-A files.
 *
 * Only `APL` is allowed for APL files.
 */
export declare enum APLFileType {
    APLA = "APLA",
    APL_A = "APL-A",
    APL = "APL"
}
export declare const APLAFileTypes: readonly [APLFileType.APLA, APLFileType.APL_A];
export declare const APLFileTypes: readonly [APLFileType.APL];
/**
 * Contains reusable error messages used for validations.
 */
export declare enum ValidationErrorMessages {
    MustBeBackedByCatalog = "must be backed by a catalog - choose a type from ask.interactionModel.slotTypes.*, com.amazon.ask.types.builtins.AMAZON.*, or annotate your type with the @catalog annotation."
}
export declare namespace GeneratedInteractionModelModule {
    /**
     * The root acdl namespace for each each generated interaction module.
     */
    const namespacePrefix = "ask.interactionModel";
    /**
     * The uri prefix that each generated module URI will start with.
     */
    const uriPrefix = "generated-im";
}
export declare namespace Namespaces {
    /**
     * Namespace for generated slotTypes
     */
    const slotTypes = "ask.interactionModel.slotTypes";
    /**
     * Namespace for generated catalogs
     */
    const catalogs = "ask.interactionModel.catalogs";
    /**
     * Namespace for generated intents
     */
    const intents = "ask.interactionModel.intents";
    /**
     * Namespace for generated intent types
     */
    const intentTypes = "ask.interactionModel.intentTypes";
    /**
     * Namespace given to APL/A prompts loaded from `response/prompts`.
     */
    const prompts = "prompts";
    /**
     * Namespace given to APL display templates loaded from `response/display`.
     */
    const display = "displays";
    /**
     * Namespace given to builtin types
     */
    const builtinTypes = "com.amazon.ask.types.builtins.AMAZON";
    /**
     * Namespace given to builtin catalogs
     */
    const builtinCatalogs = "com.amazon.ask.catalogs.builtins.AMAZON";
}
//# sourceMappingURL=constants.d.ts.map