# Call Schema

```txt
https://amazonalexa.com/ask/2020/12/Call
```

Represents a call to an action or a dialog.

| Abstract            | Extensible | Status         | Identifiable | Custom Properties | Additional Properties | Access Restrictions | Defined In                                                  |
| :------------------ | :--------- | :------------- | :----------- | :---------------- | :-------------------- | :------------------ | :---------------------------------------------------------- |
| Can be instantiated | No         | Unknown status | No           | Forbidden         | Forbidden             | none                | [Call.json](../../schemas/Call.json "open original schema") |

## Call Type

`object` ([Call](call.md))

# Call Properties

| Property                              | Type          | Required | Nullable       | Defined by                                                                                                                      |
| :------------------------------------ | :------------ | :------- | :------------- | :------------------------------------------------------------------------------------------------------------------------------ |
| [kind](#kind)                         | Not specified | Required | cannot be null | [Call](call-properties-kind.md "https://amazonalexa.com/ask/2020/12/Call#/properties/kind")                                     |
| [name](#name)                         | `string`      | Required | cannot be null | [Call](actiondeclaration-properties-qualifiedname.md "https://amazonalexa.com/ask/2020/12/QualifiedName#/properties/name")      |
| [genericArguments](#genericarguments) | `array`       | Optional | cannot be null | [Call](call-properties-genericarguments.md "https://amazonalexa.com/ask/2020/12/GenericArguments#/properties/genericArguments") |
| [arguments](#arguments)               | Merged        | Optional | cannot be null | [Call](call-properties-arguments.md "https://amazonalexa.com/ask/2020/12/Arguments#/properties/arguments")                      |
| [type](#type)                         | `object`      | Optional | cannot be null | [Call](actiondeclaration-properties-typereference.md "https://amazonalexa.com/ask/2020/12/TypeReference#/properties/type")      |
| [annotations](#annotations)           | `array`       | Optional | cannot be null | [Call](call-properties-annotations.md "https://amazonalexa.com/ask/2020/12/Call#/properties/annotations")                       |

## kind

The expression's identifier.

`kind`

*   is required

*   Type: unknown ([kind](call-properties-kind.md))

*   cannot be null

*   defined in: [Call](call-properties-kind.md "https://amazonalexa.com/ask/2020/12/Call#/properties/kind")

### kind Type

unknown ([kind](call-properties-kind.md))

### kind Constraints

**constant**: the value of this property must be equal to:

```json
"Call"
```

## name

A qualified name

`name`

*   is required

*   Type: `string` ([QualifiedName](actiondeclaration-properties-qualifiedname.md))

*   cannot be null

*   defined in: [Call](actiondeclaration-properties-qualifiedname.md "https://amazonalexa.com/ask/2020/12/QualifiedName#/properties/name")

### name Type

`string` ([QualifiedName](actiondeclaration-properties-qualifiedname.md))

### name Constraints

**maximum length**: the maximum number of characters for this string is: `1024`

**pattern**: the string must match the following regular expression:&#x20;

```regexp
^[A-Za-z][A-Za-z0-9_]*(\.((_[A-Za-z0-9][A-Za-z0-9_]*)|([A-Za-z][A-Za-z0-9_]*)))*$
```

[try pattern](https://regexr.com/?expression=%5E%5BA-Za-z%5D%5BA-Za-z0-9_%5D*\(%5C.\(\(_%5BA-Za-z0-9%5D%5BA-Za-z0-9_%5D*\)%7C\(%5BA-Za-z%5D%5BA-Za-z0-9_%5D*\)\)\)*%24 "try regular expression with regexr.com")

### name Examples

```json
"com.amazon.alexa.schema.String"
```

```json
"foo"
```

## genericArguments

Represents a set of generic arguments (e.g. for an action).

`genericArguments`

*   is optional

*   Type: `object[]` ([TypeReference](actiondeclaration-properties-typereference.md))

*   cannot be null

*   defined in: [Call](call-properties-genericarguments.md "https://amazonalexa.com/ask/2020/12/GenericArguments#/properties/genericArguments")

### genericArguments Type

`object[]` ([TypeReference](actiondeclaration-properties-typereference.md))

## arguments

Arguments to a Call can be JSON primitives or an object/array of Calls, NameReferences or PropertyReferences

`arguments`

*   is optional

*   Type: merged type ([Arguments](call-properties-arguments.md))

*   cannot be null

*   defined in: [Call](call-properties-arguments.md "https://amazonalexa.com/ask/2020/12/Arguments#/properties/arguments")

### arguments Type

merged type ([Arguments](call-properties-arguments.md))

one (and only one) of

*   [Untitled null in Arguments](arguments-oneof-0.md "check type definition")

*   [Untitled number in Arguments](arguments-oneof-1.md "check type definition")

*   [Untitled string in Arguments](arguments-oneof-2.md "check type definition")

*   [Untitled boolean in Arguments](arguments-oneof-3.md "check type definition")

*   [Untitled array in Arguments](arguments-oneof-4.md "check type definition")

*   [Untitled object in Arguments](arguments-oneof-5.md "check type definition")

## type

The representation of a reference to a type declaration.

`type`

*   is optional

*   Type: `object` ([TypeReference](actiondeclaration-properties-typereference.md))

*   cannot be null

*   defined in: [Call](actiondeclaration-properties-typereference.md "https://amazonalexa.com/ask/2020/12/TypeReference#/properties/type")

### type Type

`object` ([TypeReference](actiondeclaration-properties-typereference.md))

## annotations



`annotations`

*   is optional

*   Type: `object[]` ([Call](actiondeclaration-properties-annotations-call.md))

*   cannot be null

*   defined in: [Call](call-properties-annotations.md "https://amazonalexa.com/ask/2020/12/Call#/properties/annotations")

### annotations Type

`object[]` ([Call](actiondeclaration-properties-annotations-call.md))
