import * as runtime from 'ask-sdk-model-runtime';
export { runtime };
import ApiConfiguration = runtime.ApiConfiguration;
import ApiResponse = runtime.ApiResponse;
import AuthenticationConfiguration = runtime.AuthenticationConfiguration;
import BaseServiceClient = runtime.BaseServiceClient;
export declare namespace v0 {
    /**
     *
     * @interface
     */
    interface BadRequestError {
        /**
         * Human readable description of error.
         */
        'message'?: string;
        /**
         * An array of violation messages.
         */
        'violations'?: Array<v0.Error>;
    }
}
export declare namespace v0 {
    /**
     *
     * @interface
     */
    interface Error {
        /**
         * Error code that maps to an error message. Developers with different locales should be able to lookup the error description based on this code.
         */
        'code'?: string;
        /**
         * Readable description of error.
         */
        'message': string;
    }
}
export declare namespace v0.catalog {
    /**
     *
     * @interface
     */
    interface CatalogDetails {
        /**
         * Unique identifier of the added catalog object.
         */
        'id'?: string;
        /**
         * Title of the catalog.
         */
        'title'?: string;
        'type'?: v0.catalog.CatalogType;
        'usage'?: v0.catalog.CatalogUsage;
        /**
         * The date time when the catalog was last updated.
         */
        'lastUpdatedDate'?: string;
        /**
         * The date time when the catalog was created.
         */
        'createdDate'?: string;
        /**
         * The list of skill Ids associated with the catalog.
         */
        'associatedSkillIds'?: Array<string>;
    }
}
export declare namespace v0.catalog {
    /**
     *
     * @interface
     */
    interface CatalogSummary {
        /**
         * Unique identifier of the added catalog object.
         */
        'id'?: string;
        /**
         * Title of the catalog.
         */
        'title'?: string;
        'type'?: v0.catalog.CatalogType;
        'usage'?: v0.catalog.CatalogUsage;
        /**
         * The date time when the catalog was last updated.
         */
        'lastUpdatedDate'?: string;
        /**
         * The date time when the catalog was created.
         */
        'createdDate'?: string;
        /**
         * The list of skill Ids associated with the catalog.
         */
        'associatedSkillIds'?: Array<string>;
    }
}
export declare namespace v0.catalog {
    /**
     * Type of catalog.
     * @enum
     */
    type CatalogType = 'AMAZON.BroadcastChannel' | 'AMAZON.Genre' | 'AMAZON.MusicAlbum' | 'AMAZON.MusicGroup' | 'AMAZON.MusicPlaylist' | 'AMAZON.MusicRecording' | 'AMAZON.TerrestrialRadioChannel' | 'AMAZON.AudioRecording';
}
export declare namespace v0.catalog {
    /**
     * Usage of the catalog.
     * @enum
     */
    type CatalogUsage = 'AlexaMusic.Catalog.BroadcastChannel' | 'AlexaMusic.Catalog.Genre' | 'AlexaMusic.Catalog.MusicAlbum' | 'AlexaMusic.Catalog.MusicGroup' | 'AlexaMusic.Catalog.MusicPlaylist' | 'AlexaMusic.Catalog.MusicRecording' | 'AlexaMusic.Catalog.TerrestrialRadioChannel' | 'AlexaTest.Catalog.AudioRecording';
}
export declare namespace v0.catalog {
    /**
     *
     * @interface
     */
    interface CreateCatalogRequest {
        /**
         * Title of the catalog.
         */
        'title': string;
        'type': v0.catalog.CatalogType;
        'usage': v0.catalog.CatalogUsage;
        /**
         * ID of the vendor owning the catalog.
         */
        'vendorId': string;
    }
}
export declare namespace v0.catalog {
    /**
     * Information about catalogs.
     * @interface
     */
    interface ListCatalogsResponse {
        '_links'?: v1.Links;
        /**
         * List of catalog summaries.
         */
        'catalogs'?: Array<v0.catalog.CatalogSummary>;
        'isTruncated'?: boolean;
        'nextToken'?: string;
    }
}
export declare namespace v0.catalog.upload {
    /**
     *
     * @interface
     */
    interface CompleteUploadRequest {
        /**
         * List of (eTag, part number) pairs for each part of the file uploaded.
         */
        'partETags'?: Array<v0.catalog.upload.PreSignedUrlItem>;
    }
}
export declare namespace v0.catalog.upload {
    /**
     *
     * @interface
     */
    interface ContentUploadFileSummary {
        /**
         * If the file is available for download, presigned download URL can be used to download the file.
         */
        'presignedDownloadUrl'?: string;
        'status'?: v0.catalog.upload.FileUploadStatus;
    }
}
export declare namespace v0.catalog.upload {
    /**
     *
     * @interface
     */
    interface ContentUploadSummary {
        /**
         * Unique identifier of the upload.
         */
        'id'?: string;
        /**
         * Provides a unique identifier of the catalog.
         */
        'catalogId'?: string;
        'status'?: v0.catalog.upload.UploadStatus;
        'createdDate'?: string;
        'lastUpdatedDate'?: string;
    }
}
export declare namespace v0.catalog.upload {
    /**
     *
     * @interface
     */
    interface CreateContentUploadRequest {
        /**
         * Provides the number of parts the file will be split into. An equal number of presigned upload urls are generated in response to facilitate each part's upload.
         */
        'numberOfUploadParts'?: number;
    }
}
export declare namespace v0.catalog.upload {
    /**
     * Value of status depends on if file is available for download or not.
     * @enum
     */
    type FileUploadStatus = 'PENDING' | 'AVAILABLE' | 'PURGED' | 'UNAVAILABLE';
}
export declare namespace v0.catalog.upload {
    /**
     *
     * @enum
     */
    type IngestionStatus = 'PENDING' | 'IN_PROGRESS' | 'FAILED' | 'SUCCEEDED' | 'CANCELLED';
}
export declare namespace v0.catalog.upload {
    /**
     *
     * @enum
     */
    type IngestionStepName = 'UPLOAD' | 'SCHEMA_VALIDATION';
}
export declare namespace v0.catalog.upload {
    /**
     *
     * @interface
     */
    interface ListUploadsResponse {
        '_links'?: v1.Links;
        'isTruncated'?: boolean;
        'nextToken'?: string;
        /**
         * List of upload summaries.
         */
        'uploads'?: Array<v0.catalog.upload.ContentUploadSummary>;
    }
}
export declare namespace v0.catalog.upload {
    /**
     *
     * @interface
     */
    interface PreSignedUrlItem {
        'eTag': string;
        'partNumber': number;
    }
}
export declare namespace v0.catalog.upload {
    /**
     * Single upload part to perform a partitioned (multipart) file upload.
     * @interface
     */
    interface PresignedUploadPart {
        'url'?: string;
        'partNumber'?: number;
    }
}
export declare namespace v0.catalog.upload {
    /**
     * Represents a single step in the ingestion process of a new upload.
     * @interface
     */
    interface UploadIngestionStep {
        'name': v0.catalog.upload.IngestionStepName;
        'status': v0.catalog.upload.IngestionStatus;
        /**
         * Represents the url for the file containing logs of ingestion step.
         */
        'logUrl'?: string;
        /**
         * This array will contain the errors occurred during the execution of step. Will be empty, if execution succeeded.
         */
        'errors': Array<v0.Error>;
    }
}
export declare namespace v0.catalog.upload {
    /**
     * Status of the entire upload.
     * @enum
     */
    type UploadStatus = 'PENDING' | 'PROCESSING' | 'FAILED' | 'SUCCEEDED';
}
export declare namespace v0.developmentEvents.subscriber {
    /**
     *
     * @interface
     */
    interface CreateSubscriberRequest {
        /**
         * Name of the subscriber.
         */
        'name'?: string;
        /**
         * The Vendor ID.
         */
        'vendorId'?: string;
        'endpoint'?: v0.developmentEvents.subscriber.Endpoint;
    }
}
export declare namespace v0.developmentEvents.subscriber {
    /**
     *
     * @interface
     */
    interface Endpoint {
        /**
         * Uri of the endpoint that receives the notification.
         */
        'uri'?: string;
        'authorization'?: v0.developmentEvents.subscriber.EndpointAuthorization;
    }
}
export declare namespace v0.developmentEvents.subscriber {
    /**
     * Authorization information to be able to publish notification to specified endpoint.
     * @interface
     */
    type EndpointAuthorization = v0.developmentEvents.subscriber.EndpointAwsAuthorization;
}
export declare namespace v0.developmentEvents.subscriber {
    /**
     * Type of authorization (e.g. AWS IAM, OAuth).
     * @enum
     */
    type EndpointAuthorizationType = 'AWS_IAM';
}
export declare namespace v0.developmentEvents.subscriber {
    /**
     *
     * @interface
     */
    interface ListSubscribersResponse {
        '_links'?: v1.Links;
        'nextToken'?: string;
        /**
         * List containing subscriber summary.
         */
        'subscribers'?: Array<v0.developmentEvents.subscriber.SubscriberSummary>;
    }
}
export declare namespace v0.developmentEvents.subscriber {
    /**
     * Information about the subscriber.
     * @interface
     */
    interface SubscriberInfo {
        /**
         * Unique identifier of the subscriber resource.
         */
        'subscriberId'?: string;
        /**
         * Name of the subscriber.
         */
        'name'?: string;
        'endpoint'?: v0.developmentEvents.subscriber.Endpoint;
    }
}
export declare namespace v0.developmentEvents.subscriber {
    /**
     * Status of the subscriber. This enum may get extended with new values in future. Clients are expected to gracefully handle any unknown values.
     * @enum
     */
    type SubscriberStatus = 'ACTIVE' | 'INACTIVE';
}
export declare namespace v0.developmentEvents.subscriber {
    /**
     *
     * @interface
     */
    interface SubscriberSummary {
        /**
         * Unique identifier of the subscriber resource.
         */
        'subscriberId'?: string;
        /**
         * Name of the subscriber.
         */
        'name'?: string;
        'status'?: v0.developmentEvents.subscriber.SubscriberStatus;
        /**
         * Client Id of the subscriber resource.
         */
        'clientId'?: string;
        'endpoint'?: v0.developmentEvents.subscriber.Endpoint;
    }
}
export declare namespace v0.developmentEvents.subscriber {
    /**
     *
     * @interface
     */
    interface UpdateSubscriberRequest {
        /**
         * Name of the subscriber.
         */
        'name'?: string;
        'endpoint'?: v0.developmentEvents.subscriber.Endpoint;
    }
}
export declare namespace v0.developmentEvents.subscription {
    /**
     *
     * @interface
     */
    interface CreateSubscriptionRequest {
        /**
         * Name of the subscription.
         */
        'name': string;
        /**
         * The list of events that the subscriber should be notified for.
         */
        'events': Array<v0.developmentEvents.subscription.Event>;
        /**
         * The vendorId of the event publisher.
         */
        'vendorId': string;
        /**
         * The id of the subscriber that would receive the events.
         */
        'subscriberId': string;
    }
}
export declare namespace v0.developmentEvents.subscription {
    /**
     * Represents an event that the subscriber is interested in. The event is of the format EventCategory.OPERATION. You can use wildcard event 'AlexaDevelopmentEvent.All' for recieving all AlexaDevelopmentEvent notifications listed below. We do not support 'AlexaCustomerFeedbackEvent.All' at this point as we only have one event in this category.   * 'AlexaDevelopmentEvent.ManifestUpdate' - The event representing the status of the update request on the Manifest.   * 'AlexaDevelopmentEvent.SkillPublish' -   The event representing the status of the skill publish process.   * 'AlexaDevelopmentEvent.SkillCertification' -   The event represents if a skill has been certified or not.   * 'AlexaDevelopmentEvent.InteractionModelUpdate' -   The event represents the status of an Interaction Model build for a particular locale.   * 'AlexaDevelopmentEvent.All' - A wildcard event name that allows subscription to all the existing events. While using this, you must not specify any other event name. AlexaDevelopmentEvent.All avoids the need of specifying every development event name in order to receive all events pertaining to a vendor account. Similarly, it avoids the need of updating an existing subscription to be able to receive new events, whenever supproted by notification service. Test Subscriber API cannot use this wildcard. Please make sure that your code can gracefully handle new/previously unknown events, if you are using this wildcard.   * 'AlexaCustomerFeedbackEvent.SkillReviewPublish' - The event represents the publishing of a new/updated customer review for a skill on the skill store.
     * @enum
     */
    type Event = 'AlexaDevelopmentEvent.ManifestUpdate' | 'AlexaDevelopmentEvent.SkillPublish' | 'AlexaDevelopmentEvent.SkillCertification' | 'AlexaDevelopmentEvent.InteractionModelUpdate' | 'AlexaDevelopmentEvent.All' | 'AlexaCustomerFeedbackEvent.SkillReviewPublish';
}
export declare namespace v0.developmentEvents.subscription {
    /**
     *
     * @interface
     */
    interface ListSubscriptionsResponse {
        '_links'?: v1.Links;
        'nextToken'?: string;
        /**
         * List of subscription summaries.
         */
        'subscriptions'?: Array<v0.developmentEvents.subscription.SubscriptionSummary>;
    }
}
export declare namespace v0.developmentEvents.subscription {
    /**
     *
     * @interface
     */
    interface SubscriptionInfo {
        /**
         * Name of the subscription.
         */
        'name'?: string;
        /**
         * Unique identifier of the subscription resource.
         */
        'subscriptionId'?: string;
        /**
         * Subscriber Id of the event-receiver.
         */
        'subscriberId'?: string;
        /**
         * Vendor Id of the event-publisher.
         */
        'vendorId'?: string;
        /**
         * The list of events that the subscriber should be notified for.
         */
        'events'?: Array<v0.developmentEvents.subscription.Event>;
    }
}
export declare namespace v0.developmentEvents.subscription {
    /**
     *
     * @interface
     */
    interface SubscriptionSummary {
        /**
         * Name of the subscription.
         */
        'name'?: string;
        /**
         * Unique identifier of the subscription resource.
         */
        'subscriptionId'?: string;
        /**
         * Subscriber Id of the event-reciever.
         */
        'subscriberId'?: string;
        /**
         * VendorId of the event-publisher.
         */
        'vendorId'?: string;
        /**
         * The list of events that the subscriber should be notified for.
         */
        'events'?: Array<v0.developmentEvents.subscription.Event>;
    }
}
export declare namespace v0.developmentEvents.subscription {
    /**
     *
     * @interface
     */
    interface UpdateSubscriptionRequest {
        /**
         * Name of the subscription.
         */
        'name': string;
        /**
         * The list of events that the subscriber should be notified for.
         */
        'events': Array<v0.developmentEvents.subscription.Event>;
    }
}
export declare namespace v0.eventSchema {
    /**
     * Represents an actor that submitted a request causing development notification event.
     * @interface
     */
    interface ActorAttributes {
        /**
         * Identifies an Amazon Customer who submitted a request corresponding to the generated event.
         */
        'customerId'?: string;
    }
}
export declare namespace v0.eventSchema {
    /**
     * Represents attributes common to all development notifications.
     * @interface
     */
    type BaseSchema = v0.eventSchema.AlexaDevelopmentEvent.InteractionModelUpdate | v0.eventSchema.AlexaCustomerFeedbackEvent.SkillReviewPublish | v0.eventSchema.AlexaDevelopmentEvent.SkillPublish | v0.eventSchema.AlexaDevelopmentEvent.ManifestUpdate | v0.eventSchema.AlexaDevelopmentEvent.SkillCertification;
}
export declare namespace v0.eventSchema {
    /**
     * Interaction model event specific attributes.
     * @interface
     */
    interface InteractionModelEventAttributes {
        'status'?: v0.eventSchema.RequestStatus;
        'actor'?: v0.eventSchema.ActorAttributes;
        'interactionModel'?: v0.eventSchema.InteractionModelAttributes;
        'subscription'?: v0.eventSchema.SubscriptionAttributes;
    }
}
export declare namespace v0.eventSchema {
    /**
     * Represents the completion status of the request.
     * @enum
     */
    type RequestStatus = 'SUCCEEDED' | 'FAILED';
}
export declare namespace v0.eventSchema {
    /**
     * Represents a set of attributes specific to an Alexa Skill.
     * @interface
     */
    interface SkillAttributes {
        /**
         * Unique identifier of an Alexa skill.
         */
        'skillId'?: string;
        /**
         * Unique identifier of vendor account to which this skill belongs.
         */
        'vendorId'?: string;
    }
}
export declare namespace v0.eventSchema {
    /**
     * Skill event specific attributes.
     * @interface
     */
    interface SkillEventAttributes {
        'status'?: v0.eventSchema.RequestStatus;
        'actor'?: v0.eventSchema.ActorAttributes;
        'skill'?: v0.eventSchema.SkillAttributes;
        'subscription'?: v0.eventSchema.SubscriptionAttributes;
    }
}
export declare namespace v0.eventSchema {
    /**
     * Represents attributes of a customer review for a skill.
     * @interface
     */
    interface SkillReviewAttributes {
        /**
         * Unique review id associated with a customer review for a skill.
         */
        'reviewId'?: string;
        /**
         * Link to the customer review on Amazon retail website.
         */
        'url'?: string;
        /**
         * StarRating provided by the customer in the review. It is always a natural number from 1 to 5 (inclusive of 1 and 5).
         */
        'starRating'?: string;
    }
}
export declare namespace v0.eventSchema {
    /**
     * Skill Review by customer event specific attributes.
     * @interface
     */
    interface SkillReviewEventAttributes {
        'skill'?: v0.eventSchema.SkillAttributes;
        'subscription'?: v0.eventSchema.SubscriptionAttributes;
        'review'?: v0.eventSchema.SkillReviewAttributes;
    }
}
export declare namespace v0.eventSchema {
    /**
     * Represents attributes of a subscription for development notification.
     * @interface
     */
    interface SubscriptionAttributes {
        /**
         * Unique subscription id that triggered the development notification event.
         */
        'subscriptionId'?: string;
    }
}
export declare namespace v1 {
    /**
     *
     * @interface
     */
    interface BadRequestError {
        /**
         * Human readable description of error.
         */
        'message'?: string;
        /**
         * An array of violation messages.
         */
        'violations'?: Array<v1.Error>;
    }
}
export declare namespace v1 {
    /**
     *
     * @interface
     */
    type Error = v1.skill.StandardizedError;
}
export declare namespace v1 {
    /**
     *
     * @interface
     */
    interface Link {
        'href'?: string;
    }
}
export declare namespace v1 {
    /**
     * Links for the API navigation.
     * @interface
     */
    interface Links {
        'self'?: v1.Link;
        'next'?: v1.Link;
    }
}
export declare namespace v1 {
    /**
     *
     * @enum
     */
    type StageType = 'development' | 'live';
}
export declare namespace v1 {
    /**
     *
     * @enum
     */
    type StageV2Type = 'live' | 'certified' | 'development';
}
export declare namespace v1.auditLogs {
    /**
     *
     * @interface
     */
    interface AuditLog {
        /**
         * UUID that identifies a specific request.
         */
        'xAmznRequestId'?: string;
        /**
         * Date-Time when the request was made.
         */
        'timestamp'?: string;
        'client'?: v1.auditLogs.Client;
        'operation'?: v1.auditLogs.Operation;
        /**
         * Contains information about the resources affected in this request.
         */
        'resources'?: Array<v1.auditLogs.Resource>;
        'requester'?: v1.auditLogs.Requester;
        /**
         * HTTP Status Code returned by this request.
         */
        'httpResponseCode'?: number;
    }
}
export declare namespace v1.auditLogs {
    /**
     *
     * @interface
     */
    interface AuditLogsRequest {
        /**
         * Vendor Id. See developer.amazon.com/mycid.html.
         */
        'vendorId': string;
        'requestFilters'?: v1.auditLogs.RequestFilters;
        'sortDirection'?: v1.auditLogs.SortDirection;
        'sortField'?: v1.auditLogs.SortField;
        'paginationContext'?: v1.auditLogs.RequestPaginationContext;
    }
}
export declare namespace v1.auditLogs {
    /**
     * Response to the Query Audit Logs API. It contains the collection of audit logs for the vendor, nextToken and other metadata related to the search query.
     * @interface
     */
    interface AuditLogsResponse {
        'paginationContext'?: v1.auditLogs.ResponsePaginationContext;
        '_links'?: v1.Links;
        /**
         * List of audit logs for the vendor.
         */
        'auditLogs'?: Array<v1.auditLogs.AuditLog>;
    }
}
export declare namespace v1.auditLogs {
    /**
     * Contains information about the Client that this request was performed by.
     * @interface
     */
    interface Client {
        'id'?: string;
        'name'?: string;
    }
}
export declare namespace v1.auditLogs {
    /**
     * Identifier for the application the developer used to manage their skills and skill-related resources. For OAuth applications, this is the OAuth Client Id.
     * @interface
     */
    interface ClientFilter {
        'id'?: string;
    }
}
export declare namespace v1.auditLogs {
    /**
     * Object containing name and version.
     * @interface
     */
    interface Operation {
        'name'?: string;
        'version'?: string;
    }
}
export declare namespace v1.auditLogs {
    /**
     * Name and version of the operation that the developer performed. For example, 'deleteSkill' and 'v1'. This is the same name used in the SMAPI SDK.
     * @interface
     */
    interface OperationFilter {
        'name'?: string;
        'version'?: string;
    }
}
export declare namespace v1.auditLogs {
    /**
     * Request Filters for filtering audit logs.
     * @interface
     */
    interface RequestFilters {
        /**
         * List of Client IDs for filtering.
         */
        'clients'?: Array<v1.auditLogs.ClientFilter>;
        /**
         * Filters for a list of operation names and versions.
         */
        'operations'?: Array<v1.auditLogs.OperationFilter>;
        /**
         * Filters for a list of resources and/or their types. See documentation for allowed types.
         */
        'resources'?: Array<v1.auditLogs.ResourceFilter>;
        'requesters'?: Array<v1.auditLogs.RequesterFilter>;
        /**
         * Sets the start time for this search. Any audit logs with timestamps after this time (inclusive) will be included in the response.
         */
        'startTime'?: string;
        /**
         * Sets the end time for this search. Any audit logs with timestamps before this time (exclusive) will be included in the result.
         */
        'endTime'?: string;
        /**
         * Filters for HTTP response codes. For example, '200' or '503'
         */
        'httpResponseCodes'?: Array<string>;
    }
}
export declare namespace v1.auditLogs {
    /**
     * This object includes nextToken and maxResults.
     * @interface
     */
    interface RequestPaginationContext {
        /**
         * When the response to this API call is truncated, the response includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that this API understands. Token has expiry of 1 hour.
         */
        'nextToken'?: string;
        /**
         * Sets the maximum number of results returned in the response body. If you want to retrieve more or less than the default of 50 results, you can add this parameter to your request. maxResults can exceed the upper limit of 250 but we will not return more items than that. The response might contain fewer results than maxResults for purpose of keeping SLA or because there are not enough items, but it will never contain more.
         */
        'maxResults'?: number;
    }
}
export declare namespace v1.auditLogs {
    /**
     * The user that performed the operation.
     * @interface
     */
    interface Requester {
        /**
         * LWA User ID. https://developer.amazon.com/docs/login-with-amazon/obtain-customer-profile.html
         */
        'userId'?: string;
    }
}
export declare namespace v1.auditLogs {
    /**
     * Filter for the requester of the operation.
     * @interface
     */
    interface RequesterFilter {
        /**
         * LoginWithAmazon User ID.
         */
        'userId'?: string;
    }
}
export declare namespace v1.auditLogs {
    /**
     * Resource that the developer operated on. This includes both the type and ID of the resource.
     * @interface
     */
    interface Resource {
        'id'?: string;
        'type'?: string;
    }
}
export declare namespace v1.auditLogs {
    /**
     * Resource that the developer operated on. Both do not need to be provided.
     * @interface
     */
    interface ResourceFilter {
        'id'?: string;
        'type'?: v1.auditLogs.ResourceTypeEnum;
    }
}
export declare namespace v1.auditLogs {
    /**
     *
     * @enum
     */
    type ResourceTypeEnum = 'Skill' | 'SkillCatalog' | 'InSkillProduct' | 'Import' | 'Export';
}
export declare namespace v1.auditLogs {
    /**
     * This object contains the next token used to load the next page of the result.
     * @interface
     */
    interface ResponsePaginationContext {
        /**
         * This token can be used to load the next page of the result.
         */
        'nextToken'?: string;
    }
}
export declare namespace v1.auditLogs {
    /**
     * Sets the sorting direction of the result items. When set to 'ASC' these items are returned in ascending order of sortField value and when set to 'DESC' these items are returned in descending order of sortField value.
     * @enum
     */
    type SortDirection = 'ASC' | 'DESC';
}
export declare namespace v1.auditLogs {
    /**
     * Sets the field on which the sorting would be applied.
     * @enum
     */
    type SortField = 'timestamp' | 'operation' | 'resource.id' | 'resource.type' | 'requester.userId' | 'client.id' | 'httpResponseCode';
}
export declare namespace v1.catalog {
    /**
     *
     * @interface
     */
    interface CreateContentUploadUrlRequest {
        /**
         * Provides the number of parts the file will be split into. An equal number of presigned upload urls are generated in response to facilitate each part's upload.
         */
        'numberOfUploadParts': number;
    }
}
export declare namespace v1.catalog {
    /**
     *
     * @interface
     */
    interface CreateContentUploadUrlResponse {
        /**
         * Unique identifier for collection of generated urls.
         */
        'urlId': string;
        /**
         * Ordered list of presigned upload parts to perform a partitioned (multipart) file upload
         */
        'presignedUploadParts'?: Array<v1.catalog.PresignedUploadPartItems>;
    }
}
export declare namespace v1.catalog {
    /**
     *
     * @interface
     */
    interface PresignedUploadPartItems {
        'url': string;
        'partNumber': number;
        'expiresAt': string;
    }
}
export declare namespace v1.catalog.upload {
    /**
     *
     * @interface
     */
    type CatalogUploadBase = v1.catalog.upload.Location | v1.catalog.upload.PreSignedUrl;
}
export declare namespace v1.catalog.upload {
    /**
     *
     * @interface
     */
    interface ContentUploadFileSummary {
        /**
         * If the file is available for download, downloadUrl can be used to download the file.
         */
        'downloadUrl': string;
        'expiresAt': string;
        'status': v1.catalog.upload.FileUploadStatus;
    }
}
export declare namespace v1.catalog.upload {
    /**
     * Value of status depends on if file is available for download or not.
     * @enum
     */
    type FileUploadStatus = 'PENDING' | 'AVAILABLE' | 'PURGED' | 'UNAVAILABLE';
}
export declare namespace v1.catalog.upload {
    /**
     *
     * @interface
     */
    interface GetContentUploadResponse {
        /**
         * Unique identifier of the upload
         */
        'id': string;
        /**
         * Unique identifier of the added catalog object
         */
        'catalogId': string;
        'status': v1.catalog.upload.UploadStatus;
        'createdDate': string;
        'lastUpdatedDate': string;
        'file': v1.catalog.upload.ContentUploadFileSummary;
        /**
         * List of different steps performed on the upload.
         */
        'ingestionSteps': Array<v1.catalog.upload.UploadIngestionStep>;
    }
}
export declare namespace v1.catalog.upload {
    /**
     *
     * @enum
     */
    type IngestionStatus = 'PENDING' | 'IN_PROGRESS' | 'FAILED' | 'SUCCEEDED' | 'CANCELLED';
}
export declare namespace v1.catalog.upload {
    /**
     *
     * @enum
     */
    type IngestionStepName = 'UPLOAD' | 'SCHEMA_VALIDATION';
}
export declare namespace v1.catalog.upload {
    /**
     *
     * @interface
     */
    interface PreSignedUrlItem {
        'eTag'?: string;
        'partNumber'?: number;
    }
}
export declare namespace v1.catalog.upload {
    /**
     * Represents a single step in the multi-step ingestion process of a new upload.
     * @interface
     */
    interface UploadIngestionStep {
        'name': v1.catalog.upload.IngestionStepName;
        'status': v1.catalog.upload.IngestionStatus;
        /**
         * Url for the file containing logs of ingestion step.
         */
        'logUrl'?: string;
        /**
         * This array will contain the violations occurred during the execution of step. Will be empty, if execution succeeded.
         */
        'violations': Array<v1.Error>;
    }
}
export declare namespace v1.catalog.upload {
    /**
     * Status of the entire upload.
     * @enum
     */
    type UploadStatus = 'PENDING' | 'IN_PROGRESS' | 'FAILED' | 'SUCCEEDED';
}
export declare namespace v1.isp {
    /**
     * In-skill product skill association details.
     * @interface
     */
    interface AssociatedSkillResponse {
        /**
         * List of skill IDs that correspond to the skills associated with the in-skill product. The associations are stage specific. A live association is created through successful skill certification.
         */
        'associatedSkillIds'?: Array<string>;
        '_links'?: v1.Links;
        'isTruncated'?: boolean;
        'nextToken'?: string;
    }
}
export declare namespace v1.isp {
    /**
     * Currency to use for in-skill product.
     * @enum
     */
    type Currency = 'USD' | 'GBP' | 'EUR' | 'JPY';
}
export declare namespace v1.isp {
    /**
     * Custom prompts used for in-skill product purchasing options. Supports Speech Synthesis Markup Language (SSML), which can be used to control pronunciation, intonation, timing, and emotion.
     * @interface
     */
    interface CustomProductPrompts {
        /**
         * Description of in-skill product heard before customer is prompted for purchase.
         */
        'purchasePromptDescription'?: string;
        /**
         * A description of the product that displays on the skill card in the Alexa app.
         */
        'boughtCardDescription'?: string;
    }
}
export declare namespace v1.isp {
    /**
     *
     * @enum
     */
    type DistributionCountries = 'AF' | 'AX' | 'AL' | 'DZ' | 'AS' | 'AD' | 'AO' | 'AI' | 'AQ' | 'AG' | 'AR' | 'AM' | 'AW' | 'AU' | 'AT' | 'AZ' | 'BS' | 'BH' | 'BD' | 'BB' | 'BY' | 'BE' | 'BZ' | 'BJ' | 'BM' | 'BT' | 'BO' | 'BA' | 'BW' | 'BV' | 'BR' | 'IO' | 'BN' | 'BG' | 'BF' | 'BI' | 'KH' | 'CM' | 'CA' | 'CV' | 'KY' | 'CF' | 'TD' | 'CL' | 'CN' | 'CX' | 'CC' | 'CO' | 'KM' | 'CG' | 'CD' | 'CK' | 'CR' | 'HR' | 'CY' | 'CZ' | 'DK' | 'DJ' | 'DM' | 'DO' | 'EC' | 'EG' | 'SV' | 'GQ' | 'ER' | 'EE' | 'ET' | 'FK' | 'FO' | 'FJ' | 'FI' | 'FR' | 'GF' | 'PF' | 'TF' | 'GA' | 'GM' | 'GE' | 'DE' | 'GH' | 'GI' | 'GR' | 'GL' | 'GD' | 'GP' | 'GU' | 'GT' | 'GG' | 'GN' | 'GW' | 'GY' | 'HT' | 'HM' | 'VA' | 'HN' | 'HK' | 'HU' | 'IS' | 'IN' | 'ID' | 'IQ' | 'IE' | 'IM' | 'IL' | 'IT' | 'CI' | 'JM' | 'JP' | 'JE' | 'JO' | 'KZ' | 'KE' | 'KI' | 'KR' | 'KW' | 'KG' | 'LA' | 'LV' | 'LB' | 'LS' | 'LR' | 'LY' | 'LI' | 'LT' | 'LU' | 'MO' | 'MK' | 'MG' | 'MW' | 'MY' | 'MV' | 'ML' | 'MT' | 'MH' | 'MQ' | 'MR' | 'MU' | 'YT' | 'MX' | 'FM' | 'MD' | 'MC' | 'MN' | 'ME' | 'MS' | 'MA' | 'MZ' | 'MM' | 'NA' | 'NR' | 'NP' | 'NL' | 'AN' | 'NC' | 'NZ' | 'NI' | 'NE' | 'NG' | 'NU' | 'NF' | 'MP' | 'NO' | 'OM' | 'PK' | 'PW' | 'PS' | 'PA' | 'PG' | 'PY' | 'PE' | 'PH' | 'PN' | 'PL' | 'PT' | 'PR' | 'QA' | 'RE' | 'RO' | 'RU' | 'RW' | 'BL' | 'SH' | 'KN' | 'LC' | 'MF' | 'PM' | 'VC' | 'WS' | 'SM' | 'ST' | 'SA' | 'SN' | 'RS' | 'SC' | 'SL' | 'SG' | 'SK' | 'SI' | 'SB' | 'SO' | 'ZA' | 'GS' | 'ES' | 'LK' | 'SR' | 'SJ' | 'SZ' | 'SE' | 'CH' | 'TW' | 'TJ' | 'TZ' | 'TH' | 'TL' | 'TG' | 'TK' | 'TO' | 'TT' | 'TN' | 'TR' | 'TM' | 'TC' | 'TV' | 'UG' | 'UA' | 'AE' | 'GB' | 'US' | 'UM' | 'UY' | 'UZ' | 'VU' | 'VE' | 'VN' | 'VG' | 'VI' | 'WF' | 'EH' | 'YE' | 'ZM' | 'ZW';
}
export declare namespace v1.isp {
    /**
     * Whether or not the in-skill product is editable.
     * @enum
     */
    type EditableState = 'EDITABLE' | 'NOT_EDITABLE';
}
export declare namespace v1.isp {
    /**
     * Defines the structure for an in-skill product.
     * @interface
     */
    interface InSkillProductDefinition {
        /**
         * Version of in-skill product definition.
         */
        'version'?: string;
        'type'?: v1.isp.ProductType;
        /**
         * Developer selected in-skill product name. This is for developer reference only, it can be used to filter query results to identify a matching in-skill product.
         */
        'referenceName'?: string;
        'purchasableState'?: v1.isp.PurchasableState;
        'promotableState'?: v1.isp.PromotableState;
        'subscriptionInformation'?: v1.isp.SubscriptionInformation;
        'publishingInformation'?: v1.isp.PublishingInformation;
        'privacyAndCompliance'?: v1.isp.PrivacyAndCompliance;
        /**
         * Special instructions provided by the developer to test the in-skill product.
         */
        'testingInstructions'?: string;
    }
}
export declare namespace v1.isp {
    /**
     * Defines In-skill product response.
     * @interface
     */
    interface InSkillProductDefinitionResponse {
        'inSkillProductDefinition'?: v1.isp.InSkillProductDefinition;
    }
}
export declare namespace v1.isp {
    /**
     * Information about the in-skill product that is not editable.
     * @interface
     */
    interface InSkillProductSummary {
        'type'?: v1.isp.ProductType;
        /**
         * primary identifier of in-skill product.
         */
        'productId'?: string;
        /**
         * Developer selected in-skill product name. This is for developer reference only, it can be used to filter query results to identify a matching in-skill product.
         */
        'referenceName'?: string;
        /**
         * Date of last update.
         */
        'lastUpdated'?: string;
        'nameByLocale'?: {
            [key: string]: string;
        };
        'status'?: v1.isp.Status;
        'stage'?: v1.StageType;
        'editableState'?: v1.isp.EditableState;
        'purchasableState'?: v1.isp.PurchasableState;
        'promotableState'?: v1.isp.PromotableState;
        '_links'?: v1.isp.IspSummaryLinks;
        /**
         * In-skill product pricing information.
         */
        'pricing'?: {
            [key: string]: v1.isp.SummaryMarketplacePricing;
        };
    }
}
export declare namespace v1.isp {
    /**
     * In-skill product summary response.
     * @interface
     */
    interface InSkillProductSummaryResponse {
        'inSkillProductSummary'?: v1.isp.InSkillProductSummary;
    }
}
export declare namespace v1.isp {
    /**
     *
     * @interface
     */
    interface IspSummaryLinks {
        'self'?: v1.Link;
    }
}
export declare namespace v1.isp {
    /**
     * List of in-skill products.
     * @interface
     */
    interface ListInSkillProduct {
        '_links'?: v1.Links;
        /**
         * Information for each in-skill product.
         */
        'inSkillProducts'?: Array<v1.isp.InSkillProductSummary>;
        'isTruncated'?: boolean;
        'nextToken'?: string;
    }
}
export declare namespace v1.isp {
    /**
     * List of in-skill product response.
     * @interface
     */
    interface ListInSkillProductResponse {
        'inSkillProductSummaryList'?: v1.isp.ListInSkillProduct;
    }
}
export declare namespace v1.isp {
    /**
     * Defines the structure for localized privacy and compliance.
     * @interface
     */
    interface LocalizedPrivacyAndCompliance {
        /**
         * Link to the privacy policy that applies to this in-skill product.
         */
        'privacyPolicyUrl'?: string;
    }
}
export declare namespace v1.isp {
    /**
     * Defines the structure for locale specific publishing information in the in-skill product definition.
     * @interface
     */
    interface LocalizedPublishingInformation {
        /**
         * Name of the in-skill product that is heard by customers and displayed in the Alexa app.
         */
        'name'?: string;
        /**
         * Uri for the small icon image of the in-skill product.
         */
        'smallIconUri'?: string;
        /**
         * Uri for the large icon image of the in-skill product.
         */
        'largeIconUri'?: string;
        /**
         * Short description of the in-skill product that displays on the in-skill product list page in the Alexa App.
         */
        'summary'?: string;
        /**
         * Description of the in-skill product's purpose and features, and how it works. Should describe any prerequisites like hardware or account requirements and detailed steps for the customer to get started. This description displays to customers on the in-skill product detail card in the Alexa app.
         */
        'description'?: string;
        /**
         * Example phrases appear on the in-skill product detail page and are the key utterances that customers can say to interact directly with the in-skill product.
         */
        'examplePhrases'?: Array<string>;
        /**
         * Search terms that can be used to describe the in-skill product. This helps customers find an in-skill product.
         */
        'keywords'?: Array<string>;
        'customProductPrompts'?: v1.isp.CustomProductPrompts;
    }
}
export declare namespace v1.isp {
    /**
     * In-skill product pricing information for a marketplace.
     * @interface
     */
    interface MarketplacePricing {
        /**
         * Date when in-skill product is available to customers for both purchase and use. Prior to this date the in-skill product will appear unavailable to customers and will not be purchasable.
         */
        'releaseDate'?: string;
        'defaultPriceListing'?: v1.isp.PriceListing;
    }
}
export declare namespace v1.isp {
    /**
     * Price listing information for in-skill product.
     * @interface
     */
    interface PriceListing {
        /**
         * Defines the price of an in-skill product. The list price should be your suggested price, not including any VAT or similar taxes. Taxes are included in the final price to end users.
         */
        'price'?: number;
        'currency'?: v1.isp.Currency;
    }
}
export declare namespace v1.isp {
    /**
     * Defines the structure for privacy and compliance.
     * @interface
     */
    interface PrivacyAndCompliance {
        /**
         * Defines the structure for locale specific privacy and compliance.
         */
        'locales'?: {
            [key: string]: v1.isp.LocalizedPrivacyAndCompliance;
        };
    }
}
export declare namespace v1.isp {
    /**
     * Product ID information.
     * @interface
     */
    interface ProductResponse {
        /**
         * ID of the in-skill product created.
         */
        'productId'?: string;
    }
}
export declare namespace v1.isp {
    /**
     * Type of in-skill product.
     * @enum
     */
    type ProductType = 'SUBSCRIPTION' | 'ENTITLEMENT' | 'CONSUMABLE';
}
export declare namespace v1.isp {
    /**
     * Promote this ISP on Amazon channels such as Amazon.com. Enabling this setting will allow customers to view ISP detail pages and purchase the ISP on Amazon.com.
     * @enum
     */
    type PromotableState = 'IN_SKILL_ONLY' | 'ALL_AMAZON_CHANNELS';
}
export declare namespace v1.isp {
    /**
     * Defines the structure for in-skill product publishing information.
     * @interface
     */
    interface PublishingInformation {
        /**
         * Defines the structure for locale specific publishing information for an in-skill product.
         */
        'locales'?: {
            [key: string]: v1.isp.LocalizedPublishingInformation;
        };
        /**
         * List of countries where the in-skill product is available.
         */
        'distributionCountries'?: Array<v1.isp.DistributionCountries>;
        /**
         * Defines the structure for in-skill product pricing.
         */
        'pricing'?: {
            [key: string]: v1.isp.MarketplacePricing;
        };
        'taxInformation'?: v1.isp.TaxInformation;
    }
}
export declare namespace v1.isp {
    /**
     * Whether or not the in-skill product is purchasable by customers. A product that is not purchasable will prevent new customers from being prompted to purchase the product. Customers who already own the product will see no effect and continue to have access to the product features.
     * @enum
     */
    type PurchasableState = 'PURCHASABLE' | 'NOT_PURCHASABLE';
}
export declare namespace v1.isp {
    /**
     * Current status of in-skill product.
     * @enum
     */
    type Status = 'INCOMPLETE' | 'COMPLETE' | 'CERTIFICATION' | 'PUBLISHED' | 'SUPPRESSED';
}
export declare namespace v1.isp {
    /**
     * Defines the structure for in-skill product subscription information.
     * @interface
     */
    interface SubscriptionInformation {
        'subscriptionPaymentFrequency'?: v1.isp.SubscriptionPaymentFrequency;
        /**
         * Days of free trial period for subscription. Max allowed is 365 days.
         */
        'subscriptionTrialPeriodDays'?: number;
    }
}
export declare namespace v1.isp {
    /**
     * Localized in-skill product pricing information.
     * @interface
     */
    interface SummaryMarketplacePricing {
        /**
         * Date when in-skill product is available to customers for both purchase and use. Prior to this date the in-skill product will appear unavailable to customers and will not be purchasable.
         */
        'releaseDate'?: string;
        'defaultPriceListing'?: v1.isp.SummaryPriceListing;
    }
}
export declare namespace v1.isp {
    /**
     * Price listing information for in-skill product.
     * @interface
     */
    interface SummaryPriceListing {
        /**
         * The price of an in-skill product.
         */
        'price'?: number;
        /**
         * The prime price of an in-skill product.
         */
        'primeMemberPrice'?: number;
        'currency'?: v1.isp.Currency;
    }
}
export declare namespace v1.isp {
    /**
     * Defines the structure for in-skill product tax information.
     * @interface
     */
    interface TaxInformation {
        'category'?: v1.isp.TaxInformationCategory;
    }
}
export declare namespace v1.isp {
    /**
     * Select tax category that best describes in-skill product. Choice will be validated during certification process.
     * @enum
     */
    type TaxInformationCategory = 'SOFTWARE' | 'STREAMING_AUDIO' | 'STREAMING_RADIO' | 'INFORMATION_SERVICES' | 'VIDEO' | 'PERIODICALS' | 'NEWSPAPERS';
}
export declare namespace v1.isp {
    /**
     *
     * @interface
     */
    interface CreateInSkillProductRequest {
        /**
         * ID of the vendor owning the in-skill product.
         */
        'vendorId'?: string;
        'inSkillProductDefinition'?: v1.isp.InSkillProductDefinition;
    }
}
export declare namespace v1.isp {
    /**
     * The frequency in which payments are collected for the subscription.
     * @enum
     */
    type SubscriptionPaymentFrequency = 'MONTHLY' | 'YEARLY';
}
export declare namespace v1.isp {
    /**
     *
     * @interface
     */
    interface UpdateInSkillProductRequest {
        'inSkillProductDefinition'?: v1.isp.InSkillProductDefinition;
    }
}
export declare namespace v1.skill {
    /**
     * Action of a resource.
     * @enum
     */
    type Action = 'CREATE' | 'UPDATE' | 'ASSOCIATE' | 'DISASSOCIATE';
}
export declare namespace v1.skill {
    /**
     * Type of the agreement that the customer must be compliant to.
     * @enum
     */
    type AgreementType = 'EXPORT_COMPLIANCE';
}
export declare namespace v1.skill.AlexaHosted {
    /**
     * Alexa hosted skill create configuration
     * @interface
     */
    interface AlexaHostedConfig {
        'runtime'?: v1.skill.AlexaHosted.HostedSkillRuntime;
        'region'?: v1.skill.AlexaHosted.HostedSkillRegion;
    }
}
export declare namespace v1.skill.AlexaHosted {
    /**
     *
     * @interface
     */
    interface HostedSkillInfo {
        'repository'?: v1.skill.AlexaHosted.HostedSkillRepositoryInfo;
        'runtime'?: v1.skill.AlexaHosted.HostedSkillRuntime;
    }
}
export declare namespace v1.skill.AlexaHosted {
    /**
     * Alexa Hosted skill's metadata
     * @interface
     */
    interface HostedSkillMetadata {
        'alexaHosted'?: v1.skill.AlexaHosted.HostedSkillInfo;
    }
}
export declare namespace v1.skill.AlexaHosted {
    /**
     * Customer's permission about Hosted skill features.
     * @interface
     */
    interface HostedSkillPermission {
        'permission'?: v1.skill.AlexaHosted.HostedSkillPermissionType;
        'status'?: v1.skill.AlexaHosted.HostedSkillPermissionStatus;
        'actionUrl'?: string;
    }
}
export declare namespace v1.skill.AlexaHosted {
    /**
     *
     * @enum
     */
    type HostedSkillPermissionStatus = 'ALLOWED' | 'NEW_USER_REGISTRATION_REQUIRED' | 'RESOURCE_LIMIT_EXCEEDED' | 'RATE_EXCEEDED';
}
export declare namespace v1.skill.AlexaHosted {
    /**
     *
     * @enum
     */
    type HostedSkillPermissionType = 'NEW_SKILL';
}
export declare namespace v1.skill.AlexaHosted {
    /**
     * Hosted skill AWS region
     * @enum
     */
    type HostedSkillRegion = 'US_EAST_1' | 'US_WEST_2' | 'EU_WEST_1';
}
export declare namespace v1.skill.AlexaHosted {
    /**
     *
     * @enum
     */
    type HostedSkillRepository = 'GIT';
}
export declare namespace v1.skill.AlexaHosted {
    /**
     *
     * @interface
     */
    interface HostedSkillRepositoryCredentials {
        /**
         * AWS Access Key ID used to access hosted skill repository
         */
        'username'?: string;
        /**
         * signed AWS Credentials used to access hosted skill repository
         */
        'password'?: string;
        /**
         * expiration time for the credentials
         */
        'expiresAt'?: string;
    }
}
export declare namespace v1.skill.AlexaHosted {
    /**
     * defines the structure for the hosted skill repository credentials response
     * @interface
     */
    interface HostedSkillRepositoryCredentialsList {
        'repositoryCredentials'?: v1.skill.AlexaHosted.HostedSkillRepositoryCredentials;
    }
}
export declare namespace v1.skill.AlexaHosted {
    /**
     *
     * @interface
     */
    interface HostedSkillRepositoryCredentialsRequest {
        'repository': v1.skill.AlexaHosted.HostedSkillRepositoryInfo;
    }
}
export declare namespace v1.skill.AlexaHosted {
    /**
     * Alexa Hosted Skill's Repository Information
     * @interface
     */
    interface HostedSkillRepositoryInfo {
        'url': string;
        'type': v1.skill.AlexaHosted.HostedSkillRepository;
    }
}
export declare namespace v1.skill.AlexaHosted {
    /**
     * Hosted skill lambda runtime; Node.js 12.x is deprecated by Hosted Skill service as of October 24, 2022.
     * @enum
     */
    type HostedSkillRuntime = 'NODE_10_X' | 'PYTHON_3_7' | 'NODE_12_X' | 'NODE_16_X';
}
export declare namespace v1.skill.AlexaHosted {
    /**
     * Configurations for creating new hosted skill
     * @interface
     */
    interface HostingConfiguration {
        'alexaHosted'?: v1.skill.AlexaHosted.AlexaHostedConfig;
    }
}
export declare namespace v1.skill {
    /**
     * Contains array which describes steps involved in a build. Elements (or build steps) are added to this array as they become IN_PROGRESS.
     * @interface
     */
    interface BuildDetails {
        /**
         * An array where each element represents a build step.
         */
        'steps'?: Array<v1.skill.BuildStep>;
    }
}
export declare namespace v1.skill {
    /**
     * Describes the status of a build step.
     * @interface
     */
    interface BuildStep {
        'name'?: v1.skill.BuildStepName;
        'status'?: v1.skill.Status;
        'errors'?: Array<v1.skill.StandardizedError>;
    }
}
export declare namespace v1.skill {
    /**
     * Name of the build step. Possible values - * `DIALOG_MODEL_BUILD` - Build status for dialog model. * `LANGUAGE_MODEL_QUICK_BUILD` - Build status for FST model. * `LANGUAGE_MODEL_FULL_BUILD` - Build status for statistical model. * `ALEXA_CONVERSATIONS_QUICK_BUILD` - AlexaConversations LowFidelity model build status. * `ALEXA_CONVERSATIONS_FULL_BUILD` - AlexaConversations HighFidelity model build status.
     * @enum
     */
    type BuildStepName = 'DIALOG_MODEL_BUILD' | 'LANGUAGE_MODEL_QUICK_BUILD' | 'LANGUAGE_MODEL_FULL_BUILD' | 'ALEXA_CONVERSATIONS_QUICK_BUILD' | 'ALEXA_CONVERSATIONS_FULL_BUILD';
}
export declare namespace v1.skill {
    /**
     * Defines the request body for the cloneLocale API.
     * @interface
     */
    interface CloneLocaleRequest {
        /**
         * Locale with the assets that will be cloned.
         */
        'sourceLocale': string;
        /**
         * A list of locale(s) where the assets will be copied to.
         */
        'targetLocales': Array<string>;
        /**
         * Can locale of skill be overwritten. Default value is DO_NOT_OVERWRITE.
         */
        'overwriteMode'?: v1.skill.OverwriteMode;
    }
}
export declare namespace v1.skill {
    /**
     * Status for a locale clone request CloneLocale API initiates cloning from a source locale to all target locales.   * `IN_PROGRESS` status would indicate the clone is still in progress.   * `SUCCEEDED` status would indicate the source locale was cloned successfully to all target locales.   * `INELIGIBLE` status would indicate the source locale was ineligible to be cloned to all target locales.   * `MIXED` status would indicate the different status of clone on different locales, and individual target locale statues should be checked.   * `FAILED` status would indicate the source locale was not cloned all target locales successfully despite the request being eligible due to internal service issues.   * `ROLLBACK_SUCCEEDED` status would indicate the skill was rolled back to the previous state in case any failure.   * `ROLLBACK_FAILED` status would indicate that in case of failure, the rollback to the previous state of the skill was attempted, but it failed.
     * @enum
     */
    type CloneLocaleRequestStatus = 'FAILED' | 'INELIGIBLE' | 'IN_PROGRESS' | 'MIXED' | 'ROLLBACK_FAILED' | 'ROLLBACK_SUCCEEDED' | 'SUCCEEDED';
}
export declare namespace v1.skill {
    /**
     * an object detailing the status of a locale clone request and if applicable the errors occurred when saving/building resources during clone process.
     * @interface
     */
    interface CloneLocaleResourceStatus {
        'status'?: v1.skill.CloneLocaleStatus;
        'errors'?: Array<v1.skill.StandardizedError>;
    }
}
export declare namespace v1.skill {
    /**
     *
     * @enum
     */
    type CloneLocaleStageType = 'development';
}
export declare namespace v1.skill {
    /**
     * Status for a locale clone on a particular target locale   * `IN_PROGRESS` status would indicate the clone is still in progress to the target locale.   * `SUCCEEDED` status would indicate the source locale was cloned successfully to the target locale.   * `INELIGIBLE` status would indicate the source locale was ineligible to be cloned the target locale.   * `FAILED` status would indicate the source locale was not cloned the target locale successfully.   * `ROLLBACK_SUCCEEDED` status would indicate the locale was rolled back to the previous state in case any failure.   * `ROLLBACK_FAILED` status would indicate that in case of failure, the rollback to the previous state of the locale was attempted, but it failed.
     * @enum
     */
    type CloneLocaleStatus = 'FAILED' | 'INELIGIBLE' | 'IN_PROGRESS' | 'ROLLBACK_FAILED' | 'ROLLBACK_SUCCEEDED' | 'SUCCEEDED';
}
export declare namespace v1.skill {
    /**
     * A mapping of statuses per locale detailing progress of resource or error if encountered.
     * @interface
     */
    interface CloneLocaleStatusResponse {
        'status'?: v1.skill.CloneLocaleRequestStatus;
        'errors'?: Array<v1.skill.StandardizedError>;
        /**
         * Source locale which is cloned to target locales.
         */
        'sourceLocale'?: string;
        /**
         * Mapping of statuses per locale.
         */
        'targetLocales'?: {
            [key: string]: v1.skill.CloneLocaleResourceStatus;
        };
    }
}
export declare namespace v1.skill {
    /**
     * Defines the request body to create a rollback request
     * @interface
     */
    interface CreateRollbackRequest {
        /**
         * The target skill version to rollback to.
         */
        'targetVersion': string;
    }
}
export declare namespace v1.skill {
    /**
     * Defines the response body when a rollback request is created
     * @interface
     */
    interface CreateRollbackResponse {
        /**
         * Defines the identifier for a rollback request.
         */
        'rollbackRequestId'?: string;
    }
}
export declare namespace v1.skill {
    /**
     * SkillId information.
     * @interface
     */
    interface CreateSkillResponse {
        /**
         * ID of the skill created.
         */
        'skillId'?: string;
    }
}
export declare namespace v1.skill {
    /**
     *
     * @interface
     */
    interface ExportResponse {
        'status'?: v1.skill.ResponseStatus;
        'skill'?: v1.skill.ExportResponseSkill;
    }
}
export declare namespace v1.skill {
    /**
     * Defines the structure of the GetExport response.
     * @interface
     */
    interface ExportResponseSkill {
        'eTag'?: string;
        'location'?: string;
        /**
         * ExpiresAt timestamp in milliseconds.
         */
        'expiresAt'?: string;
    }
}
export declare namespace v1.skill {
    /**
     * Format in which instance value is expected in.
     * @enum
     */
    type Format = 'URI';
}
export declare namespace v1.skill {
    /**
     * Details about hosted skill deployment.
     * @interface
     */
    interface HostedSkillDeploymentDetails {
        'commitId'?: string;
        'logUrl'?: string;
    }
}
export declare namespace v1.skill {
    /**
     * Defines the most recent deployment status for the Alexa hosted skill.
     * @interface
     */
    interface HostedSkillDeploymentStatus {
        'lastUpdateRequest'?: v1.skill.HostedSkillDeploymentStatusLastUpdateRequest;
    }
}
export declare namespace v1.skill {
    /**
     * Contains attributes related to last modification request of a hosted skill deployment resource.
     * @interface
     */
    interface HostedSkillDeploymentStatusLastUpdateRequest {
        'status'?: v1.skill.Status;
        'errors'?: Array<v1.skill.StandardizedError>;
        'warnings'?: Array<v1.skill.StandardizedError>;
        'deploymentDetails'?: v1.skill.HostedSkillDeploymentDetails;
    }
}
export declare namespace v1.skill {
    /**
     * Contains attributes related to last modification request of a hosted skill provisioning resource.
     * @interface
     */
    interface HostedSkillProvisioningLastUpdateRequest {
        'status'?: v1.skill.Status;
        'errors'?: Array<v1.skill.StandardizedError>;
        'warnings'?: Array<v1.skill.StandardizedError>;
    }
}
export declare namespace v1.skill {
    /**
     * Defines the provisioning status for hosted skill.
     * @interface
     */
    interface HostedSkillProvisioningStatus {
        'lastUpdateRequest'?: v1.skill.HostedSkillProvisioningLastUpdateRequest;
    }
}
export declare namespace v1.skill {
    /**
     * Dimensions of an image.
     * @interface
     */
    interface ImageDimension {
        /**
         * Width of the image in pixels.
         */
        'widthInPixels'?: number;
        /**
         * Height of the image in pixels.
         */
        'heightInPixels'?: number;
    }
}
export declare namespace v1.skill {
    /**
     * On disk storage size of image.
     * @interface
     */
    interface ImageSize {
        /**
         * Value measuring the size of the image.
         */
        'value'?: number;
        'unit'?: v1.skill.ImageSizeUnit;
    }
}
export declare namespace v1.skill {
    /**
     * Unit of measurement for size of image.
     * @enum
     */
    type ImageSizeUnit = 'MB';
}
export declare namespace v1.skill {
    /**
     *
     * @interface
     */
    interface ImportResponse {
        'status'?: v1.skill.ResponseStatus;
        'errors'?: Array<v1.skill.StandardizedError>;
        'warnings'?: Array<v1.skill.StandardizedError>;
        'skill'?: v1.skill.ImportResponseSkill;
    }
}
export declare namespace v1.skill {
    /**
     *
     * @interface
     */
    interface ImportResponseSkill {
        'skillId'?: string;
        'eTag'?: string;
        'resources': Array<v1.skill.ResourceImportStatus>;
    }
}
export declare namespace v1.skill {
    /**
     * Structure representing properties of an instance of data. Definition will be either one of a booleanInstance, stringInstance, integerInstance, or compoundInstance.
     * @interface
     */
    interface Instance {
        /**
         * Path that uniquely identifies the instance in the resource.
         */
        'propertyPath'?: string;
        'dataType'?: v1.skill.ValidationDataTypes;
        /**
         * String value of the instance. Incase of null, object or array the value field would be null or not present. Incase of string, boolean or integer dataType it will be the corresponding String value.
         */
        'value'?: string;
    }
}
export declare namespace v1.skill {
    /**
     * Contains attributes related to last modification (create/update) request of a resource.
     * @interface
     */
    interface InteractionModelLastUpdateRequest {
        'status'?: v1.skill.Status;
        'errors'?: Array<v1.skill.StandardizedError>;
        'warnings'?: Array<v1.skill.StandardizedError>;
        'buildDetails'?: v1.skill.BuildDetails;
    }
}
export declare namespace v1.skill {
    /**
     * List of skills for the vendor.
     * @interface
     */
    interface ListSkillResponse {
        '_links'?: v1.Links;
        /**
         * List of skill summaries. List might contain either one, two or three entries for a given skillId depending on the skill's publication history and the publication method. `Skill containing certified stage` * If a skill was never published to live, this list will contain two entries `:` one with stage 'development' and another with stage 'certified'. Both of these summaries will have same skillId. * For any skill that has been published to 'live', this list will contain three entries `:` one with stage 'development', one with stage `certified` and one with stage 'live'. All of these summaries will have same skillId. `Skill without certified stage` * If a skill was never published to live, this list will contain only one entry for the skill with stage as 'development'. * For any skill that has been published to 'live', this list will contain two entries `:` one with stage 'development' and another with stage 'live'. Both of these summaries will have same skillId.
         */
        'skills'?: Array<v1.skill.SkillSummary>;
        'isTruncated'?: boolean;
        'nextToken'?: string;
    }
}
export declare namespace v1.skill {
    /**
     * List of all skill versions
     * @interface
     */
    interface ListSkillVersionsResponse {
        '_links'?: v1.Links;
        /**
         * Skill version metadata
         */
        'skillVersions'?: Array<v1.skill.SkillVersion>;
        'isTruncated'?: boolean;
        'nextToken'?: string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface AlexaDataStorePackageManagerImplementedInterface {
        /**
         * The list of data store packages that are authored by skill developer.
         */
        'packages'?: Array<v1.skill.Manifest.DataStorePackage>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure of alexaForBusiness api in the skill manifest.
     * @interface
     */
    interface AlexaForBusinessApis {
        /**
         * Contains an array of the supported <region> Objects.
         */
        'regions'?: {
            [key: string]: v1.skill.Manifest.Region;
        };
        'endpoint'?: v1.skill.Manifest.SkillManifestEndpoint;
        /**
         * Contains the list of supported interfaces.
         */
        'interfaces'?: Array<v1.skill.Manifest.AlexaForBusinessInterface>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface AlexaForBusinessInterface {
        /**
         * Name of the interface.
         */
        'namespace': string;
        'version': v1.skill.Manifest.Version;
        /**
         * Contains a list of requests/messages that skill can handle.
         */
        'requests': Array<v1.skill.Manifest.AlexaForBusinessInterfaceRequest>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface AlexaForBusinessInterfaceRequest {
        'name': v1.skill.Manifest.AlexaForBusinessInterfaceRequestName;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Name of the request.
     * @enum
     */
    type AlexaForBusinessInterfaceRequestName = 'Search' | 'Create' | 'Update';
}
export declare namespace v1.skill.Manifest {
    /**
     * Supported android common intent. Each of the value maps to a common intent defined in https://developer.android.com/guide/components/intents-common.
     * @enum
     */
    type AndroidCommonIntentName = 'SHOW_IN_MAP' | 'ADD_CALENDAR_EVENT' | 'PLAY_MEDIA' | 'START_PHONE_CALL' | 'OPEN_SETTINGS';
}
export declare namespace v1.skill.Manifest {
    /**
     * Android custom intent
     * @interface
     */
    interface AndroidCustomIntent {
        /**
         * android component name
         */
        'component'?: string;
        /**
         * android intent action
         */
        'action'?: string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Details required for app linking use cases.
     * @interface
     */
    interface AppLink {
        /**
         * Allows developers to declare their Skill will use Alexa App Links, and list relevant apps. This field is required when using the APP_LINK interface.
         */
        'linkedApplications'?: Array<v1.skill.Manifest.LinkedApplication>;
        /**
         * Allow developer to decalre their skill to link to the declared web domains.
         */
        'linkedWebDomains'?: Array<string>;
        /**
         * Allow developer to declare their skill to link to the speicified android common intents.
         */
        'linkedAndroidCommonIntents'?: Array<v1.skill.Manifest.LinkedAndroidCommonIntent>;
        'linkedCommonSchemes'?: v1.skill.Manifest.LinkedCommonSchemes;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines a client authorized for a skill.
     * @interface
     */
    interface AuthorizedClient {
        'authenticationProvider': string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines an application for LWA security profile.
     * @interface
     */
    interface AuthorizedClientLwaApplication {
        'type': string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for Sync Locales in the skill manifest. This is an optional property and Sync Locales will be disabled if not set.
     * @interface
     */
    interface AutomaticClonedLocale {
        /**
         * List of language specific source locale to target locales mapping.
         */
        'locales': Array<v1.skill.Manifest.LocalesByAutomaticClonedLocale>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * optional. Used by developer to opt in to Automatic Skill Distribution, a feature where a skill will automatically be published in new eligible locales from the same language (e.g. from \"en-US\" to \"en-CA\" and \"en-GB\"). Locales that the developer has already created will not be overwritten.
     * @interface
     */
    interface AutomaticDistribution {
        /**
         * set to true to opt in to Automatic Skill Distribution. If false, then the skill will not be considered for Automatic Skill Distribution. Note that once a skill has gone through the automatic distribution process and this value is later set to false, any locales that were published through this feature will not be reverted. Any published locales will need to be suppressed manually via contacting DAG.
         */
        'isActive': boolean;
        /**
         * list of items pairing a language with a source locale. Required if isActive is set to true. For each language there must be exactly one source locale.
         */
        'sourceLocaleForLanguages'?: Array<v1.skill.Manifest.SourceLanguageForLocales>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Details about how the app is listed on app store catalogs.
     * @interface
     */
    interface CatalogInfo {
        'type': v1.skill.Manifest.CatalogType;
        /**
         * Identifier when accessing app in store.
         */
        'identifier': string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @enum
     */
    type CatalogName = 'IOS_APP_STORE' | 'GOOGLE_PLAY_STORE';
}
export declare namespace v1.skill.Manifest {
    /**
     * Supported catalog
     * @enum
     */
    type CatalogType = 'IOS_APP_STORE' | 'GOOGLE_PLAY_STORE';
}
export declare namespace v1.skill.Manifest {
    /**
     * Payload of the connection.
     * @interface
     */
    interface ConnectionsPayload {
        /**
         * Type of the payload.
         */
        'type': string;
        /**
         * Version of the payload.
         */
        'version': string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Currency to use for paid skill product.
     * @enum
     */
    type Currency = 'USD';
}
export declare namespace v1.skill.Manifest.Custom {
    /**
     * Skill connection object.
     * @interface
     */
    interface Connection {
        /**
         * Name of the connection.
         */
        'name': string;
        'payload': v1.skill.Manifest.ConnectionsPayload;
    }
}
export declare namespace v1.skill.Manifest.Custom {
    /**
     *
     * @enum
     */
    type SuppressedInterface = 'AudioPlayer' | 'PlaybackController' | 'Display' | 'VideoPlayer' | 'GameEngine' | 'GadgetController' | 'CanHandleIntentRequest' | 'CanFulfillIntentRequest' | 'AlexaPresentationApl' | 'AlexaPresentationHtml' | 'AlexaDataStore' | 'PhotoCaptureController' | 'VideoCaptureController' | 'UploadController' | 'CustomInterface' | 'AlexaAugmentationEffectsController';
}
export declare namespace v1.skill.Manifest.Custom {
    /**
     * Discriminator for target runtime objects.
     * @interface
     */
    type TargetRuntime = v1.skill.Manifest.Custom.TargetRuntimeDevice;
}
export declare namespace v1.skill.Manifest.Custom {
    /**
     *
     * @enum
     */
    type TargetRuntimeType = 'DEVICE';
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for custom api of the skill.
     * @interface
     */
    interface CustomApis {
        /**
         * Defines the set of target runtimes for this skill.
         */
        '_targetRuntimes'?: Array<v1.skill.Manifest.Custom.TargetRuntime>;
        /**
         * Object that contains <locale> Objects for each supported locale.
         */
        'locales'?: {
            [key: string]: v1.skill.Manifest.CustomLocalizedInformation;
        };
        /**
         * Contains an array of the supported <region> Objects.
         */
        'regions'?: {
            [key: string]: v1.skill.Manifest.Region;
        };
        'endpoint'?: v1.skill.Manifest.SkillManifestEndpoint;
        /**
         * Defines the structure for interfaces supported by the custom api of the skill.
         */
        'interfaces'?: Array<v1.skill.Manifest.Interface>;
        /**
         * List of provided tasks.
         */
        'tasks'?: Array<v1.skill.Manifest.CustomTask>;
        'connections'?: v1.skill.Manifest.CustomConnections;
        'dialogManagement'?: v1.skill.Manifest.DialogManagement;
        'appLink'?: v1.skill.Manifest.AppLink;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Supported connections.
     * @interface
     */
    interface CustomConnections {
        /**
         * List of required connections.
         */
        'requires'?: Array<v1.skill.Manifest.Custom.Connection>;
        /**
         * List of provided connections.
         */
        'provides'?: Array<v1.skill.Manifest.Custom.Connection>;
    }
}
export declare namespace v1.skill.Manifest.CustomDialogManagement {
    /**
     * Specifies the initial dialog manager to field requests when a new skill session starts. If absent, this is assumed to be the default \"skill\" target
     * @interface
     */
    interface SessionStartDelegationStrategy {
        'target': string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the localized custom api information.
     * @interface
     */
    interface CustomLocalizedInformation {
        'dialogManagement'?: v1.skill.Manifest.CustomLocalizedInformationDialogManagement;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines locale-specific dialog-management configuration for a skill.
     * @interface
     */
    interface CustomLocalizedInformationDialogManagement {
        'sessionStartDelegationStrategy'?: v1.skill.Manifest.CustomDialogManagement.SessionStartDelegationStrategy;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Custom prompts used for paid skill product purchasing options. Supports Speech Synthesis Markup Language (SSML), which can be used to control pronunciation, intonation, timing, and emotion.
     * @interface
     */
    interface CustomProductPrompts {
        /**
         * Description of the paid skill product heard before customer is prompted for purchase.
         */
        'purchasePromptDescription': string;
        /**
         * Description of the paid skill product that displays when the paid skill is purchased.
         */
        'purchaseConfirmationDescription': string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the name and version of the task that the skill wants to handle.
     * @interface
     */
    interface CustomTask {
        /**
         * Name of the task.
         */
        'name': string;
        /**
         * Version of the task.
         */
        'version': string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Represents a DataStore package authored by skill developer. This contains a reference to the DataStore package and doesn't contain the entire package itself.
     * @interface
     */
    interface DataStorePackage {
        /**
         * The identifier for the DataStore package.
         */
        'id': string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for demand response api of the skill.
     * @interface
     */
    interface DemandResponseApis {
        /**
         * Contains an array of the supported <region> Objects.
         */
        'regions'?: {
            [key: string]: v1.skill.Manifest.LambdaRegion;
        };
        'endpoint'?: v1.skill.Manifest.LambdaEndpoint;
        /**
         * Defines the url for enrolling into a demand response program.
         */
        'enrollmentUrl'?: string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Specifies the initial dialog manager to field requests when a new skill session starts. If absent this is assumed to be the default \\\"skill\\\" target.
     * @interface
     */
    interface DialogDelegationStrategy {
        'target': string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the dialog management configuration for the skill.
     * @interface
     */
    interface DialogManagement {
        /**
         * List of dialog managers configured by the skill
         */
        'dialogManagers': Array<v1.skill.Manifest.DialogManager>;
        'sessionStartDelegationStrategy'?: v1.skill.Manifest.DialogDelegationStrategy;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Individual dialog manager defined for the skill.
     * @interface
     */
    type DialogManager = v1.skill.Manifest.AMAZONConversationsDialogManager;
}
export declare namespace v1.skill.Manifest {
    /**
     * The minimum version of the APML specification supported by the skill. If a device does not support a version greater than or equal to the version specified her then apmlVersion will not be passed inside the Display interface in the ASK request.
     * @enum
     */
    type DisplayInterfaceApmlVersion = '0.2';
}
export declare namespace v1.skill.Manifest {
    /**
     * The minimum version of pre-defined templates supported by the skill. If a device does not support a version greater than or equal to the version specified her then templateVersion will not be passed inside the Display interface in the ASK request.
     * @enum
     */
    type DisplayInterfaceTemplateVersion = '1';
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @enum
     */
    type DistributionCountries = 'AF' | 'AX' | 'AL' | 'DZ' | 'AS' | 'AD' | 'AO' | 'AI' | 'AQ' | 'AG' | 'AR' | 'AM' | 'AW' | 'AU' | 'AT' | 'AZ' | 'BS' | 'BH' | 'BD' | 'BB' | 'BY' | 'BE' | 'BZ' | 'BJ' | 'BM' | 'BT' | 'BO' | 'BA' | 'BW' | 'BV' | 'BR' | 'IO' | 'BN' | 'BG' | 'BF' | 'BI' | 'KH' | 'CM' | 'CA' | 'CV' | 'KY' | 'CF' | 'TD' | 'CL' | 'CN' | 'CX' | 'CC' | 'CO' | 'KM' | 'CG' | 'CD' | 'CK' | 'CR' | 'HR' | 'CY' | 'CZ' | 'DK' | 'DJ' | 'DM' | 'DO' | 'EC' | 'EG' | 'SV' | 'GQ' | 'ER' | 'EE' | 'ET' | 'FK' | 'FO' | 'FJ' | 'FI' | 'FR' | 'GF' | 'PF' | 'TF' | 'GA' | 'GM' | 'GE' | 'DE' | 'GH' | 'GI' | 'GR' | 'GL' | 'GD' | 'GP' | 'GU' | 'GT' | 'GG' | 'GN' | 'GW' | 'GY' | 'HT' | 'HM' | 'VA' | 'HN' | 'HK' | 'HU' | 'IS' | 'IN' | 'ID' | 'IQ' | 'IE' | 'IM' | 'IL' | 'IT' | 'CI' | 'JM' | 'JP' | 'JE' | 'JO' | 'KZ' | 'KE' | 'KI' | 'KR' | 'KW' | 'KG' | 'LA' | 'LV' | 'LB' | 'LS' | 'LR' | 'LY' | 'LI' | 'LT' | 'LU' | 'MO' | 'MK' | 'MG' | 'MW' | 'MY' | 'MV' | 'ML' | 'MT' | 'MH' | 'MQ' | 'MR' | 'MU' | 'YT' | 'MX' | 'FM' | 'MD' | 'MC' | 'MN' | 'ME' | 'MS' | 'MA' | 'MZ' | 'MM' | 'NA' | 'NR' | 'NP' | 'NL' | 'AN' | 'NC' | 'NZ' | 'NI' | 'NE' | 'NG' | 'NU' | 'NF' | 'MP' | 'NO' | 'OM' | 'PK' | 'PW' | 'PS' | 'PA' | 'PG' | 'PY' | 'PE' | 'PH' | 'PN' | 'PL' | 'PT' | 'PR' | 'QA' | 'RE' | 'RO' | 'RU' | 'RW' | 'BL' | 'SH' | 'KN' | 'LC' | 'MF' | 'PM' | 'VC' | 'WS' | 'SM' | 'ST' | 'SA' | 'SN' | 'RS' | 'SC' | 'SL' | 'SG' | 'SK' | 'SI' | 'SB' | 'SO' | 'ZA' | 'GS' | 'ES' | 'LK' | 'SR' | 'SJ' | 'SZ' | 'SE' | 'CH' | 'TW' | 'TJ' | 'TZ' | 'TH' | 'TL' | 'TG' | 'TK' | 'TO' | 'TT' | 'TN' | 'TR' | 'TM' | 'TC' | 'TV' | 'UG' | 'UA' | 'AE' | 'GB' | 'US' | 'UM' | 'UY' | 'UZ' | 'VU' | 'VE' | 'VN' | 'VG' | 'VI' | 'WF' | 'EH' | 'YE' | 'ZM' | 'ZW';
}
export declare namespace v1.skill.Manifest {
    /**
     * What audience the skill should be distributed to. \"PUBLIC\" - available to all users. Has ASIN and can be enabled. \"PRIVATE\" - available to entitled users. Has ASIN and can be enabled. \"INTERNAL\" - has no ASIN and cannot be enabled by users. Internally managed skills.
     * @enum
     */
    type DistributionMode = 'PRIVATE' | 'PUBLIC';
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface EventName {
        'eventName'?: v1.skill.Manifest.EventNameType;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Name of the event to be subscribed to.
     * @enum
     */
    type EventNameType = 'Legacy.AudioPlayerGui.LyricsViewedEvent' | 'Legacy.ListModel.DeleteItemRequest' | 'Legacy.MediaPlayer.SequenceModified' | 'Legacy.PlaybackController.ButtonCommand' | 'EffectsController.RequestEffectChangeRequest' | 'Legacy.ExternalMediaPlayer.RequestToken' | 'ITEMS_UPDATED' | 'Alexa.Video.Xray.ShowDetailsSuccessful' | 'PlaybackController.NextCommandIssued' | 'Legacy.MediaPlayer.PlaybackFinished' | 'Alexa.Camera.VideoCaptureController.CaptureFailed' | 'SKILL_DISABLED' | 'Alexa.Camera.VideoCaptureController.CancelCaptureFailed' | 'CustomInterfaceController.EventsReceived' | 'Legacy.DeviceNotification.NotificationStarted' | 'REMINDER_UPDATED' | 'AUDIO_ITEM_PLAYBACK_STOPPED' | 'Legacy.AuxController.InputActivityStateChanged' | 'LocalApplication.MShopPurchasing.Event' | 'Legacy.ExternalMediaPlayer.AuthorizationComplete' | 'LocalApplication.HHOPhotos.Event' | 'Alexa.Presentation.APL.UserEvent' | 'Legacy.AudioPlayer.PlaybackInterrupted' | 'Legacy.BluetoothNetwork.DeviceUnpairFailure' | 'IN_SKILL_PRODUCT_SUBSCRIPTION_ENDED' | 'Alexa.FileManager.UploadController.UploadFailed' | 'Legacy.BluetoothNetwork.DeviceConnectedFailure' | 'Legacy.AudioPlayer.AudioStutter' | 'Alexa.Camera.VideoCaptureController.CaptureStarted' | 'Legacy.Speaker.MuteChanged' | 'CardRenderer.DisplayContentFinished' | 'Legacy.SpeechSynthesizer.SpeechStarted' | 'AudioPlayer.PlaybackStopped' | 'Legacy.SoftwareUpdate.CheckSoftwareUpdateReport' | 'CardRenderer.DisplayContentStarted' | 'LocalApplication.NotificationsApp.Event' | 'AudioPlayer.PlaybackStarted' | 'Legacy.DeviceNotification.NotificationEnteredForground' | 'Legacy.DeviceNotification.SetNotificationFailed' | 'Legacy.AudioPlayer.PeriodicPlaybackProgressReport' | 'Legacy.HomeAutoWifiController.HttpNotified' | 'Alexa.Camera.PhotoCaptureController.CancelCaptureFailed' | 'SKILL_ACCOUNT_LINKED' | 'LIST_UPDATED' | 'Legacy.DeviceNotification.NotificationSync' | 'Legacy.SconeRemoteControl.VolumeDown' | 'Legacy.MediaPlayer.PlaybackPaused' | 'Legacy.Presentation.PresentationUserEvent' | 'PlaybackController.PlayCommandIssued' | 'Legacy.ListModel.UpdateItemRequest' | 'Messaging.MessageReceived' | 'Legacy.SoftwareUpdate.InitiateSoftwareUpdateReport' | 'AUDIO_ITEM_PLAYBACK_FAILED' | 'LocalApplication.DeviceMessaging.Event' | 'Alexa.Camera.PhotoCaptureController.CaptureFailed' | 'Legacy.AudioPlayer.PlaybackIdle' | 'Legacy.BluetoothNetwork.EnterPairingModeSuccess' | 'Legacy.AudioPlayer.PlaybackError' | 'Legacy.ListModel.GetPageByOrdinalRequest' | 'Legacy.MediaGrouping.GroupChangeResponseEvent' | 'Legacy.BluetoothNetwork.DeviceDisconnectedFailure' | 'Legacy.BluetoothNetwork.EnterPairingModeFailure' | 'Legacy.SpeechSynthesizer.SpeechInterrupted' | 'PlaybackController.PreviousCommandIssued' | 'Legacy.AudioPlayer.PlaybackFinished' | 'Legacy.System.UserInactivity' | 'Display.UserEvent' | 'Legacy.PhoneCallController.Event' | 'Legacy.DeviceNotification.SetNotificationSucceeded' | 'LocalApplication.Photos.Event' | 'LocalApplication.VideoExperienceService.Event' | 'Legacy.ContentManager.ContentPlaybackTerminated' | 'Legacy.PlaybackController.PlayCommand' | 'Legacy.PlaylistController.ErrorResponse' | 'Legacy.SconeRemoteControl.VolumeUp' | 'MessagingController.UpdateConversationsStatus' | 'Legacy.BluetoothNetwork.DeviceDisconnectedSuccess' | 'LocalApplication.Communications.Event' | 'AUDIO_ITEM_PLAYBACK_STARTED' | 'Legacy.BluetoothNetwork.DevicePairFailure' | 'LIST_DELETED' | 'Legacy.PlaybackController.ToggleCommand' | 'Legacy.BluetoothNetwork.DevicePairSuccess' | 'Legacy.MediaPlayer.PlaybackError' | 'AudioPlayer.PlaybackFinished' | 'Legacy.DeviceNotification.NotificationStopped' | 'Legacy.SipClient.Event' | 'Display.ElementSelected' | 'LocalApplication.MShop.Event' | 'Legacy.ListModel.AddItemRequest' | 'Legacy.BluetoothNetwork.ScanDevicesReport' | 'Legacy.MediaPlayer.PlaybackStopped' | 'Legacy.AudioPlayerGui.ButtonClickedEvent' | 'LocalApplication.AlexaVoiceLayer.Event' | 'Legacy.PlaybackController.PreviousCommand' | 'Legacy.AudioPlayer.InitialPlaybackProgressReport' | 'Legacy.BluetoothNetwork.DeviceConnectedSuccess' | 'LIST_CREATED' | 'Legacy.ActivityManager.ActivityContextRemovedEvent' | 'ALL_LISTS_CHANGED' | 'Legacy.AudioPlayer.PlaybackNearlyFinished' | 'Legacy.MediaGrouping.GroupChangeNotificationEvent' | 'LocalApplication.Sentry.Event' | 'SKILL_PROACTIVE_SUBSCRIPTION_CHANGED' | 'SKILL_NOTIFICATION_SUBSCRIPTION_CHANGED' | 'REMINDER_CREATED' | 'Alexa.Presentation.HTML.Event' | 'FitnessSessionController.FitnessSessionError' | 'Legacy.SconeRemoteControl.Next' | 'Alexa.Camera.VideoCaptureController.CaptureFinished' | 'Legacy.MediaPlayer.SequenceItemsRequested' | 'Legacy.PlaybackController.PauseCommand' | 'LocalApplication.AlexaVision.Event' | 'LocalApplication.Closet.Event' | 'Alexa.FileManager.UploadController.CancelUploadFailed' | 'Legacy.MediaPlayer.PlaybackResumed' | 'SKILL_PERMISSION_ACCEPTED' | 'FitnessSessionController.FitnessSessionPaused' | 'Legacy.AudioPlayer.PlaybackPaused' | 'Alexa.Presentation.HTML.LifecycleStateChanged' | 'LocalApplication.SipUserAgent.Event' | 'Legacy.MediaPlayer.PlaybackStarted' | 'REMINDER_STATUS_CHANGED' | 'MessagingController.UploadConversations' | 'ITEMS_DELETED' | 'Legacy.AuxController.PluggedStateChanged' | 'Legacy.AudioPlayer.PlaybackStarted' | 'Alexa.FileManager.UploadController.UploadStarted' | 'ITEMS_CREATED' | 'Legacy.ExternalMediaPlayer.Event' | 'LocalApplication.LocalMediaPlayer.Event' | 'LocalApplication.KnightContacts.Event' | 'LocalApplication.Calendar.Event' | 'Legacy.AlertsController.DismissCommand' | 'Legacy.AudioPlayer.PlaybackStutterFinished' | 'Legacy.SpeechSynthesizer.SpeechFinished' | 'Legacy.ExternalMediaPlayer.ReportDiscoveredPlayers' | 'LocalApplication.SipClient.Event' | 'Legacy.BluetoothNetwork.DeviceUnpairSuccess' | 'Legacy.Speaker.VolumeChanged' | 'CardRenderer.ReadContentFinished' | 'LocalApplication.HomeAutomationMedia.Event' | 'Legacy.BluetoothNetwork.CancelPairingMode' | 'LocalApplication.DigitalDash.Event' | 'CardRenderer.ReadContentStarted' | 'Legacy.GameEngine.GameInputEvent' | 'LocalApplication.LocalVoiceUI.Event' | 'Legacy.Microphone.AudioRecording' | 'LocalApplication.AlexaPlatformTestSpeechlet.Event' | 'Legacy.HomeAutoWifiController.SsdpServiceDiscovered' | 'Alexa.Camera.PhotoCaptureController.CancelCaptureFinished' | 'Legacy.HomeAutoWifiController.DeviceReconnected' | 'SKILL_ENABLED' | 'Alexa.Camera.VideoCaptureController.CancelCaptureFinished' | 'MessagingController.UpdateMessagesStatusRequest' | 'REMINDER_STARTED' | 'CustomInterfaceController.Expired' | 'LocalApplication.AvaPhysicalShopping.Event' | 'LocalApplication.WebVideoPlayer.Event' | 'Legacy.HomeAutoWifiController.SsdpServiceTerminated' | 'LocalApplication.FireflyShopping.Event' | 'Legacy.PlaybackController.NextCommand' | 'LocalApplication.Gallery.Event' | 'Alexa.Presentation.PresentationDismissed' | 'EffectsController.StateReceiptChangeRequest' | 'LocalApplication.Alexa.Translation.LiveTranslation.Event' | 'LocalApplication.AlexaNotifications.Event' | 'REMINDER_DELETED' | 'GameEngine.InputHandlerEvent' | 'Legacy.PlaylistController.Response' | 'LocalApplication.KnightHome.Event' | 'Legacy.ListRenderer.ListItemEvent' | 'AudioPlayer.PlaybackFailed' | 'LocalApplication.KnightHomeThingsToTry.Event' | 'Legacy.BluetoothNetwork.SetDeviceCategoriesFailed' | 'Legacy.ExternalMediaPlayer.Logout' | 'Alexa.FileManager.UploadController.UploadFinished' | 'Legacy.ActivityManager.FocusChanged' | 'Legacy.AlertsController.SnoozeCommand' | 'Legacy.SpeechRecognizer.WakeWordChanged' | 'Legacy.ListRenderer.GetListPageByToken' | 'MessagingController.UpdateSendMessageStatusRequest' | 'FitnessSessionController.FitnessSessionEnded' | 'Alexa.Presentation.APL.RuntimeError' | 'Legacy.ListRenderer.GetListPageByOrdinal' | 'FitnessSessionController.FitnessSessionResumed' | 'IN_SKILL_PRODUCT_SUBSCRIPTION_STARTED' | 'Legacy.DeviceNotification.DeleteNotificationSucceeded' | 'Legacy.SpeechSynthesizer.SpeechSynthesizerError' | 'Alexa.Video.Xray.ShowDetailsFailed' | 'Alexa.FileManager.UploadController.CancelUploadFinished' | 'Legacy.SconeRemoteControl.PlayPause' | 'Legacy.DeviceNotification.NotificationEnteredBackground' | 'SKILL_PERMISSION_CHANGED' | 'Legacy.AudioPlayer.Metadata' | 'Legacy.AudioPlayer.PlaybackStutterStarted' | 'AUDIO_ITEM_PLAYBACK_FINISHED' | 'EffectsController.RequestGuiChangeRequest' | 'FitnessSessionController.FitnessSessionStarted' | 'Legacy.PlaybackController.LyricsViewedEvent' | 'Legacy.ExternalMediaPlayer.Login' | 'PlaybackController.PauseCommandIssued' | 'Legacy.MediaPlayer.PlaybackIdle' | 'Legacy.SconeRemoteControl.Previous' | 'DeviceSetup.SetupCompleted' | 'Legacy.MediaPlayer.PlaybackNearlyFinished' | 'LocalApplication.todoRenderer.Event' | 'Legacy.BluetoothNetwork.SetDeviceCategoriesSucceeded' | 'Legacy.BluetoothNetwork.MediaControlSuccess' | 'Legacy.HomeAutoWifiController.SsdpDiscoveryFinished' | 'Alexa.Presentation.APL.LoadIndexListData' | 'IN_SKILL_PRODUCT_SUBSCRIPTION_RENEWED' | 'Legacy.BluetoothNetwork.MediaControlFailure' | 'Legacy.AuxController.EnabledStateChanged' | 'Legacy.FavoritesController.Response' | 'Legacy.ListModel.ListStateUpdateRequest' | 'Legacy.EqualizerController.EqualizerChanged' | 'Legacy.MediaGrouping.GroupSyncEvent' | 'Legacy.FavoritesController.Error' | 'Legacy.ListModel.GetPageByTokenRequest' | 'Legacy.ActivityManager.ActivityInterrupted' | 'Legacy.MeetingClientController.Event' | 'Legacy.Presentation.PresentationDismissedEvent' | 'Legacy.Spotify.Event' | 'Legacy.ExternalMediaPlayer.Error' | 'Legacy.AuxController.DirectionChanged' | 'AudioPlayer.PlaybackNearlyFinished' | 'Alexa.Camera.PhotoCaptureController.CaptureFinished' | 'Legacy.UDPController.BroadcastResponse' | 'Legacy.AudioPlayer.PlaybackResumed' | 'Legacy.DeviceNotification.DeleteNotificationFailed';
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface EventPublications {
        /**
         * Name of the event to publish.
         */
        'eventName'?: string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Represents a request to automatically initialize an extension by a runtime.
     * @interface
     */
    interface ExtensionInitializationRequest {
        /**
         * The extension's URI.
         */
        'uri': string;
        /**
         * Default initialization extension settings.
         */
        'settings'?: any;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Represents a request for a runtime extension. Extensions are optional enhancements to a runtime that provide additional sources of data, commands, and event handlers.
     * @interface
     */
    interface ExtensionRequest {
        /**
         * The extension's URI.
         */
        'uri': string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure of flash briefing api in the skill manifest.
     * @interface
     */
    interface FlashBriefingApis {
        /**
         * Object that contains <locale> objects for each supported locale.
         */
        'locales': {
            [key: string]: v1.skill.Manifest.LocalizedFlashBriefingInfo;
        };
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Format of the feed content.
     * @enum
     */
    type FlashBriefingContentType = 'TEXT' | 'AUDIO';
}
export declare namespace v1.skill.Manifest {
    /**
     * Type or subject of the content in the feed.
     * @enum
     */
    type FlashBriefingGenre = 'HEADLINE_NEWS' | 'BUSINESS' | 'POLITICS' | 'ENTERTAINMENT' | 'TECHNOLOGY' | 'HUMOR' | 'LIFESTYLE' | 'SPORTS' | 'SCIENCE' | 'HEALTH_AND_FITNESS' | 'ARTS_AND_CULTURE' | 'PRODUCTIVITY_AND_UTILITIES' | 'OTHER';
}
export declare namespace v1.skill.Manifest {
    /**
     * Tells how often the feed has new content.
     * @enum
     */
    type FlashBriefingUpdateFrequency = 'HOURLY' | 'DAILY' | 'WEEKLY';
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for paid skill product free trial information.
     * @interface
     */
    interface FreeTrialInformation {
        /**
         * Defines the free trial period for the paid skill product, in ISO_8601#Durations format.
         */
        'freeTrialDuration': string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Localized App name
     * @interface
     */
    interface FriendlyName {
        /**
         * Default app name
         */
        'default': string;
        /**
         * Localized app names.
         */
        'localizedNames'?: Array<v1.skill.Manifest.LocalizedName>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Specifies if gadget support is required/optional for this skill to work.
     * @enum
     */
    type GadgetSupportRequirement = 'REQUIRED' | 'OPTIONAL';
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface HealthInterface {
        /**
         * Name of the interface.
         */
        'namespace': string;
        /**
         * defines the version of skill interface.
         */
        'version'?: string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure of household list api in the skill manifest.
     * @interface
     */
    interface HouseHoldList {
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * supported common schemes for IOS_APP_STORE. MAPS is for \"maps:\" and TEL is for \"tel:\".
     * @enum
     */
    type IOSAppStoreCommonSchemeName = 'MAPS' | 'TEL';
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    type Interface = v1.skill.Manifest.AlexaSearch | v1.skill.Manifest.AlexaPresentationAplInterface | v1.skill.Manifest.AppLinkInterface | v1.skill.Manifest.AlexaPresentationHtmlInterface | v1.skill.Manifest.AudioInterface | v1.skill.Manifest.GameEngineInterface | v1.skill.Manifest.AppLinkV2Interface | v1.skill.Manifest.AlexaDataStorePackageManagerInterface | v1.skill.Manifest.DisplayInterface | v1.skill.Manifest.GadgetControllerInterface | v1.skill.Manifest.VideoAppInterface;
}
export declare namespace v1.skill.Manifest {
    /**
     * Name of the interface.
     * @enum
     */
    type InterfaceType = 'AUDIO_PLAYER' | 'VIDEO_APP' | 'RENDER_TEMPLATE' | 'GAME_ENGINE' | 'GADGET_CONTROLLER' | 'CAN_FULFILL_INTENT_REQUEST' | 'ALEXA_PRESENTATION_APL' | 'ALEXA_CAMERA_PHOTO_CAPTURE_CONTROLLER' | 'ALEXA_CAMERA_VIDEO_CAPTURE_CONTROLLER' | 'ALEXA_FILE_MANAGER_UPLOAD_CONTROLLER' | 'CUSTOM_INTERFACE' | 'ALEXA_AUGMENTATION_EFFECTS_CONTROLLER' | 'APP_LINKS' | 'ALEXA_EXTENSION' | 'APP_LINKS_V2' | 'ALEXA_SEARCH' | 'ALEXA_DATASTORE_PACKAGEMANAGER' | 'ALEXA_DATA_STORE';
}
export declare namespace v1.skill.Manifest {
    /**
     * defines the structure for the knowledge api of the skill.
     * @interface
     */
    interface KnowledgeApis {
        'enablementChannel'?: v1.skill.Manifest.KnowledgeApisEnablementChannel;
        /**
         * Defines the structure of locale specific knowledge information in the skill manifest.
         */
        'locales'?: {
            [key: string]: v1.skill.Manifest.LocalizedKnowledgeInformation;
        };
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines how the skill can be enabled by developers. values can be set to 'PUBLIC' (in Alexa Skill Store), 'ASP' (A4R/A4H vendor devices), or 'A4B' Public and ASP selections must have \"distributionMode\" = 'PUBLIC' and will only be eligible for distribution on personal or vendor (A4H/A4R or A4B) devices.
     * @enum
     */
    type KnowledgeApisEnablementChannel = 'PUBLIC' | 'ASP' | 'A4B';
}
export declare namespace v1.skill.Manifest {
    /**
     * Contains the uri field. This sets the global default endpoint.
     * @interface
     */
    interface LambdaEndpoint {
        /**
         * Amazon Resource Name (ARN) of the Lambda function.
         */
        'uri': string;
        'sslCertificateType'?: v1.skill.Manifest.LambdaSSLCertificateType;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure of a regional information.
     * @interface
     */
    interface LambdaRegion {
        'endpoint': v1.skill.Manifest.LambdaEndpoint;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * The SSL certificate type of the skill's HTTPS endpoint. Only valid for HTTPS endpoint not for AWS Lambda ARN.
     * @enum
     */
    type LambdaSSLCertificateType = 'SelfSigned' | 'Wildcard' | 'Trusted';
}
export declare namespace v1.skill.Manifest {
    /**
     * Android common intents associated with the skill
     * @interface
     */
    interface LinkedAndroidCommonIntent {
        'intentName': v1.skill.Manifest.AndroidCommonIntentName;
        'catalogType': v1.skill.Manifest.CatalogName;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Applications associated with the skill.
     * @interface
     */
    interface LinkedApplication {
        'catalogInfo': v1.skill.Manifest.CatalogInfo;
        /**
         * Supported schemes
         */
        'customSchemes'?: Array<string>;
        /**
         * Supported domains
         */
        'domains'?: Array<string>;
        'friendlyName': v1.skill.Manifest.FriendlyName;
        /**
         * Supported android custom intent
         */
        'androidCustomIntents'?: Array<v1.skill.Manifest.AndroidCustomIntent>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Allow developer to declare their skill to link to the speicified common schemes
     * @interface
     */
    interface LinkedCommonSchemes {
        'IOS_APP_STORE'?: Array<v1.skill.Manifest.IOSAppStoreCommonSchemeName>;
        'GOOGLE_PLAY_STORE'?: Array<v1.skill.Manifest.PlayStoreCommonSchemeName>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * maps source locale to list of target locales. Source and target locales should be with the same language.
     * @interface
     */
    interface LocalesByAutomaticClonedLocale {
        /**
         * Locale where the metadata and model will be copied from. For example: en-US. This locale must already exist in the skill.
         */
        'source': string;
        /**
         * Optional. List of locales where the metadata and model will be copied to. All configuration of source locale will be copied, so target locales do not have to exist before. Defaults to all locales with the same language as the sourceLocale.
         */
        'targets'?: Array<string>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure of a localized flash briefing information.
     * @interface
     */
    interface LocalizedFlashBriefingInfo {
        /**
         * Defines the structure for a feed information in the skill manifest.
         */
        'feeds'?: Array<v1.skill.Manifest.LocalizedFlashBriefingInfoItems>;
        /**
         * Alexa says this to the customer if the skill fails to render the content.
         */
        'customErrorMessage'?: string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface LocalizedFlashBriefingInfoItems {
        /**
         * Logical name of the feed. This is used to signify relation among feeds across different locales. Example If you have \"weather\" feed in multiple locale then consider naming it \"weather_update\" and we will make sure to play the right feed if customer changes the language on device.
         */
        'logicalName'?: string;
        /**
         * Name that identifies this feed.
         */
        'name'?: string;
        /**
         * Url for the feed
         */
        'url': string;
        /**
         * Uri for the feed image
         */
        'imageUri'?: string;
        'contentType': v1.skill.Manifest.FlashBriefingContentType;
        'genre': v1.skill.Manifest.FlashBriefingGenre;
        'updateFrequency': v1.skill.Manifest.FlashBriefingUpdateFrequency;
        /**
         * A short introduction for the feed that Alexa reads to the customer before the feed contents. Should start with \"In\" or \"From\".
         */
        'vuiPreamble'?: string;
        /**
         * True if this should be the default feed to be enabled when customer enables the skill false otherwise.
         */
        'isDefault': boolean;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure of localized knowledge information in the skill manifest.
     * @interface
     */
    interface LocalizedKnowledgeInformation {
        /**
         * enables skill developers to prepend a custom message to all of their knowledge skill's answers, which can help inform end-users of the skill and data source answering their question.
         */
        'answerAttribution'?: string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure of localized music information in the skill manifest.
     * @interface
     */
    interface LocalizedMusicInfo {
        /**
         * Name to be used when Alexa renders the music skill name.
         */
        'promptName'?: string;
        /**
         * Defines the structure of the music prompt name information in the skill manifest.
         */
        'aliases'?: Array<v1.skill.Manifest.MusicAlias>;
        'features'?: Array<v1.skill.Manifest.MusicFeature>;
        'wordmarkLogos'?: Array<v1.skill.Manifest.MusicWordmark>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Localized app name
     * @interface
     */
    interface LocalizedName {
        /**
         * locale
         */
        'locale': string;
        /**
         * app name
         */
        'name': string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for gadget buttons support in the skill manifest.
     * @interface
     */
    interface ManifestGadgetSupport {
        'requirement': v1.skill.Manifest.GadgetSupportRequirement;
        /**
         * Minimum number of gadget buttons required.
         */
        'minGadgetButtons'?: number;
        /**
         * Maximum number of gadget buttons required.
         */
        'maxGadgetButtons'?: number;
        /**
         * Maximum number of players in the game.
         */
        'numPlayersMax'?: number;
        /**
         * Minimum number of players in the game.
         */
        'numPlayersMin'?: number;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Version of the skill manifest.
     * @enum
     */
    type ManifestVersion = '1.0';
}
export declare namespace v1.skill.Manifest {
    /**
     * Paid skill product pricing information.
     * @interface
     */
    interface MarketplacePricing {
        'offerType': v1.skill.Manifest.OfferType;
        /**
         * Defines the price of a paid skill product. The price should be your suggested price, not including any VAT or similar taxes. Taxes are included in the final price to end users.
         */
        'price': number;
        'currency': v1.skill.Manifest.Currency;
        'freeTrialInformation'?: v1.skill.Manifest.FreeTrialInformation;
        'subscriptionInformation'?: v1.skill.Manifest.SubscriptionInformation;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface MusicAlias {
        /**
         * Alias name to be associated with the music skill.
         */
        'name'?: string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure of music api in the skill manifest.
     * @interface
     */
    interface MusicApis {
        /**
         * Contains an array of the supported <region> Objects.
         */
        'regions'?: {
            [key: string]: v1.skill.Manifest.LambdaRegion;
        };
        'endpoint'?: v1.skill.Manifest.LambdaEndpoint;
        /**
         * Defines the structure of music capabilities information in the skill manifest.
         */
        'capabilities'?: Array<v1.skill.Manifest.MusicCapability>;
        /**
         * A list of music skill interfaces that your skill supports.
         */
        'interfaces'?: Array<v1.skill.Manifest.MusicInterfaces>;
        /**
         * Defines the structure of locale specific music information in the skill manifest.
         */
        'locales'?: {
            [key: string]: v1.skill.Manifest.LocalizedMusicInfo;
        };
        /**
         * List of the type of content to be provided by the music skill.
         */
        'contentTypes'?: Array<v1.skill.Manifest.MusicContentType>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface MusicCapability {
        /**
         * Namespace of music skill api.
         */
        'namespace'?: string;
        /**
         * Name of music skill api.
         */
        'name'?: string;
        /**
         * Version of music skill api.
         */
        'version'?: string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Name of the content type that's supported for the music skill.
     * @enum
     */
    type MusicContentName = 'ON_DEMAND' | 'RADIO' | 'PODCAST';
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for content that can be provided by a music skill.
     * @interface
     */
    interface MusicContentType {
        'name'?: v1.skill.Manifest.MusicContentName;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface MusicFeature {
        /**
         * Feature name to be associated with the music skill.
         */
        'name'?: string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface MusicInterfaces {
        /**
         * Name of the interface.
         */
        'namespace': string;
        /**
         * Version of the interface.
         */
        'version'?: string;
        /**
         * Contains a list of requests/messages that skill can handle.
         */
        'requests'?: Array<v1.skill.Manifest.MusicRequest>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface MusicRequest {
        /**
         * Name of the request.
         */
        'name'?: string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface MusicWordmark {
        /**
         * Wordmark logo to be used by devices with displays.
         */
        'uri'?: string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * The type of the offer.
     * @enum
     */
    type OfferType = 'SUBSCRIPTION' | 'ENTITLEMENT';
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure of the paid skill information of the skill.
     * @interface
     */
    interface PaidSkillInformation {
        /**
         * Defines the structure for marketplace specific pricing information in the skill manifest
         */
        'pricing': {
            [key: string]: Array<v1.skill.Manifest.MarketplacePricing>;
        };
        'taxInformation': v1.skill.Manifest.TaxInformation;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface PermissionItems {
        'name': v1.skill.Manifest.PermissionName;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Name of the required permission.
     * @enum
     */
    type PermissionName = 'alexa::device_id:read' | 'alexa::personality:explicit:read' | 'alexa::authenticate:2:mandatory' | 'alexa:devices:all:address:country_and_postal_code:read' | 'alexa::profile:mobile_number:read' | 'alexa::async_event:write' | 'alexa::device_type:read' | 'alexa::skill:proactive_enablement' | 'alexa::personality:explicit:write' | 'alexa::household:lists:read' | 'alexa::utterance_id:read' | 'alexa::user_experience_guidance:read' | 'alexa::devices:all:notifications:write' | 'avs::distributed_audio' | 'alexa::devices:all:address:full:read' | 'alexa::devices:all:notifications:urgent:write' | 'payments:autopay_consent' | 'alexa::alerts:timers:skill:readwrite' | 'alexa::customer_id:read' | 'alexa::skill:cds:monetization' | 'alexa::music:cast' | 'alexa::profile:given_name:read' | 'alexa::alerts:reminders:skill:readwrite' | 'alexa::household:lists:write' | 'alexa::profile:email:read' | 'alexa::profile:name:read' | 'alexa::devices:all:geolocation:read' | 'alexa::raw_person_id:read' | 'alexa::authenticate:2:optional' | 'alexa::health:profile:write' | 'alexa::person_id:read' | 'alexa::skill:products:entitlements' | 'alexa::energy:devices:state:read' | 'alexa::origin_ip_address:read' | 'alexa::devices:all:coarse_location:read' | 'alexa::devices:all:tokenized_geolocation:read' | 'alexa::devices:all:intent_tokens:read' | 'alexa::measurement_system::readwrite' | 'dash::vendor:read:endpoints' | 'dash::read:endpoints:sensors';
}
export declare namespace v1.skill.Manifest {
    /**
     * supported common schemes for GOOGLE_PLAY_STORE. MAPS is for \"maps:\" and TEL is for \"tel:\".
     * @enum
     */
    type PlayStoreCommonSchemeName = 'MAPS' | 'TEL';
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for regional information.
     * @interface
     */
    interface Region {
        'endpoint': v1.skill.Manifest.SkillManifestEndpoint;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * The SSL certificate type of the skill's HTTPS endpoint. Only valid for HTTPS endpoint not for AWS Lambda ARN.
     * @enum
     */
    type SSLCertificateType = 'SelfSigned' | 'Wildcard' | 'Trusted';
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for Shopping Kit related information in the skill manifest.
     * @interface
     */
    interface ShoppingKit {
        /**
         * True if the skill uses Alexa Shopping Actions, false otherwise.
         */
        'isShoppingActionsEnabled'?: boolean;
        /**
         * True if the skill uses Shopping Actions with Amazon Associates, false otherwise.
         */
        'isAmazonAssociatesOnAlexaEnabled'?: boolean;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for a skill's metadata.
     * @interface
     */
    interface SkillManifest {
        'manifestVersion'?: v1.skill.Manifest.ManifestVersion;
        'publishingInformation'?: v1.skill.Manifest.SkillManifestPublishingInformation;
        'privacyAndCompliance'?: v1.skill.Manifest.SkillManifestPrivacyAndCompliance;
        'events'?: v1.skill.Manifest.SkillManifestEvents;
        /**
         * Defines the structure for required permissions information in the skill manifest.
         */
        'permissions'?: Array<v1.skill.Manifest.PermissionItems>;
        /**
         * Defines a list of clients authorized for a skill.
         */
        'authorizedClients'?: Array<v1.skill.Manifest.AuthorizedClient>;
        'apis'?: v1.skill.Manifest.SkillManifestApis;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for implemented apis information in the skill manifest.
     * @interface
     */
    interface SkillManifestApis {
        'flashBriefing'?: v1.skill.Manifest.FlashBriefingApis;
        'custom'?: v1.skill.Manifest.CustomApis;
        'knowledge'?: v1.skill.Manifest.KnowledgeApis;
        'smartHome'?: v1.skill.Manifest.SmartHomeApis;
        'video'?: v1.skill.Manifest.VideoApis;
        'alexaForBusiness'?: v1.skill.Manifest.AlexaForBusinessApis;
        'householdList'?: v1.skill.Manifest.HouseHoldList;
        'music'?: v1.skill.Manifest.MusicApis;
        'demandResponse'?: v1.skill.Manifest.DemandResponseApis;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for endpoint information in the skill manifest.
     * @interface
     */
    interface SkillManifestEndpoint {
        /**
         * Amazon Resource Name (ARN) of the skill's Lambda function or HTTPS URL.
         */
        'uri': string;
        'sslCertificateType'?: v1.skill.Manifest.SSLCertificateType;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface SkillManifestEnvelope {
        'manifest'?: v1.skill.Manifest.SkillManifest;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for subscribed events information in the skill manifest.
     * @interface
     */
    interface SkillManifestEvents {
        /**
         * Contains an array of eventName object each of which contains the name of a skill event.
         */
        'subscriptions'?: Array<v1.skill.Manifest.EventName>;
        'publications'?: Array<v1.skill.Manifest.EventPublications>;
        /**
         * Contains an array of the supported <region> Objects.
         */
        'regions'?: {
            [key: string]: v1.skill.Manifest.Region;
        };
        'endpoint': v1.skill.Manifest.SkillManifestEndpoint;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for locale specific privacy & compliance information in the skill manifest.
     * @interface
     */
    interface SkillManifestLocalizedPrivacyAndCompliance {
        /**
         * Link to the privacy policy that applies to this skill.
         */
        'privacyPolicyUrl'?: string;
        /**
         * link to the terms of use document for this skill
         */
        'termsOfUseUrl'?: string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for locale specific publishing information in the skill manifest.
     * @interface
     */
    interface SkillManifestLocalizedPublishingInformation {
        /**
         * Name of the skill that is displayed to customers in the Alexa app.
         */
        'name': string;
        /**
         * URL to a small icon for the skill, which is shown in the list of skills (108x108px).
         */
        'smallIconUri'?: string;
        /**
         * URL to a large icon that represents this skill (512x512px).
         */
        'largeIconUri'?: string;
        /**
         * Summary description of the skill, which is shown when viewing the list of skills.
         */
        'summary'?: string;
        /**
         * A full description explaining the skill’s core functionality and any prerequisites to using it (such as additional hardware, software, or accounts). For a Flash Briefing skill, you must list the feeds for the skill.
         */
        'description'?: string;
        /**
         * Updates description of the skill's new features and fixes in the version. Should describe changes in the revisions of the skill.
         */
        'updatesDescription'?: string;
        /**
         * Three example phrases that illustrate how users can invoke your skill. For accuracy, these phrases must come directly from your sample utterances.
         */
        'examplePhrases'?: Array<string>;
        /**
         * Sample keyword phrases that describe the skill.
         */
        'keywords'?: Array<string>;
        'customProductPrompts'?: v1.skill.Manifest.CustomProductPrompts;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for privacy & compliance information in the skill manifest.
     * @interface
     */
    interface SkillManifestPrivacyAndCompliance {
        /**
         * Object that contains <locale> objects for each supported locale.
         */
        'locales'?: {
            [key: string]: v1.skill.Manifest.SkillManifestLocalizedPrivacyAndCompliance;
        };
        /**
         * True if the skill allows users to make purchases or spend real money false otherwise.
         */
        'allowsPurchases'?: boolean;
        /**
         * True if the skill collects users' personal information false otherwise.
         */
        'usesPersonalInfo'?: boolean;
        /**
         * True if the skill is directed to or targets children under the age of 13/16 false otherwise.
         */
        'isChildDirected'?: boolean;
        /**
         * True if it is certified that the skill may be imported to and exported from the United States and all other countries and regions in which Amazon operate its program or in which skill owner have authorized sales to end users (without the need for Amazon to obtain any license or clearance or take any other action) and is in full compliance with all applicable laws and regulations governing imports and export including those applicable to software that makes use of encryption technology.
         */
        'isExportCompliant'?: boolean;
        /**
         * True if the skill contains advertising false otherwise.
         */
        'containsAds'?: boolean;
        /**
         * True if the skill developer is a Covered Entity (CE) or Business Associate (BA) as defined by the Health Insurance Portability And Accountability Act (HIPAA) and the skill requires Amazon to process PHI on their behalf, false otherwise. This is an optional property and treated as false if not set.
         */
        'usesHealthInfo'?: boolean;
        'shoppingKit'?: v1.skill.Manifest.ShoppingKit;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for publishing information in the skill manifest.
     * @interface
     */
    interface SkillManifestPublishingInformation {
        /**
         * Name of the skill that is displayed to customers in the Alexa app.
         */
        'name'?: string;
        /**
         * Description of the skill's purpose and feature and how it works. Should describe any prerequisites like hardware or account requirements and detailed steps for the customer to get started. For Flash Briefing skill list the feeds offered within the skill. Use a conversational tone and correct grammar and punctuation. This description displays to customers on the skill detail card in the Alexa app.
         */
        'description'?: string;
        /**
         * Defines the structure for locale specific publishing information in the skill manifest.
         */
        'locales'?: {
            [key: string]: v1.skill.Manifest.SkillManifestLocalizedPublishingInformation;
        };
        /**
         * True if the skill should be distributed in all countries where Amazon distributes skill false otherwise.
         */
        'isAvailableWorldwide'?: boolean;
        'distributionMode'?: v1.skill.Manifest.DistributionMode;
        'gadgetSupport'?: v1.skill.Manifest.ManifestGadgetSupport;
        /**
         * Special instructions provided by the developer to test the skill.
         */
        'testingInstructions'?: string;
        /**
         * Category that best describes a skill. Indicates the filter category for the skill in the Alexa App.
         */
        'category'?: string;
        /**
         * Selected list of countries provided by the skill owner where Amazon can distribute the skill.
         */
        'distributionCountries'?: Array<v1.skill.Manifest.DistributionCountries>;
        'automaticDistribution'?: v1.skill.Manifest.AutomaticDistribution;
        'automaticClonedLocale'?: v1.skill.Manifest.AutomaticClonedLocale;
        'paidSkillInformation'?: v1.skill.Manifest.PaidSkillInformation;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure of smart home api of the skill.
     * @interface
     */
    interface SmartHomeApis {
        /**
         * Contains an array of the supported <region> Objects.
         */
        'regions'?: {
            [key: string]: v1.skill.Manifest.LambdaRegion;
        };
        'endpoint'?: v1.skill.Manifest.LambdaEndpoint;
        'protocolVersion': v1.skill.Manifest.SmartHomeProtocol;
        'supportedControls'?: v1.skill.Manifest.SupportedControls;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Version of the Smart Home API. Default and recommended value is '3'. You may create a skill with version '2' for testing migration to version '3', but a skill submission using version '2' will not be certified.
     * @enum
     */
    type SmartHomeProtocol = '2' | '2.0' | '3' | '3.0';
}
export declare namespace v1.skill.Manifest {
    /**
     * maps a language to a locale. During Automatic Skill Distribution, skill metadata and model of the source locale will be copied to other eligible locales of the same language. Eligible destination locales will be determined by the system.
     * @interface
     */
    interface SourceLanguageForLocales {
        /**
         * two-letter string representing the language to distribute to. There must be at least one locale in publishingInformation.locales which has this language as the prefix.
         */
        'language': string;
        /**
         * locale where the metadata and model will be copied from. This locale must already exist in the skill.
         */
        'sourceLocale': string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for paid skill product subscription information.
     * @interface
     */
    interface SubscriptionInformation {
        'subscriptionPaymentFrequency': v1.skill.Manifest.SubscriptionPaymentFrequency;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * The frequency in which payments are collected for the subscription.
     * @enum
     */
    type SubscriptionPaymentFrequency = 'MONTHLY' | 'YEARLY';
}
export declare namespace v1.skill.Manifest {
    /**
     * (Optional) Contains the attributes specifying additional functionalities supported by the skill.
     * @interface
     */
    interface SupportedControls {
        'type'?: v1.skill.Manifest.SupportedControlsType;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Type of the supported functionality.
     * @enum
     */
    type SupportedControlsType = 'REMOTE_VEHICLE_CONTROL';
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for paid skill product tax information.
     * @interface
     */
    interface TaxInformation {
        'category': v1.skill.Manifest.TaxInformationCategory;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * The tax category that best describes the paid skill product.
     * @enum
     */
    type TaxInformationCategory = 'SOFTWARE' | 'STREAMING_AUDIO' | 'STREAMING_RADIO' | 'INFORMATION_SERVICES' | 'VIDEO' | 'PERIODICALS' | 'NEWSPAPERS';
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface UpChannelItems {
        /**
         * Use \\\"SNS\\\" for this field.
         */
        'type'?: string;
        /**
         * SNS Amazon Resource Name (ARN) for video skill through which video partner can send events to Alexa.
         */
        'uri'?: string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Version of the interface.
     * @enum
     */
    type Version = '1.0';
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for video api of the skill.
     * @interface
     */
    interface VideoApis {
        /**
         * Defines the structure for region information.
         */
        'regions'?: {
            [key: string]: v1.skill.Manifest.VideoRegion;
        };
        /**
         * Defines the structure for the locale specific video api information.
         */
        'locales'?: {
            [key: string]: v1.skill.Manifest.VideoApisLocale;
        };
        'endpoint'?: v1.skill.Manifest.LambdaEndpoint;
        /**
         * Object that contains <country> Objects for each supported country.
         */
        'countries'?: {
            [key: string]: v1.skill.Manifest.VideoCountryInfo;
        };
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for localized video api information.
     * @interface
     */
    interface VideoApisLocale {
        /**
         * Defines the video provider's targeting name.
         */
        'videoProviderTargetingNames': Array<string>;
        'videoProviderLogoUri'?: string;
        'fireTvCatalogIngestion'?: v1.skill.Manifest.VideoFireTvCatalogIngestion;
        /**
         * Defines the array of video features for this skill.
         */
        'features'?: Array<v1.skill.Manifest.VideoFeature>;
        /**
         * Name to use when Alexa renders the video skill name in a prompt to the user
         */
        'promptNames'?: Array<v1.skill.Manifest.VideoPromptName>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface VideoCatalogInfo {
        'sourceId': string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure of per-country video info in the skill manifest.
     * @interface
     */
    interface VideoCountryInfo {
        'catalogInformation'?: Array<v1.skill.Manifest.VideoCatalogInfo>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * A feature of an Alexa skill.
     * @interface
     */
    type VideoFeature = v1.skill.Manifest.VoiceProfileFeature;
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface VideoFireTvCatalogIngestion {
        'fireTvCatalogIngestionSourceId'?: string;
        'isFireTvCatalogIngestionEnabled'?: boolean;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface VideoPromptName {
        'type': v1.skill.Manifest.VideoPromptNameType;
        'name': string;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @enum
     */
    type VideoPromptNameType = 'Default';
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the structure for endpoint information.
     * @interface
     */
    interface VideoRegion {
        'endpoint': v1.skill.Manifest.SkillManifestEndpoint;
        /**
         * The channel through which the partner skill can communicate to Alexa.
         */
        'upchannel'?: Array<v1.skill.Manifest.UpChannelItems>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the mode of viewport that comply with this specification. E.g. HUB TV.
     * @enum
     */
    type ViewportMode = 'HUB' | 'TV' | 'MOBILE' | 'PC' | 'AUTO';
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines the shape of the device's viewport.
     * @enum
     */
    type ViewportShape = 'RECTANGLE' | 'ROUND';
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines a viewport specification.
     * @interface
     */
    interface ViewportSpecification {
        'mode': v1.skill.Manifest.ViewportMode;
        'shape': v1.skill.Manifest.ViewportShape;
        /**
         * Defines the minimum width of viewport that comply with this specification.
         */
        'minWidth'?: number;
        /**
         * Defines the maximum width of viewport that comply with this specification.
         */
        'maxWidth'?: number;
        /**
         * Defines the minimum height of viewport that comply with this specification.
         */
        'minHeight'?: number;
        /**
         * Defines the maximum height of viewport that comply with this specification.
         */
        'maxHeight'?: number;
    }
}
export declare namespace v1.skill {
    /**
     * Contains attributes related to last modification (create/update) request of a resource.
     * @interface
     */
    interface ManifestLastUpdateRequest {
        'status'?: v1.skill.Status;
        'errors'?: Array<v1.skill.StandardizedError>;
        'warnings'?: Array<v1.skill.StandardizedError>;
        /**
         * on success, this field indicates the created version.
         */
        'version'?: string;
    }
}
export declare namespace v1.skill {
    /**
     * Defines the structure for a resource status.
     * @interface
     */
    interface ManifestStatus {
        'lastUpdateRequest'?: v1.skill.ManifestLastUpdateRequest;
        /**
         * An opaque identifier for last successfully updated resource.
         */
        'eTag'?: string;
    }
}
export declare namespace v1.skill {
    /**
     * Can locale of skill be overwritten. Default value is DO_NOT_OVERWRITE.
     * @enum
     */
    type OverwriteMode = 'DO_NOT_OVERWRITE' | 'OVERWRITE';
}
export declare namespace v1.skill.Private {
    /**
     * Enterprise IT administrators' action on the private distribution.
     * @enum
     */
    type AcceptStatus = 'ACCEPTED' | 'PENDING';
}
export declare namespace v1.skill.Private {
    /**
     * Response of ListPrivateDistributionAccounts.
     * @interface
     */
    interface ListPrivateDistributionAccountsResponse {
        '_links'?: v1.Links;
        /**
         * List of PrivateDistributionAccounts.
         */
        'privateDistributionAccounts'?: Array<v1.skill.Private.PrivateDistributionAccount>;
        'nextToken'?: string;
    }
}
export declare namespace v1.skill.Private {
    /**
     * Contains information of the private distribution account with given id.
     * @interface
     */
    interface PrivateDistributionAccount {
        /**
         * 12-digit numerical account ID for AWS account holders.
         */
        'principal'?: string;
        'acceptStatus'?: v1.skill.Private.AcceptStatus;
    }
}
export declare namespace v1.skill {
    /**
     * Determines if the skill should be submitted only for certification and manually publish later or publish immediately after the skill is certified. Omitting the publication method will default to auto publishing.
     * @enum
     */
    type PublicationMethod = 'MANUAL_PUBLISHING' | 'AUTO_PUBLISHING';
}
export declare namespace v1.skill {
    /**
     * Publication status of the skill. It is associated with the skill's stage. Skill in 'development' stage can have publication status as 'DEVELOPMENT' or 'CERTIFICATION'. Skill in 'certified' stage can have publication status as 'CERTIFIED'. 'Skill in 'live' stage can have publication status as 'PUBLISHED', 'HIDDEN' or 'REMOVED'. * `DEVELOPMENT` - The skill is available only to you. If you have enabled it for testing, you can test it on devices registered to your developer account. * `CERTIFICATION` - Amazon is currently reviewing the skill for publication. During this time, you cannot edit the configuration. * `CERTIFIED` - The skill has been certified and ready to be published. Skill can be either published immediately or an future release date can be set for the skill. You cannot edit the configuration for the certified skills. To start development, make your changes on the development version. * `PUBLISHED` - The skill has been published and is available to users. You cannot edit the configuration for live skills. To start development on an updated version, make your changes on the development version instead. * `HIDDEN` - The skill has been published but is no longer available to new users for activation. Existing users can still invoke this skill. * `REMOVED` - The skill has been published but removed for use, due to Amazon's policy violation. You can update your skill and publish a new version to live to address the policy violation.
     * @enum
     */
    type PublicationStatus = 'DEVELOPMENT' | 'CERTIFICATION' | 'CERTIFIED' | 'PUBLISHED' | 'HIDDEN' | 'REMOVED';
}
export declare namespace v1.skill {
    /**
     * The reason to withdraw.
     * @enum
     */
    type Reason = 'TEST_SKILL' | 'MORE_FEATURES' | 'DISCOVERED_ISSUE' | 'NOT_RECEIVED_CERTIFICATION_FEEDBACK' | 'NOT_INTEND_TO_PUBLISH' | 'OTHER';
}
export declare namespace v1.skill {
    /**
     *
     * @interface
     */
    interface RegionalSSLCertificate {
        'sslCertificate'?: string;
    }
}
export declare namespace v1.skill {
    /**
     * Defines the structure for a resource deployment status.
     * @interface
     */
    interface ResourceImportStatus {
        /**
         * Resource name. eg. manifest, interactionModels.en_US and so on.
         */
        'name'?: string;
        'status': v1.skill.ResponseStatus;
        'action'?: v1.skill.Action;
        'errors'?: Array<v1.skill.StandardizedError>;
        'warnings'?: Array<v1.skill.StandardizedError>;
    }
}
export declare namespace v1.skill {
    /**
     * Status for a Response resource.
     * @enum
     */
    type ResponseStatus = 'FAILED' | 'IN_PROGRESS' | 'SUCCEEDED' | 'ROLLBACK_SUCCEEDED' | 'ROLLBACK_FAILED' | 'SKIPPED';
}
export declare namespace v1.skill {
    /**
     * Rollback request for a skill
     * @interface
     */
    interface RollbackRequestStatus {
        /**
         * rollback request id
         */
        'id'?: string;
        /**
         * The target skill version to rollback to.
         */
        'targetVersion'?: string;
        'submissionTime'?: string;
        'status'?: v1.skill.RollbackRequestStatusTypes;
        'errors'?: Array<v1.skill.StandardizedError>;
    }
}
export declare namespace v1.skill {
    /**
     * The rollback status of the rollback request. * `FAILED` - The rollback has failed. Please retry the rollback. * `INELIGIBLE` - The target version is ineligible for rollback. * `IN_PROGRESS` - The rollback is in progress. * `SUCCEEDED` - The rollback has succeeded.
     * @enum
     */
    type RollbackRequestStatusTypes = 'FAILED' | 'INELIGIBLE' | 'IN_PROGRESS' | 'SUCCEEDED';
}
export declare namespace v1.skill {
    /**
     *
     * @interface
     */
    interface SSLCertificatePayload {
        /**
         * The default ssl certificate for the skill. If a request is made for a region without an explicit ssl certificate, this certificate will be used.
         */
        'sslCertificate'?: string;
        /**
         * A map of region to ssl certificate. Keys are string region codes (https://developer.amazon.com/docs/smapi/skill-manifest.html#regions), values are regional ssl certificate objects which contain the ssl certificate blobs as strings.
         */
        'regions'?: {
            [key: string]: v1.skill.RegionalSSLCertificate;
        };
    }
}
export declare namespace v1.skill {
    /**
     * Structure for skill credentials response.
     * @interface
     */
    interface SkillCredentials {
        'skillMessagingCredentials'?: v1.skill.SkillMessagingCredentials;
    }
}
export declare namespace v1.skill {
    /**
     * Defines the structure for interaction model build status.
     * @interface
     */
    interface SkillInteractionModelStatus {
        'lastUpdateRequest'?: v1.skill.InteractionModelLastUpdateRequest;
        /**
         * An opaque identifier for last successfully updated resource.
         */
        'eTag'?: string;
        /**
         * Version for last successfully built model.
         */
        'version'?: string;
    }
}
export declare namespace v1.skill {
    /**
     * Defines the structure for skill messaging credentials.
     * @interface
     */
    interface SkillMessagingCredentials {
        /**
         * The client id for the security profile.
         */
        'clientId'?: string;
        /**
         * The client secret for the security profile.
         */
        'clientSecret'?: string;
    }
}
export declare namespace v1.skill {
    /**
     * Defines the structure for skill status response.
     * @interface
     */
    interface SkillStatus {
        'manifest'?: v1.skill.ManifestStatus;
        /**
         * Status for available interaction models, keyed by locale.
         */
        'interactionModel'?: {
            [key: string]: v1.skill.SkillInteractionModelStatus;
        };
        'hostedSkillDeployment'?: v1.skill.HostedSkillDeploymentStatus;
        'hostedSkillProvisioning'?: v1.skill.HostedSkillProvisioningStatus;
    }
}
export declare namespace v1.skill {
    /**
     * Information about the skills.
     * @interface
     */
    interface SkillSummary {
        'skillId'?: string;
        'stage'?: v1.StageV2Type;
        /**
         * List of APIs currently implemented by the skill.
         */
        'apis'?: Array<v1.skill.SkillSummaryApis>;
        'publicationStatus'?: v1.skill.PublicationStatus;
        'lastUpdated'?: string;
        /**
         * Name of the skill in skill locales (keys are locale names (e.g. 'en-US') whereas values are name of the skill in that locale.
         */
        'nameByLocale'?: {
            [key: string]: string;
        };
        /**
         * Amazon Standard Identification Number (ASIN) is unique blocks of 10 letters and/or numbers that identify items. More info about ASIN can be found here: https://www.amazon.com/gp/seller/asin-upc-isbn-info.html ASIN is available for those skills only, that have been published, at least once.
         */
        'asin'?: string;
        '_links'?: v1.Links;
    }
}
export declare namespace v1.skill {
    /**
     *
     * @enum
     */
    type SkillSummaryApis = 'custom' | 'smartHome' | 'flashBriefing' | 'video' | 'music' | 'householdList' | 'health' | 'alexaForBusiness' | 'demandResponse';
}
export declare namespace v1.skill {
    /**
     * Information about the skill version
     * @interface
     */
    interface SkillVersion {
        'version'?: string;
        /**
         * Description of the version (limited to 300 characters).
         */
        'message'?: string;
        'creationTime'?: string;
        /**
         * List of submissions for the skill version
         */
        'submissions'?: Array<v1.skill.VersionSubmission>;
    }
}
export declare namespace v1.skill {
    /**
     * Standardized structure which wraps machine parsable and human readable information about an error.
     * @interface
     */
    interface StandardizedError {
        /**
         * Standardized, machine readable structure that wraps all the information about a specific occurrence of an error of the type specified by the code.
         */
        'validationDetails'?: v1.skill.ValidationDetails;
        /**
         * Error code that maps to an error message. Developers with different locales should be able to lookup the error description based on this code.
         */
        'code'?: string;
        /**
         * Readable description of error. If standardized, this is generated from the error code and validation details.
         */
        'message': string;
    }
}
export declare namespace v1.skill {
    /**
     * Status of a resource.
     * @enum
     */
    type Status = 'FAILED' | 'IN_PROGRESS' | 'SUCCEEDED';
}
export declare namespace v1.skill {
    /**
     *
     * @interface
     */
    interface SubmitSkillForCertificationRequest {
        'publicationMethod'?: v1.skill.PublicationMethod;
        /**
         * Description of the version (limited to 300 characters).
         */
        'versionMessage'?: string;
    }
}
export declare namespace v1.skill {
    /**
     * Defines the structure for skill upload response.
     * @interface
     */
    interface UploadResponse {
        /**
         * The upload URL to upload a skill package.
         */
        'uploadUrl'?: string;
        /**
         * The expiration time of the URL
         */
        'expiresAt'?: string;
    }
}
export declare namespace v1.skill {
    /**
     *
     * @enum
     */
    type ValidationDataTypes = 'object' | 'boolean' | 'integer' | 'array' | 'string' | 'null';
}
export declare namespace v1.skill {
    /**
     * Structure representing an endpoint.
     * @interface
     */
    interface ValidationEndpoint {
        /**
         * Path to the endpoint URI in the resource.
         */
        'propertyPath'?: string;
        /**
         * Type of the endpoint (https, http, arn etc).
         */
        'type'?: string;
        /**
         * Full URI of the endpoint.
         */
        'value'?: string;
    }
}
export declare namespace v1.skill {
    /**
     * Object representing what is wrong in the request.
     * @interface
     */
    interface ValidationFailureReason {
        /**
         * Enum for type of validation failure in the request.
         */
        'type'?: v1.skill.ValidationFailureType;
    }
}
export declare namespace v1.skill {
    /**
     * Enum for type of validation failure in the request.
     * @enum
     */
    type ValidationFailureType = 'RESOURCE_DOES_NOT_EXIST' | 'RESOURCE_VERSION_DOES_NOT_MATCH' | 'MALFORMED_INPUT' | 'EXPECTED_NOT_EMPTY_VALUE' | 'INVALID_NUMBER_OF_OCCURENCES' | 'INVALID_NUMBER_OF_PROPERTIES' | 'EXPECTED_ATLEAST_ONE_RELATED_INSTANCE' | 'EXPECTED_EXACTLY_ONE_RELATED_INSTANCE' | 'RESOURCE_LOCKED' | 'UNEXPECTED_RESOURCE_STAGE' | 'UNEXPECTED_RESOURCE_PROPERTY' | 'MISSING_RESOURCE_PROPERTY';
}
export declare namespace v1.skill {
    /**
     * Structure representing a public feature.
     * @interface
     */
    interface ValidationFeature {
        /**
         * Name of the feature.
         */
        'name'?: string;
        /**
         * Contact URL or email for the feature.
         */
        'contact'?: string;
    }
}
export declare namespace v1.skill {
    /**
     * Submission for a skill version
     * @interface
     */
    interface VersionSubmission {
        'status'?: v1.skill.VersionSubmissionStatus;
        'submissionTime'?: string;
    }
}
export declare namespace v1.skill {
    /**
     * The lifecycle status of the skill version submission. * `LIVE` - The skill version is in the live stage * `CERTIFIED` - The skill version has gone through the certification review process and has been certified. * `IN_REVIEW` - The skill version is currently under review for certification and publication. During this time, you cannot edit the configuration. * `FAILED_CERTIFICATION` - The skill version has been submitted for certification, however it has failed certification review. Please submit a new version for certification. * `HIDDEN` - The skill version has been published but is no longer available to new users for activation. Existing users can still invoke this skill if it is the most recent version. * `REMOVED` - The skill version has been published but removed for use, due to Amazon's policy violation. You can update your skill and publish a new version to live to address the policy violation. * `WITHDRAWN_FROM_CERTIFICATION` - The skill version was submitted for certification but was withdrawn from review.
     * @enum
     */
    type VersionSubmissionStatus = 'LIVE' | 'CERTIFIED' | 'IN_REVIEW' | 'FAILED_CERTIFICATION' | 'HIDDEN' | 'REMOVED' | 'WITHDRAWN_FROM_CERTIFICATION';
}
export declare namespace v1.skill {
    /**
     * The payload for the withdraw operation.
     * @interface
     */
    interface WithdrawRequest {
        'reason': v1.skill.Reason;
        /**
         * The message only in case the reason in OTHER.
         */
        'message'?: string;
    }
}
export declare namespace v1.skill.accountLinking {
    /**
     * The type of client authentication scheme.
     * @enum
     */
    type AccessTokenSchemeType = 'HTTP_BASIC' | 'REQUEST_BODY_CREDENTIALS';
}
export declare namespace v1.skill.accountLinking {
    /**
     * A key-value pair object that contains the OAuth2 authorization url to initiate the skill account linking process.
     * @interface
     */
    interface AccountLinkingPlatformAuthorizationUrl {
        'platformType': v1.skill.accountLinking.PlatformType;
        /**
         * Defines the OAuth2 Authorization URL that will be used in this platform to authenticate the customer / person.
         */
        'platformAuthorizationUrl': string;
    }
}
export declare namespace v1.skill.accountLinking {
    /**
     * The request body of AccountLinkingRequest.
     * @interface
     */
    interface AccountLinkingRequest {
        'accountLinkingRequest'?: v1.skill.accountLinking.AccountLinkingRequestPayload;
    }
}
export declare namespace v1.skill.accountLinking {
    /**
     * The payload for creating the account linking partner.
     * @interface
     */
    interface AccountLinkingRequestPayload {
        'type'?: v1.skill.accountLinking.AccountLinkingType;
        /**
         * The url where customers will be redirected in the companion app to enter login credentials.
         */
        'authorizationUrl'?: string;
        /**
         * The list of domains that the authorization URL will fetch content from.
         */
        'domains'?: Array<string>;
        /**
         * The unique public string used to identify the client requesting for authentication.
         */
        'clientId'?: string;
        /**
         * The list of permissions which will be requested from the skill user.
         */
        'scopes'?: Array<string>;
        /**
         * The url used for access token and token refresh requests.
         */
        'accessTokenUrl'?: string;
        /**
         * The client secret provided by developer.
         */
        'clientSecret'?: string;
        'accessTokenScheme'?: v1.skill.accountLinking.AccessTokenSchemeType;
        /**
         * The time in seconds for which access token is valid. If OAuth client returns \"expires_in\", it will be overwrite this parameter.
         */
        'defaultTokenExpirationInSeconds'?: number;
        /**
         * Optional, if your skill requires reciprocal authorization, provide this additional access token url to handle reciprocal (Alexa) authorization codes that can be exchanged for Alexa access tokens.
         */
        'reciprocalAccessTokenUrl'?: string;
        /**
         * The list of valid urls to redirect back to, when the linking process is initiated from a third party system.
         */
        'redirectUrls'?: Array<string>;
        /**
         * The list of valid authorization urls for allowed platforms to initiate account linking.
         */
        'authorizationUrlsByPlatform'?: Array<v1.skill.accountLinking.AccountLinkingPlatformAuthorizationUrl>;
        /**
         * Set to true to let users enable the skill without starting the account linking flow. Set to false to require the normal account linking flow when users enable the skill.
         */
        'skipOnEnablement'?: boolean;
        'voiceForwardAccountLinking'?: v1.skill.accountLinking.VoiceForwardAccountLinkingStatus;
    }
}
export declare namespace v1.skill.accountLinking {
    /**
     * The account linking information of a skill.
     * @interface
     */
    interface AccountLinkingResponse {
        'type'?: v1.skill.accountLinking.AccountLinkingType;
        /**
         * The url where customers will be redirected in the companion app to enter login credentials.
         */
        'authorizationUrl'?: string;
        /**
         * The list of domains that the authorization URL will fetch content from.
         */
        'domains'?: Array<string>;
        /**
         * The unique public string used to identify the client requesting for authentication.
         */
        'clientId'?: string;
        /**
         * The list of permissions which will be requested from the skill user.
         */
        'scopes'?: Array<string>;
        /**
         * The url used for access token and token refresh requests.
         */
        'accessTokenUrl'?: string;
        'accessTokenScheme'?: v1.skill.accountLinking.AccessTokenSchemeType;
        /**
         * The time in seconds for which access token is valid. If OAuth client returns \"expires_in\", it will be overwrite this parameter.
         */
        'defaultTokenExpirationInSeconds'?: number;
        /**
         * The list of valid urls to redirect back to, when the linking process is initiated from a third party system.
         */
        'redirectUrls'?: Array<string>;
        /**
         * The list of valid authorization urls for allowed platforms to initiate account linking.
         */
        'authorizationUrlsByPlatform'?: Array<v1.skill.accountLinking.AccountLinkingPlatformAuthorizationUrl>;
        'voiceForwardAccountLinking'?: v1.skill.accountLinking.VoiceForwardAccountLinkingStatus;
    }
}
export declare namespace v1.skill.accountLinking {
    /**
     * The type of account linking.
     * @enum
     */
    type AccountLinkingType = 'AUTH_CODE' | 'IMPLICIT';
}
export declare namespace v1.skill.accountLinking {
    /**
     * Defines the type of platform that will be used by the customer to perform account linking.
     * @enum
     */
    type PlatformType = 'iOS' | 'Android';
}
export declare namespace v1.skill.accountLinking {
    /**
     * Defines the voice forward account linking status of a skill.
     * @enum
     */
    type VoiceForwardAccountLinkingStatus = 'ENABLED' | 'DISABLED';
}
export declare namespace v1.skill.betaTest {
    /**
     * Beta test for an Alexa skill.
     * @interface
     */
    interface BetaTest {
        /**
         * Expiry date of the beta test.
         */
        'expiryDate'?: string;
        'status'?: v1.skill.betaTest.Status;
        /**
         * Email address for providing feedback
         */
        'feedbackEmail'?: string;
        /**
         * Deeplinking for getting authorized to the beta test.
         */
        'invitationUrl'?: string;
        /**
         * Remaining invite count for the beta test.
         */
        'invitesRemaining'?: number;
    }
}
export declare namespace v1.skill.betaTest {
    /**
     * Status of the beta test.
     * @enum
     */
    type Status = 'IN_DRAFT' | 'STARTING' | 'RUNNING' | 'STOPPING' | 'ENDED';
}
export declare namespace v1.skill.betaTest {
    /**
     * Beta test meta-data.
     * @interface
     */
    interface TestBody {
        /**
         * Email address for providing feedback.
         */
        'feedbackEmail'?: string;
    }
}
export declare namespace v1.skill.betaTest.testers {
    /**
     * Indicates whether the tester has accepted the invitation.
     * @enum
     */
    type InvitationStatus = 'ACCEPTED' | 'NOT_ACCEPTED';
}
export declare namespace v1.skill.betaTest.testers {
    /**
     *
     * @interface
     */
    interface ListTestersResponse {
        'testers'?: Array<v1.skill.betaTest.testers.TesterWithDetails>;
        'isTruncated'?: boolean;
        'nextToken'?: string;
    }
}
export declare namespace v1.skill.betaTest.testers {
    /**
     *
     * @interface
     */
    interface Tester {
        /**
         * Email address of the tester.
         */
        'emailId'?: string;
    }
}
export declare namespace v1.skill.betaTest.testers {
    /**
     * Tester information.
     * @interface
     */
    interface TesterWithDetails {
        /**
         * Email address of the tester.
         */
        'emailId'?: string;
        /**
         * Date and time when the tester is added to the beta test.
         */
        'associationDate'?: string;
        /**
         * Indicates whether the tester is allowed to be sent reminder.
         */
        'isReminderAllowed'?: boolean;
        'invitationStatus'?: v1.skill.betaTest.testers.InvitationStatus;
    }
}
export declare namespace v1.skill.betaTest.testers {
    /**
     * List of testers.
     * @interface
     */
    interface TestersList {
        /**
         * List of the email address of testers.
         */
        'testers'?: Array<v1.skill.betaTest.testers.Tester>;
    }
}
export declare namespace v1.skill.blueprint {
    /**
     * Defines the structure for Shopping Kit related information in the skill manifest.
     * @interface
     */
    interface ShoppingKit {
        /**
         * True if the skill uses Alexa Shopping Actions, false otherwise.
         */
        'isShoppingActionsEnabled'?: boolean;
        /**
         * True if the skill uses Shopping Actions with Amazon Associates, false otherwise.
         */
        'isAmazonAssociatesOnAlexaEnabled'?: boolean;
    }
}
export declare namespace v1.skill.certification {
    /**
     *
     * @interface
     */
    interface CertificationResponse {
        /**
         * Certification Id for the skill
         */
        'id'?: string;
        'status'?: v1.skill.certification.CertificationStatus;
        /**
         * Timestamp for when the skill was submitted for certification.
         */
        'skillSubmissionTimestamp'?: string;
        'reviewTrackingInfo'?: v1.skill.certification.ReviewTrackingInfo;
        'result'?: v1.skill.certification.CertificationResult;
    }
}
export declare namespace v1.skill.certification {
    /**
     * Structure for the result for the outcomes of certification review for the skill. Currently provides the distribution information of a skill if the certification SUCCEEDED.
     * @interface
     */
    interface CertificationResult {
        'distributionInfo'?: v1.skill.certification.DistributionInfo;
    }
}
export declare namespace v1.skill.certification {
    /**
     * String that specifies the current status of skill's certification Possible values are \"IN_PROGRESS\", \"SUCCEEDED\", \"FAILED\" and \"CANCELLED\"
     * @enum
     */
    type CertificationStatus = 'IN_PROGRESS' | 'SUCCEEDED' | 'FAILED' | 'CANCELLED';
}
export declare namespace v1.skill.certification {
    /**
     * Summary of the certification resource. This is a leaner view of the certification resource for the collections API.
     * @interface
     */
    interface CertificationSummary {
        /**
         * Certification Id for the skill.
         */
        'id'?: string;
        'status'?: v1.skill.certification.CertificationStatus;
        /**
         * Timestamp for when the skill was submitted for certification.
         */
        'skillSubmissionTimestamp'?: string;
        'reviewTrackingInfo'?: v1.skill.certification.ReviewTrackingInfoSummary;
    }
}
export declare namespace v1.skill.certification {
    /**
     * The distribution information for skill where Amazon distributed the skill
     * @interface
     */
    interface DistributionInfo {
        /**
         * All countries where the skill was published in by Amazon.
         */
        'publishedCountries'?: Array<string>;
        'publicationFailures'?: Array<v1.skill.certification.PublicationFailure>;
    }
}
export declare namespace v1.skill.certification {
    /**
     * Structure for any updates to estimation completion time for certification review for the skill.
     * @interface
     */
    interface EstimationUpdate {
        /**
         * Timestamp for originally estimated completion of certification review for the skill.
         */
        'originalEstimatedCompletionTimestamp'?: string;
        /**
         * Timestamp for originally estimated completion of certification review for the skill.
         */
        'revisedEstimatedCompletionTimestamp'?: string;
        /**
         * Reason for updates to estimates for certification review
         */
        'reason'?: string;
    }
}
export declare namespace v1.skill.certification {
    /**
     * List of certification summary for a skill.
     * @interface
     */
    interface ListCertificationsResponse {
        '_links'?: v1.Links;
        /**
         * boolean value for if the response is truncated. isTruncated = true if more than the assigned maxResults parameter value certification items are available for the skill. The results are then paginated and the remaining results can be retrieved in a similar paginated manner by using 'next' link in the _links or using the nextToken in a following request.
         */
        'isTruncated'?: boolean;
        /**
         * Encrypted token present when isTruncated is true.
         */
        'nextToken'?: string;
        /**
         * Total number of certification results available for the skill.
         */
        'totalCount'?: number;
        /**
         * List of certifications available for a skill. The list of certifications is sorted in a default descending sort order on id field.
         */
        'items'?: Array<v1.skill.certification.CertificationSummary>;
    }
}
export declare namespace v1.skill.certification {
    /**
     * Information about why the skill was not published in certain countries.
     * @interface
     */
    interface PublicationFailure {
        /**
         * Reason why Amazon did not publish the skill in certain countries.
         */
        'reason'?: string;
        /**
         * List of countries where Amazon did not publish the skill for a specific reason
         */
        'countries'?: Array<string>;
    }
}
export declare namespace v1.skill.certification {
    /**
     * Structure for review tracking information of the skill.
     * @interface
     */
    interface ReviewTrackingInfo {
        /**
         * Timestamp for estimated completion of certification review for the skill.
         */
        'estimatedCompletionTimestamp'?: string;
        /**
         * Timestamp for actual completion of certification review for the skill.
         */
        'actualCompletionTimestamp'?: string;
        /**
         * Timestamp for when the last update was made to review tracking info.
         */
        'lastUpdated'?: string;
        /**
         * List of updates to estimation completion time for certification review for the skill.
         */
        'estimationUpdates'?: Array<v1.skill.certification.EstimationUpdate>;
    }
}
export declare namespace v1.skill.certification {
    /**
     * Structure for summarised view of review tracking information of the skill. This does not have the estimationUpdates array field.
     * @interface
     */
    interface ReviewTrackingInfoSummary {
        /**
         * Timestamp for estimated completion of certification review for the skill.
         */
        'estimatedCompletionTimestamp'?: string;
        /**
         * Timestamp for actual completion of certification review workflow for the skill.
         */
        'actualCompletionTimestamp'?: string;
        /**
         * Timestamp for when the last update was made to review tracking info.
         */
        'lastUpdated'?: string;
    }
}
export declare namespace v1.skill {
    /**
     *
     * @interface
     */
    interface CreateSkillRequest {
        /**
         * ID of the vendor owning the skill.
         */
        'vendorId'?: string;
        'manifest'?: v1.skill.Manifest.SkillManifest;
        'hosting'?: v1.skill.AlexaHosted.HostingConfiguration;
    }
}
export declare namespace v1.skill {
    /**
     *
     * @interface
     */
    interface CreateSkillWithPackageRequest {
        /**
         * ID of the vendor owning the skill.
         */
        'vendorId'?: string;
        /**
         * The URL for the skill package.
         */
        'location': string;
    }
}
export declare namespace v1.skill.evaluations {
    /**
     * An enumeration indicating whether the user has explicitly confirmed or denied the entire intent. Possible values: \"NONE\", \"CONFIRMED\", \"DENIED\".
     * @enum
     */
    type ConfirmationStatusType = 'NONE' | 'CONFIRMED' | 'DENIED';
}
export declare namespace v1.skill.evaluations {
    /**
     * A representation of question prompts to the user for multi-turn, which requires user to fill a slot value, or confirm a slot value, or confirm an intent.
     * @interface
     */
    interface DialogAct {
        'type'?: v1.skill.evaluations.DialogActType;
        /**
         * The name of the target slot that needs to be filled or confirmed for a dialogAct
         */
        'targetSlot'?: string;
    }
}
export declare namespace v1.skill.evaluations {
    /**
     *
     * @enum
     */
    type DialogActType = 'Dialog.ElicitSlot' | 'Dialog.ConfirmSlot' | 'Dialog.ConfirmIntent';
}
export declare namespace v1.skill.evaluations {
    /**
     *
     * @interface
     */
    interface Intent {
        'name'?: string;
        'confirmationStatus'?: v1.skill.evaluations.ConfirmationStatusType;
        /**
         * A map of key-value pairs that further describes what the user meant based on a predefined intent schema. The map can be empty.
         */
        'slots'?: {
            [key: string]: v1.skill.evaluations.Slot;
        };
    }
}
export declare namespace v1.skill.evaluations {
    /**
     * Included when the selected intent has dialog defined and the dialog is not completed.  To continue the dialog, provide the value of the token in the multiTurnToken field in the next request.
     * @interface
     */
    interface MultiTurn {
        'dialogAct'?: v1.skill.evaluations.DialogAct;
        /**
         * Opaque string which contains multi-turn related context.
         */
        'token'?: string;
        /**
         * A sample prompt defined in the dialog model for each DialogAct.
         */
        'prompt'?: string;
    }
}
export declare namespace v1.skill.evaluations {
    /**
     *
     * @interface
     */
    interface ProfileNluRequest {
        /**
         * Actual representation of user input to Alexa.
         */
        'utterance': string;
        /**
         * Opaque string which contains multi-turn related context.
         */
        'multiTurnToken'?: string;
    }
}
export declare namespace v1.skill.evaluations {
    /**
     *
     * @interface
     */
    interface ProfileNluResponse {
        /**
         * Represents when an utterance results in the skill exiting. It would be true when NLU selects 1P ExitAppIntent or GoHomeIntent, and false otherwise.
         */
        'sessionEnded'?: boolean;
        'selectedIntent'?: v1.skill.evaluations.ProfileNluSelectedIntent;
        /**
         * All intents that Alexa considered for the utterance in the request, but did not select.
         */
        'consideredIntents'?: Array<v1.skill.evaluations.Intent>;
        'multiTurn'?: v1.skill.evaluations.MultiTurn;
    }
}
export declare namespace v1.skill.evaluations {
    /**
     *
     * @interface
     */
    interface ResolutionsPerAuthorityItems {
        /**
         * The name of the authority for the slot values. For custom slot types, this authority label incorporates your skill ID and the slot type name.
         */
        'authority'?: string;
        'status'?: v1.skill.evaluations.ResolutionsPerAuthorityStatus;
        /**
         * An array of resolved values for the slot.
         */
        'values'?: Array<v1.skill.evaluations.ResolutionsPerAuthorityValueItems>;
    }
}
export declare namespace v1.skill.evaluations {
    /**
     * An object representing the status of entity resolution for the slot.
     * @interface
     */
    interface ResolutionsPerAuthorityStatus {
        'code'?: v1.skill.evaluations.ResolutionsPerAuthorityStatusCode;
    }
}
export declare namespace v1.skill.evaluations {
    /**
     * A code indicating the results of attempting to resolve the user utterance against the defined slot types. This can be one of the following: ER_SUCCESS_MATCH: The spoken value matched a value or synonym explicitly defined in your custom slot type. ER_SUCCESS_NO_MATCH: The spoken value did not match any values or synonyms explicitly defined in your custom slot type. ER_ERROR_TIMEOUT: An error occurred due to a timeout. ER_ERROR_EXCEPTION: An error occurred due to an exception during processing.
     * @enum
     */
    type ResolutionsPerAuthorityStatusCode = 'ER_SUCCESS_MATCH' | 'ER_SUCCESS_NO_MATCH' | 'ER_ERROR_TIMEOUT' | 'ER_ERROR_EXCEPTION';
}
export declare namespace v1.skill.evaluations {
    /**
     * An object representing the resolved value for the slot, based on the user's utterance and the slot type definition.
     * @interface
     */
    interface ResolutionsPerAuthorityValueItems {
        /**
         * The string for the resolved slot value.
         */
        'name'?: string;
        /**
         * The unique ID defined for the resolved slot value. This is based on the IDs defined in the slot type definition.
         */
        'id'?: string;
    }
}
export declare namespace v1.skill.evaluations {
    /**
     *
     * @interface
     */
    interface Slot {
        'name'?: string;
        'value'?: string;
        'confirmationStatus'?: v1.skill.evaluations.ConfirmationStatusType;
        'resolutions'?: v1.skill.evaluations.SlotResolutions;
    }
}
export declare namespace v1.skill.evaluations {
    /**
     * A resolutions object representing the results of resolving the words captured from the user's utterance.
     * @interface
     */
    interface SlotResolutions {
        /**
         * An array of objects representing each possible authority for entity resolution. An authority represents the source for the data provided for the slot. For a custom slot type, the authority is the slot type you defined.
         */
        'resolutionsPerAuthority'?: Array<v1.skill.evaluations.ResolutionsPerAuthorityItems>;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the Experiment body used for requesting an experiment creation. Only includes fields that are editable by the user.
     * @interface
     */
    interface CreateExperimentInput {
        /**
         * Name that developer assigns to the experiment for easier identification.
         */
        'name'?: string;
        /**
         * Hypothesis that developer provides to describe the experiment's purpose.
         */
        'description'?: string;
        'type'?: v1.skill.experiment.ExperimentType;
        /**
         * The number of weeks the skill builder intends to run the experiment. Used for documentation purposes and by metric platform as a reference. Does not impact experiment execution. Format uses ISO-8601 representation of duration. (Example: 4 weeks = \"P4W\")
         */
        'plannedDuration'?: string;
        /**
         * The percentage of unique customers that will be part of the skill experiment while the experiment is running.
         */
        'exposurePercentage'?: number;
        /**
         * List of metric configurations that determine which metrics are key/guardrail metrics and the expected metric direction.
         */
        'metricConfigurations'?: Array<v1.skill.experiment.MetricConfiguration>;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the request body for creating an experiment.
     * @interface
     */
    interface CreateExperimentRequest {
        'experiment': v1.skill.experiment.CreateExperimentInput;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * These states are for recording the destination state from a transition action (Created, Pilot, Start, Stop) on the experiment. * `CREATED`: Result state for the 'Create' action. Experiment has been created. * `ENABLED`: Result state for the 'Pilot' action. Experiment configurations are deployed and customer overrides are activated. Actual experiment has not started yet. * `RUNNING`: Result state for the 'Start' action. Experiment has started with the configured exposure. Skill customers selected within the exposure are contributing to the metric data. * `STOPPED`: Result state for the 'Stop' action. Experiment has stopped and all experiment configurations have been removed. All customers will see the C behavior by default.
     * @enum
     */
    type DestinationState = 'CREATED' | 'ENABLED' | 'RUNNING' | 'STOPPED';
}
export declare namespace v1.skill.experiment {
    /**
     * Defines historical properties of a skill experiment.
     * @interface
     */
    interface ExperimentHistory {
        'creationTime'?: string;
        'startTime'?: string;
        /**
         * The reason an experiment was stopped if experiment was stopped.
         */
        'stoppedReason'?: string;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the full Experiment body which would contain all experiment details.
     * @interface
     */
    interface ExperimentInformation {
        /**
         * Name that developer assigns to the experiment for easier identification.
         */
        'name'?: string;
        /**
         * Hypothesis that developer provides to describe the experiment's purpose.
         */
        'description'?: string;
        'type'?: v1.skill.experiment.ExperimentType;
        /**
         * The number of weeks the skill builder intends to run the experiment. Used for documentation purposes and by metric platform as a reference. Does not impact experiment execution. Format uses ISO-8601 representation of duration. (Example: 4 weeks = \"P4W\")
         */
        'plannedDuration'?: string;
        /**
         * The percentage of unique customers that will be part of the skill experiment while the experiment is running.
         */
        'exposurePercentage'?: number;
        /**
         * The number of overrides which currently exist for the experiment.
         */
        'treatmentOverrideCount'?: number;
        /**
         * List of metric configurations that determine which metrics are key/guardrail metrics and the expected metric direction. This is required by the system that collects metrics and generates the metric reports.
         */
        'metricConfigurations'?: Array<v1.skill.experiment.MetricConfiguration>;
        'state'?: v1.skill.experiment.State;
        'history'?: v1.skill.experiment.ExperimentHistory;
        'trigger'?: v1.skill.experiment.ExperimentTrigger;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the last state transition information for the experiment.
     * @interface
     */
    interface ExperimentLastStateTransition {
        'sourceState'?: v1.skill.experiment.SourceState;
        'targetState'?: v1.skill.experiment.DestinationState;
        'status'?: v1.skill.experiment.StateTransitionStatus;
        'startTime'?: string;
        'endTime'?: string;
        /**
         * List of error objects which define what errors caused the state transition failure.
         */
        'errors'?: Array<v1.skill.experiment.StateTransitionError>;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * The reason indicating why an exerpiment was stopped. If none is chosen then default to DEVELOPER_REQUEST. Only used when putting experiment into STOPPED state.
     * @enum
     */
    type ExperimentStoppedReason = 'EXPERIMENT_SUCCESS' | 'EXPERIMENT_ISSUE';
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the shortened Experiment body which would contain a summary of experiment information.
     * @interface
     */
    interface ExperimentSummary {
        /**
         * Identifier for experiment within a skill.
         */
        'experimentId'?: string;
        /**
         * Name that developer assigns to the experiment for easier identification.
         */
        'name'?: string;
        'state'?: v1.skill.experiment.State;
        'experimentHistory'?: v1.skill.experiment.ExperimentHistory;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines trigger properties of a skill experiment.
     * @interface
     */
    interface ExperimentTrigger {
        'scheduledEndTime'?: string;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Type of the experiment which directly affects the skill version used for T1. C will always point to the skill version in the skill's LIVE stage regardless of experiment type.
     * @enum
     */
    type ExperimentType = 'ENDPOINT_BASED';
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the response body when this customer's treatment override information is requested.
     * @interface
     */
    interface GetCustomerTreatmentOverrideResponse {
        'treatmentId'?: v1.skill.experiment.TreatmentId;
        /**
         * The number of overrides which currently exist for the experiment.
         */
        'treatmentOverrideCount'?: number;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the response body for retrieving the experiment results.
     * @interface
     */
    interface GetExperimentMetricSnapshotResponse {
        'status'?: v1.skill.experiment.MetricSnapshotStatus;
        /**
         * The reason why the metric snapshot status is unreliable.
         */
        'statusReason'?: string;
        /**
         * List of actual experiment metrics represented by a metric snapshot.
         */
        'metrics'?: Array<v1.skill.experiment.Metric>;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the response body for retrieving an experiment.
     * @interface
     */
    interface GetExperimentResponse {
        'experiment'?: v1.skill.experiment.ExperimentInformation;
        'lastStateTransition'?: v1.skill.experiment.ExperimentLastStateTransition;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the response body for retrieving the current experiment state.
     * @interface
     */
    interface GetExperimentStateResponse {
        'state'?: v1.skill.experiment.State;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the response body for retrieving the experiment metric snapshots.
     * @interface
     */
    interface ListExperimentMetricSnapshotsResponse {
        'paginationContext'?: v1.skill.experiment.PaginationContext;
        /**
         * List of experiment metric snapshots.
         */
        'metricSnapshots'?: Array<v1.skill.experiment.MetricSnapshot>;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the response body for retrieving all the experiments of a skill.
     * @interface
     */
    interface ListExperimentsResponse {
        'paginationContext'?: v1.skill.experiment.PaginationContext;
        /**
         * List of experiments with select fields returned.
         */
        'experiments'?: Array<v1.skill.experiment.ExperimentSummary>;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the request body for performing an experiment action to move it to a target state.
     * @interface
     */
    interface ManageExperimentStateRequest {
        'targetState': v1.skill.experiment.TargetState;
        'stoppedReason'?: v1.skill.experiment.ExperimentStoppedReason;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the metrics body.
     * @interface
     */
    interface Metric {
        /**
         * Unique name that identifies experiment metric.
         */
        'name'?: string;
        'treatmentId'?: v1.skill.experiment.TreatmentId;
        'values'?: v1.skill.experiment.MetricValues;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * The direction that an experiment metric is expected to trend during the experiment. * `INCREASE` - An upward change in metric value. * `DECREASE` - A downward change in metric value.
     * @enum
     */
    type MetricChangeDirection = 'INCREASE' | 'DECREASE';
}
export declare namespace v1.skill.experiment {
    /**
     * Configures the metrics that will be captured for the skill experiment. This is required by the system that collects metrics and generates the metric reports.
     * @interface
     */
    interface MetricConfiguration {
        /**
         * Unique name that identifies experiment metric.
         */
        'name'?: string;
        /**
         * List of types that the metric has been assigned.
         */
        'metricTypes'?: Array<v1.skill.experiment.MetricType>;
        'expectedChange'?: v1.skill.experiment.MetricChangeDirection;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the metric snapshot body with supplemental metadata properties.
     * @interface
     */
    interface MetricSnapshot {
        /**
         * Identifies the experiment metric snapshot in a skill experiment.
         */
        'metricSnapshotId'?: string;
        /**
         * The start date of the metric snapshot.
         */
        'startDate'?: string;
        /**
         * The end date of the metric snapshot.
         */
        'endDate'?: string;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * The status of the metric snapshot, whether it's RELIABLE or UNRELIABLE.
     * @enum
     */
    type MetricSnapshotStatus = 'RELIABLE' | 'UNRELIABLE';
}
export declare namespace v1.skill.experiment {
    /**
     * The metric types a specific metric can be assigned to. * `KEY` - Identified as a metric that should provide clear evidence of expected changes caused by the new treatment experience. * `GUARDRAIL` - Identified as a metric that would detect unexpected regressions caused by the new treatment experience.
     * @enum
     */
    type MetricType = 'KEY' | 'GUARDRAIL';
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the body of the metric result values.
     * @interface
     */
    interface MetricValues {
        /**
         * The mean (average) of each sample (T1 or C group).
         */
        'mean'?: number;
        /**
         * The relative percent difference between the mean of the T1 group and the mean of the C group.
         */
        'percentDiff'?: number;
        /**
         * The lower limit number of the confidence interval range. Confidence interval measures the probability that the mean falls within a range.
         */
        'confidenceIntervalLower'?: number;
        /**
         * The upper limit number of the confidence interval range.
         */
        'confidenceIntervalUpper'?: number;
        /**
         * The probability that the difference between the two means (from T1 and C) is due to random sampling error.
         */
        'pValue'?: number;
        /**
         * Count of users in the treatment sample.
         */
        'userCount'?: number;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the body that provides pagination-related properties in the operation response to indicate that additional paginated results are available.
     * @interface
     */
    interface PaginationContext {
        /**
         * Provided by server to retrieve the next set of paginated results.
         */
        'nextToken'?: string;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the request body for adding this customer's treatment override to an experiment.
     * @interface
     */
    interface SetCustomerTreatmentOverrideRequest {
        'treatmentId': v1.skill.experiment.TreatmentId;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * These states are for recording the previous state from a transition action (Created, Pilot, Start, Stop) on the experiment. * `CREATED`: Result state for the 'Create' action. Experiment has been created. * `ENABLED`: Result state for the 'Pilot' action. Experiment configurations are deployed and customer overrides are activated. Actual experiment has not started yet. * `RUNNING`: Result state for the 'Start' action. Experiment has started with the configured exposure. Skill customers selected within the exposure are contributing to the metric data.
     * @enum
     */
    type SourceState = 'CREATED' | 'ENABLED' | 'RUNNING';
}
export declare namespace v1.skill.experiment {
    /**
     * * `CREATED` - The experiment is successfully created but has not been enabled or started. * `ENABLING` - The experiment has initiated the transition to becoming \"ENABLED\". * `ENABLED` - The experiment configurations have been deployed but only customer treatment overrides set to T1 can view the T1 experience of a skill. No metrics are collected. * `RUNNING` - The experiment has started and a percentage of skill customers defined in the exposurePercentage will be entered into the experiment. Customers will randomly get assigned the T1 or C experience. Metric collection will begin. * `STOPPING` - The experiment has initated the transition to becoming \"STOPPED\". * `STOPPED` - The experiment has ended and all customers will experience the C behavior. Metrics will stop being collected. * `FAILED` - The experiment configurations have failed to deploy while enabling or starting the experiment.
     * @enum
     */
    type State = 'CREATED' | 'ENABLING' | 'ENABLED' | 'RUNNING' | 'STOPPING' | 'STOPPED' | 'FAILED';
}
export declare namespace v1.skill.experiment {
    /**
     * The errors which caused a state transition failure.
     * @interface
     */
    interface StateTransitionError {
        'type'?: v1.skill.experiment.StateTransitionErrorType;
        /**
         * The message associated with the state transition error.
         */
        'message'?: string;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * The error type which caused a state transition failure.
     * @enum
     */
    type StateTransitionErrorType = 'INELIGIBLITY';
}
export declare namespace v1.skill.experiment {
    /**
     * Status indiciating whether the state transiton was successful, in progress, or failed.
     * @enum
     */
    type StateTransitionStatus = 'SUCCEEDED' | 'IN_PROGRESS' | 'FAILED';
}
export declare namespace v1.skill.experiment {
    /**
     * These states are used to perform a transition action (Pilot, Start, Stop, Conclude) on the experiment. * `ENABLED`: Target state for the 'Pilot' action. Experiment configurations are deployed and customer overrides are activated. Actual experiment has not started yet. * `RUNNING`: Target state for the 'Start' action. Experiment has started with the configured exposure. Skill customers selected within the exposure are contributing to the metric data. * `STOPPED`: Target state for the 'Stop' action. Experiment has stopped and all experiment configurations have been removed. All customers will see the C behavior by default.
     * @enum
     */
    type TargetState = 'ENABLED' | 'RUNNING' | 'STOPPED';
}
export declare namespace v1.skill.experiment {
    /**
     * Treatment identifier for an experiment. * `C` - Control. The treatment that defines the existing skill experience. * `T1` - Treatment 1. The threatment that defines the experimental skill experience.
     * @enum
     */
    type TreatmentId = 'C' | 'T1';
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the Experiment body used for requesting an experiment update. Only includes fields that are editable by the user.
     * @interface
     */
    interface UpdateExperimentInput {
        /**
         * Hypothesis that developer provides to describe the experiment's purpose.
         */
        'description'?: string;
        /**
         * The number of weeks the skill builder intends to run the experiment. Used for documentation purposes and by metric platform as a reference. Does not impact experiment execution. Format uses ISO-8601 representation of duration. (Example: 4 weeks = \"P4W\")
         */
        'plannedDuration'?: string;
        /**
         * The percentage of unique customers that will be part of the skill experiment while the experiment is running.
         */
        'exposurePercentage'?: number;
        /**
         * List of metric configurations that determine which metrics are key/guardrail metrics and the expected metric direction.
         */
        'metricConfigurations'?: Array<v1.skill.experiment.MetricConfiguration>;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the request body for updating an experiment.
     * @interface
     */
    interface UpdateExperimentRequest {
        'experiment': v1.skill.experiment.UpdateExperimentInput;
    }
}
export declare namespace v1.skill.experiment {
    /**
     * Defines the request body for updating the exposure of an experiment.
     * @interface
     */
    interface UpdateExposureRequest {
        /**
         * The percentage of unique customers that will be part of the skill experiment while the experiment is running.
         */
        'exposurePercentage': number;
    }
}
export declare namespace v1.skill.history {
    /**
     * The hypothesized confidence for this interaction.
     * @interface
     */
    interface Confidence {
        'bin'?: v1.skill.history.ConfidenceBin;
    }
}
export declare namespace v1.skill.history {
    /**
     * Intent confidence bin for this utterance. * `HIGH`: Intent was recognized with high confidence. * `MEDIUM`: Intent was recognized with medium confidence. * `LOW`: Intent was recognized with low confidence. Note: Low confidence intents are not sent to the skill.
     * @enum
     */
    type ConfidenceBin = 'HIGH' | 'MEDIUM' | 'LOW';
}
export declare namespace v1.skill.history {
    /**
     * The dialog act used in the interaction.
     * @interface
     */
    interface DialogAct {
        'name'?: v1.skill.history.DialogActName;
    }
}
export declare namespace v1.skill.history {
    /**
     * Dialog act directive name. * `Dialog.ElicitSlot`: Alexa asked the user for the value of a specific slot. (https://developer.amazon.com/docs/custom-skills/dialog-interface-reference.html#elicitslot) * `Dialog.ConfirmSlot`: Alexa confirmed the value of a specific slot before continuing with the dialog. (https://developer.amazon.com/docs/custom-skills/dialog-interface-reference.html#confirmslot) * `Dialog.ConfirmIntent`: Alexa confirmed the all the information the user has provided for the intent before the skill took action. (https://developer.amazon.com/docs/custom-skills/dialog-interface-reference.html#confirmintent)
     * @enum
     */
    type DialogActName = 'Dialog.ElicitSlot' | 'Dialog.ConfirmSlot' | 'Dialog.ConfirmIntent';
}
export declare namespace v1.skill.history {
    /**
     * Provides the intent name, slots and confidence of the intent used in this interaction.
     * @interface
     */
    interface Intent {
        /**
         * The hypothesized intent for this utterance.
         */
        'name'?: string;
        'confidence'?: v1.skill.history.Confidence;
        /**
         * The hypothesized slot(s) for this interaction.
         */
        'slots'?: {
            [key: string]: v1.skill.history.Slot;
        };
    }
}
export declare namespace v1.skill.history {
    /**
     * A filter used to retrieve items where the intent confidence bin is equal to the given value. * `HIGH`: Intent was recognized with high confidence. * `MEDIUM`: Intent was recognized with medium confidence. * `LOW`: Intent was recognized with low confidence. Note: Low confidence intents are not sent to the skill.
     * @enum
     */
    type IntentConfidenceBin = 'HIGH' | 'MEDIUM' | 'LOW';
}
export declare namespace v1.skill.history {
    /**
     *
     * @interface
     */
    interface IntentRequest {
        'dialogAct'?: v1.skill.history.DialogAct;
        'intent'?: v1.skill.history.Intent;
        'interactionType'?: v1.skill.history.InteractionType;
        'locale'?: v1.skill.history.IntentRequestLocales;
        'publicationStatus'?: v1.skill.history.PublicationStatus;
        'stage'?: v1.StageType;
        /**
         * The transcribed user speech.
         */
        'utteranceText'?: string;
    }
}
export declare namespace v1.skill.history {
    /**
     * Skill locale in which this interaction occurred.
     * @enum
     */
    type IntentRequestLocales = 'en-US' | 'en-GB' | 'en-IN' | 'en-CA' | 'en-AU' | 'de-DE' | 'ja-JP';
}
export declare namespace v1.skill.history {
    /**
     * Response to the GET Intent Request History API. It contains the collection of utterances for the skill, nextToken and other metadata related to the search query.
     * @interface
     */
    interface IntentRequests {
        '_links'?: v1.Links;
        /**
         * This token can be used to load the next page of the result.
         */
        'nextToken'?: string;
        /**
         * This property is true when all the results matching the search request haven't been returned, false otherwise.
         */
        'isTruncated'?: boolean;
        /**
         * Total number of records that matched the given search query.
         */
        'totalCount'?: number;
        /**
         * Position of the current page in the result set.
         */
        'startIndex'?: number;
        /**
         * The Skill Id.
         */
        'skillId'?: string;
        /**
         * List of intent requests for the skill
         */
        'items'?: Array<v1.skill.history.IntentRequest>;
    }
}
export declare namespace v1.skill.history {
    /**
     * Indicates if the utterance was executed as a \"ONE_SHOT\" interaction or \"MODAL\" interaction. * `ONE_SHOT`: The user invokes the skill and states their intent in a single phrase. * `MODAL`: The user first invokes the skill and then states their intent.
     * @enum
     */
    type InteractionType = 'ONE_SHOT' | 'MODAL';
}
export declare namespace v1.skill.history {
    /**
     * The publication status of the skill when this interaction occurred
     * @enum
     */
    type PublicationStatus = 'Development' | 'Certification';
}
export declare namespace v1.skill.history {
    /**
     *
     * @interface
     */
    interface Slot {
        /**
         * Name of the slot that was used in this interaction.
         */
        'name'?: string;
    }
}
export declare namespace v1.skill.history {
    /**
     * A filter used to retrieve items where the locale is equal to the given value.
     * @enum
     */
    type LocaleInQuery = 'en-US' | 'en-GB' | 'en-IN' | 'en-CA' | 'en-AU' | 'de-DE' | 'ja-JP';
}
export declare namespace v1.skill.history {
    /**
     *
     * @enum
     */
    type SortFieldForIntentRequestType = 'recordCount' | 'intent.name' | 'intent.confidence.bin' | 'stage' | 'dialogAct.name' | 'locale' | 'utteranceText' | 'publicationStatus' | 'interactionType';
}
export declare namespace v1.skill {
    /**
     * Set of properties of the image provided by the customer.
     * @interface
     */
    interface ImageAttributes {
        'dimension'?: v1.skill.ImageDimension;
        'size'?: v1.skill.ImageSize;
        'maximumSize'?: v1.skill.ImageSize;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Enumerates delegation strategies used to control automatic dialog management through the defined dialog model. When no delegation strategies are defined, the value SKILL_RESPONSE is assumed.
     * @enum
     */
    type DelegationStrategyType = 'ALWAYS' | 'SKILL_RESPONSE';
}
export declare namespace v1.skill.interactionModel {
    /**
     * Defines dialog rules e.g. slot elicitation and validation, intent chaining etc.
     * @interface
     */
    interface Dialog {
        /**
         * Defines a delegation strategy for the dialogs in this dialog model.
         */
        'delegationStrategy'?: v1.skill.interactionModel.DelegationStrategyType;
        /**
         * List of intents that have dialog rules associated with them. Dialogs can also span multiple intents.
         */
        'intents': Array<v1.skill.interactionModel.DialogIntents>;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     *
     * @interface
     */
    interface DialogIntents {
        /**
         * Name of the intent that has a dialog specification.
         */
        'name': string;
        /**
         * Defines an intent-specific delegation strategy for this dialog intent. Overrides dialog-level setting.
         */
        'delegationStrategy'?: v1.skill.interactionModel.DelegationStrategyType;
        /**
         * List of slots that have dialog rules.
         */
        'slots'?: Array<v1.skill.interactionModel.DialogSlotItems>;
        /**
         * Describes whether confirmation of the intent is required.
         */
        'confirmationRequired'?: boolean;
        'prompts'?: v1.skill.interactionModel.DialogIntentsPrompts;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Collection of prompts for this intent.
     * @interface
     */
    interface DialogIntentsPrompts {
        /**
         * Enum value in the dialog_slots map to reference the elicitation prompt id.
         */
        'elicitation'?: string;
        /**
         * Enum value in the dialog_slots map to reference the confirmation prompt id.
         */
        'confirmation'?: string;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Dialog prompts associated with this slot i.e. for elicitation and/or confirmation.
     * @interface
     */
    interface DialogPrompts {
        /**
         * Reference to a prompt-id to use If this slot value is missing.
         */
        'elicitation'?: string;
        /**
         * Reference to a prompt-id to use to confirm the slots value.
         */
        'confirmation'?: string;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     *
     * @interface
     */
    interface DialogSlotItems {
        /**
         * The name of the slot that has dialog rules associated with it.
         */
        'name': string;
        /**
         * Type of the slot in the dialog intent.
         */
        'type': string;
        /**
         * Describes whether elicitation of the slot is required.
         */
        'elicitationRequired'?: boolean;
        /**
         * Describes whether confirmation of the slot is required.
         */
        'confirmationRequired'?: boolean;
        'prompts': v1.skill.interactionModel.DialogPrompts;
        /**
         * List of validations for the slot. if validation fails, user will be prompted with the provided prompt.
         */
        'validations'?: Array<v1.skill.interactionModel.SlotValidation>;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Denotes skill's sensitivity for out-of-domain utterances.
     * @interface
     */
    interface FallbackIntentSensitivity {
        'level': v1.skill.interactionModel.FallbackIntentSensitivityLevel;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Skill's sensitivity level for out-of-domain utterances. By default, the sensitivity level of the skill is set to ‘LOW’. As the sensitivity level for a skill is increased, more customer utterances that are not supported by the skill will be captured by AMAZON.FallbackIntent.
     * @enum
     */
    type FallbackIntentSensitivityLevel = 'HIGH' | 'MEDIUM' | 'LOW';
}
export declare namespace v1.skill.interactionModel {
    /**
     * The set of intents your service can accept and process.
     * @interface
     */
    interface Intent {
        /**
         * Name to identify the intent.
         */
        'name': string;
        /**
         * Name of the generator used to generate this object.
         */
        'generatedBy'?: string;
        /**
         * List of slots within the intent.
         */
        'slots'?: Array<v1.skill.interactionModel.SlotDefinition>;
        /**
         * Phrases the user can speak e.g. to trigger an intent or provide value for a slot elicitation.
         */
        'samples'?: Array<string>;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     *
     * @interface
     */
    interface InteractionModelData {
        'version'?: string;
        'description'?: string;
        'interactionModel': v1.skill.interactionModel.InteractionModelSchema;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     *
     * @interface
     */
    interface InteractionModelSchema {
        'languageModel': v1.skill.interactionModel.LanguageModel;
        'dialog'?: v1.skill.interactionModel.Dialog;
        /**
         * List of prompts.
         */
        'prompts'?: Array<v1.skill.interactionModel.Prompt>;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Global configurations applicable to a skill's model.
     * @interface
     */
    interface ModelConfiguration {
        'fallbackIntentSensitivity'?: v1.skill.interactionModel.FallbackIntentSensitivity;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Configuration object for multiple values capturing behavior for this slot.
     * @interface
     */
    interface MultipleValuesConfig {
        /**
         * Boolean that indicates whether this slot can capture multiple values.
         */
        'enabled': boolean;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     *
     * @interface
     */
    interface Prompt {
        /**
         * The prompt id, this id can be used from dialog definitions.
         */
        'id': string;
        /**
         * List of variations of the prompt, each variation can be either a text string or a well defined ssml string depending on the type defined.
         */
        'variations': Array<v1.skill.interactionModel.PromptItems>;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     *
     * @interface
     */
    interface PromptItems {
        'type'?: v1.skill.interactionModel.PromptItemsType;
        /**
         * Specifies the prompt.
         */
        'value': string;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Prompt can be specified in different formats e.g. text, ssml.
     * @enum
     */
    type PromptItemsType = 'SSML' | 'PlainText';
}
export declare namespace v1.skill.interactionModel {
    /**
     * Slot definition.
     * @interface
     */
    interface SlotDefinition {
        /**
         * The name of the slot.
         */
        'name': string;
        /**
         * The type of the slot. It can be a built-in or custom type.
         */
        'type'?: string;
        /**
         * Configuration object for multiple values capturing behavior for this slot.
         */
        'multipleValues'?: v1.skill.interactionModel.MultipleValuesConfig;
        /**
         * Phrases the user can speak e.g. to trigger an intent or provide value for a slot elicitation.
         */
        'samples'?: Array<string>;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Custom slot type to define a list of possible values for a slot. Used for items that are not covered by Amazon's built-in slot types.
     * @interface
     */
    interface SlotType {
        /**
         * The name of the custom slot type.
         */
        'name': string;
        /**
         * Name of the generator used to generate this object.
         */
        'generatedBy'?: string;
        /**
         * List of expected values. Values outside the list are still returned.
         */
        'values'?: Array<v1.skill.interactionModel.TypeValue>;
        'valueSupplier'?: v1.skill.interactionModel.ValueSupplier;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Validation on a slot with support for prompt and confirmation.
     * @interface
     */
    type SlotValidation = v1.skill.interactionModel.HasEntityResolutionMatch | v1.skill.interactionModel.IsLessThanOrEqualTo | v1.skill.interactionModel.IsGreaterThan | v1.skill.interactionModel.IsNotInSet | v1.skill.interactionModel.IsInDuration | v1.skill.interactionModel.IsLessThan | v1.skill.interactionModel.IsNotInDuration | v1.skill.interactionModel.IsGreaterThanOrEqualTo | v1.skill.interactionModel.IsInSet;
}
export declare namespace v1.skill.interactionModel {
    /**
     * The value schema in type object of interaction model.
     * @interface
     */
    interface TypeValue {
        'id'?: string;
        'name': v1.skill.interactionModel.TypeValueObject;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * The object that contains individual type values.
     * @interface
     */
    interface TypeValueObject {
        'value': string;
        'synonyms': Array<string>;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Catalog reference to provide values.
     * @interface
     */
    interface ValueCatalog {
        /**
         * CatalogId.
         */
        'catalogId': string;
        /**
         * Catalog version.
         */
        'version': string;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Supplier object to provide slot values.
     * @interface
     */
    type ValueSupplier = v1.skill.interactionModel.CatalogValueSupplier | v1.skill.interactionModel.InlineValueSupplier;
}
export declare namespace v1.skill.interactionModel.catalog {
    /**
     * Catalog request definitions.
     * @interface
     */
    interface CatalogDefinitionOutput {
        'catalog'?: v1.skill.interactionModel.catalog.CatalogEntity;
        /**
         * Time of the catalog definition creation.
         */
        'creationTime'?: string;
        /**
         * Total number of versions.
         */
        'totalVersions'?: string;
    }
}
export declare namespace v1.skill.interactionModel.catalog {
    /**
     * Definition for catalog entity.
     * @interface
     */
    interface CatalogEntity {
        /**
         * Name of the catalog.
         */
        'name'?: string;
        /**
         * Description string about the catalog.
         */
        'description'?: string;
    }
}
export declare namespace v1.skill.interactionModel.catalog {
    /**
     * Definition for catalog input.
     * @interface
     */
    interface CatalogInput {
        /**
         * Name of the catalog.
         */
        'name': string;
        /**
         * Description string about the catalog.
         */
        'description'?: string;
    }
}
export declare namespace v1.skill.interactionModel.catalog {
    /**
     * Definition for catalog entity.
     * @interface
     */
    interface CatalogItem {
        /**
         * Name of the catalog.
         */
        'name'?: string;
        /**
         * Description string about the catalog.
         */
        'description'?: string;
        /**
         * Identifier of the catalog, optional in get response as the request already has catalogId.
         */
        'catalogId'?: string;
        '_links'?: v1.Links;
    }
}
export declare namespace v1.skill.interactionModel.catalog {
    /**
     * CatalogId information.
     * @interface
     */
    interface CatalogResponse {
        /**
         * ID of the catalog created.
         */
        'catalogId'?: string;
    }
}
export declare namespace v1.skill.interactionModel.catalog {
    /**
     * Defines the structure for catalog status response.
     * @interface
     */
    interface CatalogStatus {
        'lastUpdateRequest'?: v1.skill.interactionModel.catalog.LastUpdateRequest;
    }
}
export declare namespace v1.skill.interactionModel.catalog {
    /**
     * Status of last modification request for a resource.
     * @enum
     */
    type CatalogStatusType = 'FAILED' | 'IN_PROGRESS' | 'SUCCEEDED';
}
export declare namespace v1.skill.interactionModel.catalog {
    /**
     * Catalog request definitions.
     * @interface
     */
    interface DefinitionData {
        'catalog': v1.skill.interactionModel.catalog.CatalogInput;
        /**
         * The vendorId that the catalog should belong to.
         */
        'vendorId': string;
    }
}
export declare namespace v1.skill.interactionModel.catalog {
    /**
     * Contains attributes related to last modification request of a resource.
     * @interface
     */
    interface LastUpdateRequest {
        'status'?: v1.skill.interactionModel.catalog.CatalogStatusType;
        /**
         * The version id of the entity returned.
         */
        'version'?: string;
        'errors'?: Array<v1.skill.StandardizedError>;
    }
}
export declare namespace v1.skill.interactionModel.catalog {
    /**
     * List of catalog versions of a skill for the vendor.
     * @interface
     */
    interface ListCatalogResponse {
        '_links'?: v1.Links;
        /**
         * List of catalogs.
         */
        'catalogs'?: Array<v1.skill.interactionModel.catalog.CatalogItem>;
        'isTruncated'?: boolean;
        'nextToken'?: string;
        'totalCount'?: number;
    }
}
export declare namespace v1.skill.interactionModel.catalog {
    /**
     * Catalog update request object.
     * @interface
     */
    interface UpdateRequest {
        /**
         * The catalog name.
         */
        'name': string;
        /**
         * The catalog description with a 255 character maximum.
         */
        'description': string;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Request to create job definitions.
     * @interface
     */
    interface CreateJobDefinitionRequest {
        /**
         * ID of the vendor owning the skill.
         */
        'vendorId'?: string;
        'jobDefinition'?: v1.skill.interactionModel.jobs.JobDefinition;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * The response of create job definition.
     * @interface
     */
    interface CreateJobDefinitionResponse {
        /**
         * Idenitifier of the job definition.
         */
        'jobId'?: string;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Error schema for dynamic update.
     * @interface
     */
    interface DynamicUpdateError {
        /**
         * Dynamic update error code.
         */
        'code'?: string;
        /**
         * Readable description of error.
         */
        'message'?: string;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Execution data.
     * @interface
     */
    interface Execution {
        /**
         * Identifier of the execution.
         */
        'executionId'?: string;
        /**
         * ISO date-time timestamp when the execution starts.
         */
        'timestamp'?: string;
        /**
         * ErrorCode to explain what went wrong in case of FAILUREs.
         */
        'errorCode'?: string;
        /**
         * Current status of the job execution.
         */
        'status'?: string;
        'errorDetails'?: v1.skill.interactionModel.jobs.JobErrorDetails;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * ExecutionMetadata for executions.
     * @interface
     */
    interface ExecutionMetadata {
        /**
         * Identifier of the job.
         */
        'jobId'?: string;
        /**
         * ErrorCode to explain what went wrong in case of FAILUREs.
         */
        'errorCode'?: string;
        /**
         * Current status of the job execution.
         */
        'status'?: string;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * The response of get execution history.
     * @interface
     */
    interface GetExecutionsResponse {
        'paginationContext'?: v1.skill.interactionModel.jobs.JobAPIPaginationContext;
        '_links'?: v1.Links;
        'executions'?: Array<v1.skill.interactionModel.jobs.Execution>;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     *
     * @interface
     */
    interface JobAPIPaginationContext {
        'nextToken'?: string;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Definition for dynamic job.
     * @interface
     */
    type JobDefinition = v1.skill.interactionModel.jobs.ReferenceVersionUpdate | v1.skill.interactionModel.jobs.CatalogAutoRefresh;
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Metadata of the job definition.
     * @interface
     */
    interface JobDefinitionMetadata {
        /**
         * Job identifier.
         */
        'id'?: string;
        /**
         * Polymorphic type of the job.
         */
        'type'?: string;
        'status'?: v1.skill.interactionModel.jobs.JobDefinitionStatus;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Current status of the job definition.
     * @enum
     */
    type JobDefinitionStatus = 'DISABLED' | 'ENALBED';
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Optional details if the execution is depending on other executions.
     * @interface
     */
    interface JobErrorDetails {
        'executionMetadata'?: Array<v1.skill.interactionModel.jobs.ExecutionMetadata>;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * The response of list job definitions.
     * @interface
     */
    interface ListJobDefinitionsResponse {
        'paginationContext'?: v1.skill.interactionModel.jobs.JobAPIPaginationContext;
        '_links'?: v1.Links;
        'jobs'?: Array<v1.skill.interactionModel.jobs.JobDefinitionMetadata>;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Resource object where the job is applied on.
     * @interface
     */
    type ResourceObject = v1.skill.interactionModel.jobs.InteractionModel | v1.skill.interactionModel.jobs.Catalog | v1.skill.interactionModel.jobs.SlotTypeReference;
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Condition when jobs will be executed.
     * @interface
     */
    type Trigger = v1.skill.interactionModel.jobs.ReferencedResourceJobsComplete | v1.skill.interactionModel.jobs.Scheduled;
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Update job status.
     * @interface
     */
    interface UpdateJobStatusRequest {
        'status': v1.skill.interactionModel.jobs.JobDefinitionStatus;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * The list of errors.
     * @interface
     */
    interface ValidationErrors {
        /**
         * The list of errors.
         */
        'errors'?: Array<v1.skill.interactionModel.jobs.DynamicUpdateError>;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Define the language model.
     * @interface
     */
    interface LanguageModel {
        /**
         * Invocation name of the skill.
         */
        'invocationName': string;
        'types'?: Array<v1.skill.interactionModel.SlotType>;
        'intents': Array<v1.skill.interactionModel.Intent>;
        'modelConfiguration'?: v1.skill.interactionModel.ModelConfiguration;
    }
}
export declare namespace v1.skill.interactionModel.type {
    /**
     * Slot type request definitions.
     * @interface
     */
    interface DefinitionData {
        'slotType'?: v1.skill.interactionModel.type.SlotTypeInput;
        /**
         * The vendorId that the slot type should belong to.
         */
        'vendorId'?: string;
    }
}
export declare namespace v1.skill.interactionModel.type {
    /**
     * The error which would fail requests.
     * @interface
     */
    interface Error {
        /**
         * The error code.
         */
        'code'?: string;
        /**
         * The error message.
         */
        'message'?: string;
    }
}
export declare namespace v1.skill.interactionModel.type {
    /**
     * Contains attributes related to last modification request of a resource.
     * @interface
     */
    interface LastUpdateRequest {
        'status'?: v1.skill.interactionModel.type.SlotTypeStatusType;
        /**
         * The version id of the entity returned.
         */
        'version'?: string;
        'errors'?: Array<v1.skill.interactionModel.type.Error>;
        'warnings'?: Array<v1.skill.interactionModel.type.Warning>;
    }
}
export declare namespace v1.skill.interactionModel.type {
    /**
     * List of slot types of a skill for the vendor.
     * @interface
     */
    interface ListSlotTypeResponse {
        '_links'?: v1.Links;
        /**
         * List of slot types.
         */
        'slotTypes'?: Array<v1.skill.interactionModel.type.SlotTypeItem>;
        'nextToken'?: string;
    }
}
export declare namespace v1.skill.interactionModel.type {
    /**
     * Slot Type request definitions.
     * @interface
     */
    interface SlotTypeDefinitionOutput {
        'slotType'?: v1.skill.interactionModel.type.SlotTypeInput;
        /**
         * Total number of versions.
         */
        'totalVersions'?: string;
    }
}
export declare namespace v1.skill.interactionModel.type {
    /**
     * Definition for slot type input.
     * @interface
     */
    interface SlotTypeInput {
        /**
         * Name of the slot type.
         */
        'name'?: string;
        /**
         * Description string about the slot type.
         */
        'description'?: string;
    }
}
export declare namespace v1.skill.interactionModel.type {
    /**
     * Definition for slot type entity.
     * @interface
     */
    interface SlotTypeItem {
        /**
         * Name of the slot type.
         */
        'name'?: string;
        /**
         * Description string about the slot type.
         */
        'description'?: string;
        /**
         * Identifier of the slot type, optional in get response as the request already has slotTypeId.
         */
        'id'?: string;
        '_links'?: v1.Links;
    }
}
export declare namespace v1.skill.interactionModel.type {
    /**
     * Slot Type information.
     * @interface
     */
    interface SlotTypeResponse {
        'slotType'?: v1.skill.interactionModel.type.SlotTypeResponseEntity;
    }
}
export declare namespace v1.skill.interactionModel.type {
    /**
     * SlotTypeId information.
     * @interface
     */
    interface SlotTypeResponseEntity {
        /**
         * ID of the slot type created.
         */
        'id'?: string;
    }
}
export declare namespace v1.skill.interactionModel.type {
    /**
     * Defines the structure for slot type status response.
     * @interface
     */
    interface SlotTypeStatus {
        'updateRequest'?: v1.skill.interactionModel.type.LastUpdateRequest;
    }
}
export declare namespace v1.skill.interactionModel.type {
    /**
     * Status of last modification request for a resource.
     * @enum
     */
    type SlotTypeStatusType = 'FAILED' | 'IN_PROGRESS' | 'SUCCEEDED';
}
export declare namespace v1.skill.interactionModel.type {
    /**
     * Slot type update definition object.
     * @interface
     */
    interface SlotTypeUpdateDefinition {
        /**
         * The slot type description with a 255 character maximum.
         */
        'description': string;
    }
}
export declare namespace v1.skill.interactionModel.type {
    /**
     * Slot type update request object.
     * @interface
     */
    interface UpdateRequest {
        'slotType'?: v1.skill.interactionModel.type.SlotTypeUpdateDefinition;
    }
}
export declare namespace v1.skill.interactionModel.type {
    /**
     * The warning which would not fail requests.
     * @interface
     */
    interface Warning {
        /**
         * The warning code.
         */
        'code'?: string;
        /**
         * The warning message.
         */
        'message'?: string;
    }
}
export declare namespace v1.skill.interactionModel.typeVersion {
    /**
     * List of slot type versions of a skill for the vendor.
     * @interface
     */
    interface ListSlotTypeVersionResponse {
        '_links'?: v1.Links;
        /**
         * List of slot types.
         */
        'slotTypeVersions'?: Array<v1.skill.interactionModel.typeVersion.SlotTypeVersionItem>;
        'nextToken'?: string;
    }
}
export declare namespace v1.skill.interactionModel.typeVersion {
    /**
     * Slot Type version data with metadata.
     * @interface
     */
    interface SlotTypeVersionData {
        'slotType'?: v1.skill.interactionModel.typeVersion.SlotTypeVersionDataObject;
    }
}
export declare namespace v1.skill.interactionModel.typeVersion {
    /**
     * Slot Type version fields with metadata.
     * @interface
     */
    interface SlotTypeVersionDataObject {
        /**
         * Slot type id associated with the slot type version.
         */
        'id'?: string;
        'definition'?: v1.skill.interactionModel.typeVersion.ValueSupplierObject;
        /**
         * Description string for specific slot type version.
         */
        'description'?: string;
        /**
         * Specific slot type version.
         */
        'version'?: string;
    }
}
export declare namespace v1.skill.interactionModel.typeVersion {
    /**
     * Definition for slot type entity.
     * @interface
     */
    interface SlotTypeVersionItem {
        /**
         * Version number of slot type.
         */
        'version'?: string;
        /**
         * Description string about the slot type version.
         */
        'description'?: string;
        '_links'?: v1.Links;
    }
}
export declare namespace v1.skill.interactionModel.typeVersion {
    /**
     * Value supplier object for slot definition.
     * @interface
     */
    interface ValueSupplierObject {
        'valueSupplier'?: v1.skill.interactionModel.ValueSupplier;
    }
}
export declare namespace v1.skill.interactionModel.typeVersion {
    /**
     * Slot Type version specific data.
     * @interface
     */
    interface VersionData {
        'slotType'?: v1.skill.interactionModel.typeVersion.VersionDataObject;
    }
}
export declare namespace v1.skill.interactionModel.typeVersion {
    /**
     * Slot Type version fields with specific data.
     * @interface
     */
    interface VersionDataObject {
        'definition'?: v1.skill.interactionModel.typeVersion.ValueSupplierObject;
        /**
         * Description string for specific slot type version.
         */
        'description'?: string;
    }
}
export declare namespace v1.skill.interactionModel.typeVersion {
    /**
     * Slot Type update description wrapper.
     * @interface
     */
    interface SlotTypeUpdate {
        'slotType'?: v1.skill.interactionModel.typeVersion.SlotTypeUpdateObject;
    }
}
export declare namespace v1.skill.interactionModel.typeVersion {
    /**
     * Slot Type update description object.
     * @interface
     */
    interface SlotTypeUpdateObject {
        /**
         * The slot type description with a 255 character maximum.
         */
        'description'?: string;
    }
}
export declare namespace v1.skill.interactionModel.version {
    /**
     * Version metadata about the catalog entity version.
     * @interface
     */
    interface CatalogEntityVersion {
        'version'?: string;
        'creationTime'?: string;
        'description'?: string;
        '_links'?: v1.skill.interactionModel.version.Links;
    }
}
export declare namespace v1.skill.interactionModel.version {
    /**
     * List of catalog values.
     * @interface
     */
    interface CatalogValues {
        'isTruncated'?: boolean;
        'nextToken'?: string;
        /**
         * Total number of catalog values.
         */
        'totalCount'?: number;
        '_links'?: v1.Links;
        'values'?: Array<v1.skill.interactionModel.version.ValueSchema>;
    }
}
export declare namespace v1.skill.interactionModel.version {
    /**
     * Catalog version data with metadata.
     * @interface
     */
    interface CatalogVersionData {
        'source'?: v1.skill.interactionModel.version.InputSource;
        /**
         * Description string for specific catalog version.
         */
        'description'?: string;
        /**
         * Specific catalog version.
         */
        'version'?: string;
    }
}
export declare namespace v1.skill.interactionModel.version {
    /**
     * Definition for catalog version input data.
     * @interface
     */
    interface InputSource {
        /**
         * Type of catalog.
         */
        'type'?: string;
        /**
         * Url to the catalog reference.
         */
        'url'?: string;
    }
}
export declare namespace v1.skill.interactionModel.version {
    /**
     *
     * @interface
     */
    interface Links {
        'self'?: v1.Link;
    }
}
export declare namespace v1.skill.interactionModel.version {
    /**
     * List of catalog versions of a catalog for the vendor in sortDirection order, descending as default.
     * @interface
     */
    interface ListCatalogEntityVersionsResponse {
        '_links'?: v1.skill.interactionModel.version.Links;
        /**
         * List of catalog entity versions.
         */
        'catalogVersions'?: Array<v1.skill.interactionModel.version.CatalogEntityVersion>;
        'isTruncated'?: boolean;
        'nextToken'?: string;
        'totalCount'?: number;
    }
}
export declare namespace v1.skill.interactionModel.version {
    /**
     * List of interactionModel versions of a skill for the vendor
     * @interface
     */
    interface ListResponse {
        '_links'?: v1.Links;
        /**
         * List of interaction model versions.
         */
        'skillModelVersions'?: Array<v1.skill.interactionModel.version.VersionItems>;
        'isTruncated'?: boolean;
        'nextToken'?: string;
    }
}
export declare namespace v1.skill.interactionModel.version {
    /**
     * The value schema in type object of interaction model.
     * @interface
     */
    interface ValueSchema {
        'id'?: string;
        'name'?: v1.skill.interactionModel.version.ValueSchemaName;
    }
}
export declare namespace v1.skill.interactionModel.version {
    /**
     *
     * @interface
     */
    interface ValueSchemaName {
        'value'?: string;
        'synonyms'?: Array<string>;
    }
}
export declare namespace v1.skill.interactionModel.version {
    /**
     * Catalog version specific data.
     * @interface
     */
    interface VersionData {
        'source': v1.skill.interactionModel.version.InputSource;
        /**
         * Description string for specific catalog version.
         */
        'description'?: string;
    }
}
export declare namespace v1.skill.interactionModel.version {
    /**
     * Version metadata about the entity.
     * @interface
     */
    interface VersionItems {
        'version'?: string;
        'creationTime'?: string;
        'description'?: string;
        '_links'?: v1.skill.interactionModel.version.Links;
    }
}
export declare namespace v1.skill.interactionModel.version {
    /**
     * Catalog update description object.
     * @interface
     */
    interface CatalogUpdate {
        /**
         * The catalog description with a 255 character maximum.
         */
        'description'?: string;
    }
}
export declare namespace v1.skill.invocations {
    /**
     * Region of endpoint to be called.
     * @enum
     */
    type EndPointRegions = 'NA' | 'EU' | 'FE';
}
export declare namespace v1.skill.invocations {
    /**
     *
     * @interface
     */
    interface InvocationResponseResult {
        'skillExecutionInfo'?: v1.skill.invocations.SkillExecutionInfo;
        'error'?: v1.skill.StandardizedError;
    }
}
export declare namespace v1.skill.invocations {
    /**
     * String that specifies the status of skill invocation. Possible values are \"SUCCEEDED\", and \"FAILED\".
     * @enum
     */
    type InvocationResponseStatus = 'SUCCEEDED' | 'FAILED';
}
export declare namespace v1.skill.invocations {
    /**
     *
     * @interface
     */
    interface InvokeSkillRequest {
        'endpointRegion': v1.skill.invocations.EndPointRegions;
        'skillRequest': v1.skill.invocations.SkillRequest;
    }
}
export declare namespace v1.skill.invocations {
    /**
     *
     * @interface
     */
    interface InvokeSkillResponse {
        'status'?: v1.skill.invocations.InvocationResponseStatus;
        'result'?: v1.skill.invocations.InvocationResponseResult;
    }
}
export declare namespace v1.skill.invocations {
    /**
     *
     * @interface
     */
    interface Metrics {
        /**
         * How long, in milliseconds, it took the skill's Lambda or HTTPS endpoint to process the request.
         */
        'skillExecutionTimeInMilliseconds'?: number;
    }
}
export declare namespace v1.skill.invocations {
    /**
     *
     * @interface
     */
    interface Request {
        /**
         * Skill's Lambda or HTTPS endpoint.
         */
        'endpoint'?: string;
        /**
         * JSON payload that was sent to the skill's Lambda or HTTPS endpoint.
         */
        'body'?: any;
    }
}
export declare namespace v1.skill.invocations {
    /**
     *
     * @interface
     */
    interface Response {
        /**
         * Payload that was returned by the skill's Lambda or HTTPS endpoint.
         */
        'body'?: any;
    }
}
export declare namespace v1.skill.invocations {
    /**
     *
     * @interface
     */
    interface SkillExecutionInfo {
        'invocationRequest'?: {
            [key: string]: v1.skill.invocations.Request;
        };
        'invocationResponse'?: {
            [key: string]: v1.skill.invocations.Response;
        };
        'metrics'?: {
            [key: string]: v1.skill.invocations.Metrics;
        };
    }
}
export declare namespace v1.skill.invocations {
    /**
     *
     * @interface
     */
    interface SkillRequest {
        /**
         * ASK request body schema as defined in the public facing documentation (https://developer.amazon.com/en-US/docs/alexa/custom-skills/request-and-response-json-reference.html#request-body-syntax)
         */
        'body': any;
    }
}
export declare namespace v1.skill.metrics {
    /**
     * Response object for the API call which contains metrics data.
     * @interface
     */
    interface GetMetricDataResponse {
        /**
         * The name of metric which customer requested.
         */
        'metric': string;
        /**
         * The timestamps for the data points.
         */
        'timestamps': Array<string>;
        /**
         * The data points for the metric corresponding to Timestamps.
         */
        'values': Array<number>;
        /**
         * A token that marks the next batch of returned results.
         */
        'nextToken'?: string;
    }
}
export declare namespace v1.skill.metrics {
    /**
     * A distinct set of logic which predictably returns a set of data.
     * @enum
     */
    type Metric = 'uniqueCustomers' | 'totalEnablements' | 'totalUtterances' | 'successfulUtterances' | 'failedUtterances' | 'totalSessions' | 'successfulSessions' | 'incompleteSessions' | 'userEndedSessions' | 'skillEndedSessions';
}
export declare namespace v1.skill.metrics {
    /**
     * The aggregation period to use when retrieving the metric, follows ISO_8601#Durations format.
     * @enum
     */
    type Period = 'SINGLE' | 'PT15M' | 'PT1H' | 'P1D';
}
export declare namespace v1.skill.metrics {
    /**
     * The type of the skill (custom, smartHome and flashBriefing).
     * @enum
     */
    type SkillType = 'custom' | 'smartHome' | 'flashBriefing';
}
export declare namespace v1.skill.metrics {
    /**
     * The stage of the skill (live, development).
     * @enum
     */
    type StageForMetric = 'live' | 'development';
}
export declare namespace v1.skill.nlu.annotationSets {
    /**
     *
     * @interface
     */
    interface AnnotationSetEntity {
        'locale'?: string;
        /**
         * Name of the NLU annotation set
         */
        'name'?: string;
        /**
         * Number of entries which represents number of utterances in each NLU annotation set content
         */
        'numberOfEntries'?: number;
        /**
         * The lastest updated timestamp for the NLU annotation set
         */
        'updatedTimestamp'?: string;
    }
}
export declare namespace v1.skill.nlu.annotationSets {
    /**
     *
     * @interface
     */
    interface CreateNLUAnnotationSetRequest {
        /**
         * The locale of the NLU annotation set
         */
        'locale': string;
        /**
         * The name of NLU annotation set provided by customer
         */
        'name': string;
    }
}
export declare namespace v1.skill.nlu.annotationSets {
    /**
     *
     * @interface
     */
    interface CreateNLUAnnotationSetResponse {
        /**
         * Id used to retrieve the NLU annotation set.
         */
        'id'?: string;
    }
}
export declare namespace v1.skill.nlu.annotationSets {
    /**
     * Links for the API navigation.
     * @interface
     */
    interface Links {
        'self'?: v1.Link;
        'next'?: v1.Link;
    }
}
export declare namespace v1.skill.nlu.annotationSets {
    /**
     *
     * @interface
     */
    interface ListNLUAnnotationSetsResponse {
        'annotationSets'?: Array<v1.skill.nlu.annotationSets.AnnotationSet>;
        'paginationContext'?: v1.skill.nlu.annotationSets.PaginationContext;
        '_links'?: v1.skill.nlu.annotationSets.Links;
    }
}
export declare namespace v1.skill.nlu.annotationSets {
    /**
     *
     * @interface
     */
    interface PaginationContext {
        /**
         * Opaque token returned if there are more results for the given inputs than `maxResults` from the request.
         */
        'nextToken'?: string;
    }
}
export declare namespace v1.skill.nlu.annotationSets {
    /**
     *
     * @interface
     */
    interface UpdateNLUAnnotationSetAnnotationsRequest {
    }
}
export declare namespace v1.skill.nlu.annotationSets {
    /**
     *
     * @interface
     */
    interface UpdateNLUAnnotationSetPropertiesRequest {
        /**
         * The name of NLU annotation set provided by customer
         */
        'name': string;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface Actual {
        'domain'?: string;
        'intent'?: v1.skill.nlu.evaluations.Intent;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     * An enumeration indicating whether the user has explicitly confirmed or denied the entire intent/slot. Possible values: 'NONE', 'CONFIRMED', 'DENIED'.
     * @enum
     */
    type ConfirmationStatus = 'NONE' | 'CONFIRMED' | 'DENIED';
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface EvaluateNLURequest {
        'stage': any;
        'locale': string;
        'source': v1.skill.nlu.evaluations.Source;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface EvaluateResponse {
        /**
         * Id used to retrieve the evaluation later.
         */
        'id'?: string;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface EvaluationEntity {
        'startTimestamp'?: string;
        'endTimestamp'?: string;
        'status'?: v1.skill.nlu.evaluations.Status;
        /**
         * Error message when evaluation job fails
         */
        'errorMessage'?: string;
        'inputs'?: v1.skill.nlu.evaluations.EvaluationInputs;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface EvaluationInputs {
        'locale'?: string;
        'stage'?: any;
        'source'?: v1.skill.nlu.evaluations.Source;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface Expected {
        'domain'?: string;
        'intent'?: v1.skill.nlu.evaluations.ExpectedIntent;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface ExpectedIntent {
        'name'?: string;
        'slots'?: {
            [key: string]: v1.skill.nlu.evaluations.ExpectedIntentSlotsProps;
        };
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface ExpectedIntentSlotsProps {
        'value'?: string;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface GetNLUEvaluationResponseLinks {
        'results'?: v1.skill.nlu.evaluations.Results;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface Inputs {
        'utterance'?: string;
        /**
         * Datetime to use to base date operations on.
         */
        'referenceTimestamp'?: string;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface Intent {
        'name'?: string;
        'confirmationStatus'?: v1.skill.nlu.evaluations.ConfirmationStatus;
        'slots'?: {
            [key: string]: v1.skill.nlu.evaluations.SlotsProps;
        };
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     * Links for the API navigation.
     * @interface
     */
    interface Links {
        'self'?: v1.Link;
        'next'?: v1.Link;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface PagedResponse {
        'paginationContext'?: v1.skill.nlu.evaluations.PaginationContext;
        '_links'?: v1.skill.nlu.evaluations.Links;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface PagedResultsResponse {
        'paginationContext'?: v1.skill.nlu.evaluations.PagedResultsResponsePaginationContext;
        '_links'?: v1.skill.nlu.evaluations.Links;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface PagedResultsResponsePaginationContext {
        /**
         * opaque token returned if there are more results for the given inputs than `maxResults` from the request.
         */
        'nextToken'?: string;
        /**
         * Total available results for the given query.
         */
        'totalCount'?: string;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface PaginationContext {
        /**
         * opaque token returned if there are more results for the given inputs than `maxResults` from the request.
         */
        'nextToken'?: string;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     * A resolutions object representing the results of resolving the words captured from the user's utterance.
     * @interface
     */
    interface Resolutions {
        /**
         * An array of objects representing each possible authority for entity resolution. An authority represents the source for the data provided for the slot. For a custom slot type, the authority is the slot type you defined.
         */
        'resolutionsPerAuthority'?: Array<{
            [key: string]: v1.skill.nlu.evaluations.ResolutionsPerAuthority;
        }>;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface ResolutionsPerAuthority {
        /**
         * The name of the authority for the slot values. For custom slot types, this authority label incorporates your skill ID and the slot type name.
         */
        'authority'?: string;
        'status'?: v1.skill.nlu.evaluations.ResolutionsPerAuthorityStatus;
        /**
         * An array of resolved values for the slot.
         */
        'values'?: Array<v1.skill.nlu.evaluations.ResolutionsPerAuthorityValue>;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface ResolutionsPerAuthorityStatus {
        /**
         * A code indicating the results of attempting to resolve the user utterance against the defined slot types. This can be one of the following: ER_SUCCESS_MATCH: The spoken value matched a value or synonym explicitly defined in your custom slot type. ER_SUCCESS_NO_MATCH: The spoken value did not match any values or synonyms explicitly defined in your custom slot type. ER_ERROR_TIMEOUT: An error occurred due to a timeout. ER_ERROR_EXCEPTION: An error occurred due to an exception during processing.
         */
        'code'?: v1.skill.nlu.evaluations.ResolutionsPerAuthorityStatusCode;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     * A code indicating the results of attempting to resolve the user utterance against the defined slot types. This can be one of the following: ER_SUCCESS_MATCH: The spoken value matched a value or synonym explicitly defined in your custom slot type. ER_SUCCESS_NO_MATCH: The spoken value did not match any values or synonyms explicitly defined in your custom slot type. ER_ERROR_TIMEOUT: An error occurred due to a timeout. ER_ERROR_EXCEPTION: An error occurred due to an exception during processing.
     * @enum
     */
    type ResolutionsPerAuthorityStatusCode = 'ER_SUCCESS_MATCH' | 'ER_SUCCESS_NO_MATCH' | 'ER_ERROR_TIMEOUT' | 'ER_ERROR_EXCEPTION';
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface ResolutionsPerAuthorityValue {
        /**
         * The string for the resolved slot value.
         */
        'name'?: string;
        /**
         * The unique ID defined for the resolved slot value. This is based on the IDs defined in the slot type definition.
         */
        'id'?: string;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface Results {
        /**
         * url to get the test case result details Example: /v1/skills/{skillId}/nluEvaluations/{evaluationId}/results
         */
        'href'?: string;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @enum
     */
    type ResultsStatus = 'PASSED' | 'FAILED';
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface SlotsProps {
        'name'?: string;
        'value'?: string;
        'confirmationStatus'?: v1.skill.nlu.evaluations.ConfirmationStatus;
        'resolutions'?: v1.skill.nlu.evaluations.Resolutions;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     * Use Annotation Set as evaluation source
     * @interface
     */
    interface Source {
        /**
         * ID of the annotation set
         */
        'annotationId'?: string;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @enum
     */
    type Status = 'PASSED' | 'FAILED' | 'IN_PROGRESS' | 'ERROR';
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface TestCase {
        'status'?: v1.skill.nlu.evaluations.ResultsStatus;
        'inputs'?: v1.skill.nlu.evaluations.Inputs;
        'actual'?: v1.skill.nlu.evaluations.Actual;
        'expected'?: Array<v1.skill.nlu.evaluations.Expected>;
    }
}
export declare namespace v1.skill.publication {
    /**
     *
     * @interface
     */
    interface PublishSkillRequest {
        /**
         * Used to determine when the skill Publishing should start. It takes the request timestamp as default value. The date range can be a maximum of upto 6 months from the current time stamp. The format should be the  RFC 3399 variant of ISO 8601. e.g 2019-04-12T23:20:50.52Z
         */
        'publishesAtDate'?: string;
    }
}
export declare namespace v1.skill.publication {
    /**
     *
     * @interface
     */
    interface SkillPublicationResponse {
        /**
         * Used to determine when the skill Publishing should start.
         */
        'publishesAtDate'?: string;
        'status'?: v1.skill.publication.SkillPublicationStatus;
    }
}
export declare namespace v1.skill.publication {
    /**
     * Status of publishing
     * @enum
     */
    type SkillPublicationStatus = 'IN_PROGRESS' | 'SUCCEEDED' | 'FAILED' | 'CANCELLED' | 'SCHEDULED';
}
export declare namespace v1.skill.resourceSchema {
    /**
     *
     * @interface
     */
    interface GetResourceSchemaResponse {
        /**
         * S3 presigned URL to schema location.
         */
        'schemaLocationUrl'?: string;
        /**
         * Timestamp when the schema location url expires in ISO 8601 format.
         */
        'expiryTime'?: string;
    }
}
export declare namespace v1.skill.simulations {
    /**
     *
     * @interface
     */
    interface AlexaExecutionInfo {
        'alexaResponses'?: Array<v1.skill.simulations.AlexaResponse>;
    }
}
export declare namespace v1.skill.simulations {
    /**
     *
     * @interface
     */
    interface AlexaResponse {
        /**
         * The type of Alexa response
         */
        'type'?: string;
        /**
         * The detail information needs to exposed in this type of Alexa response.
         */
        'content'?: v1.skill.simulations.AlexaResponseContent;
    }
}
export declare namespace v1.skill.simulations {
    /**
     *
     * @interface
     */
    interface AlexaResponseContent {
        /**
         * The plain text get from Alexa speech response
         */
        'caption'?: string;
    }
}
export declare namespace v1.skill.simulations {
    /**
     * Model of a virtual device used for simulation. This device object emulates attributes associated with a real Alexa enabled device.
     * @interface
     */
    interface Device {
        /**
         * A valid locale (e.g \"en-US\") for the virtual device used in simulation.
         */
        'locale': string;
    }
}
export declare namespace v1.skill.simulations {
    /**
     *
     * @interface
     */
    interface Input {
        /**
         * A string corresponding to the utterance text of what a customer would say to Alexa.
         */
        'content': string;
    }
}
export declare namespace v1.skill.simulations {
    /**
     *
     * @interface
     */
    interface Invocation {
        'invocationRequest'?: v1.skill.simulations.InvocationRequest;
        'invocationResponse'?: v1.skill.simulations.InvocationResponse;
        'metrics'?: v1.skill.simulations.Metrics;
    }
}
export declare namespace v1.skill.simulations {
    /**
     *
     * @interface
     */
    interface InvocationRequest {
        /**
         * Skill's Lambda or HTTPS endpoint.
         */
        'endpoint'?: string;
        /**
         * JSON payload that was sent to the skill's Lambda or HTTPS endpoint.
         */
        'body'?: {
            [key: string]: any;
        };
    }
}
export declare namespace v1.skill.simulations {
    /**
     *
     * @interface
     */
    interface InvocationResponse {
        /**
         * Payload that was returned by the skill's Lambda or HTTPS endpoint.
         */
        'body'?: {
            [key: string]: any;
        };
    }
}
export declare namespace v1.skill.simulations {
    /**
     *
     * @interface
     */
    interface Metrics {
        /**
         * How long, in milliseconds, it took the skill's Lambda or HTTPS endpoint to process the request.
         */
        'skillExecutionTimeInMilliseconds'?: number;
    }
}
export declare namespace v1.skill.simulations {
    /**
     * Session settings for running current simulation.
     * @interface
     */
    interface Session {
        'mode'?: v1.skill.simulations.SessionMode;
    }
}
export declare namespace v1.skill.simulations {
    /**
     * Indicate the session mode of the current simulation is using.
     * @enum
     */
    type SessionMode = 'DEFAULT' | 'FORCE_NEW_SESSION';
}
export declare namespace v1.skill.simulations {
    /**
     * Simulation settings for the current simulation request.
     * @interface
     */
    interface Simulation {
        'type'?: v1.skill.simulations.SimulationType;
    }
}
export declare namespace v1.skill.simulations {
    /**
     *
     * @interface
     */
    interface SimulationResult {
        'alexaExecutionInfo'?: v1.skill.simulations.AlexaExecutionInfo;
        'skillExecutionInfo'?: v1.skill.simulations.Invocation;
        'error'?: v1.Error;
    }
}
export declare namespace v1.skill.simulations {
    /**
     * String indicating the type of simulation request. Possible values are \"DEFAULT\" and \"NFI_ISOLATED_SIMULATION\". \"NFI_ISOLATED_SIMULATION\" is used to test the NFI(Name Free Interaction) enabled skills in isolation. This field is reserved for testing Name Free Interactions(NFI). Skills that are eligible to add NFI can only use this field. To learn more, visit https://developer.amazon.com/en-US/docs/alexa/custom-skills/understand-name-free-interaction-for-custom-skills.html
     * @enum
     */
    type SimulationType = 'DEFAULT' | 'NFI_ISOLATED_SIMULATION';
}
export declare namespace v1.skill.simulations {
    /**
     *
     * @interface
     */
    interface SimulationsApiRequest {
        'input': v1.skill.simulations.Input;
        'device': v1.skill.simulations.Device;
        'session'?: v1.skill.simulations.Session;
        'simulation'?: v1.skill.simulations.Simulation;
    }
}
export declare namespace v1.skill.simulations {
    /**
     *
     * @interface
     */
    interface SimulationsApiResponse {
        /**
         * Id of the simulation resource.
         */
        'id'?: string;
        'status'?: v1.skill.simulations.SimulationsApiResponseStatus;
        'result'?: v1.skill.simulations.SimulationResult;
    }
}
export declare namespace v1.skill.simulations {
    /**
     * String that specifies the current status of the simulation. Possible values are \"IN_PROGRESS\", \"SUCCESSFUL\", and \"FAILED\".
     * @enum
     */
    type SimulationsApiResponseStatus = 'IN_PROGRESS' | 'SUCCESSFUL' | 'FAILED';
}
export declare namespace v1.skill {
    /**
     *
     * @enum
     */
    type SkillResourcesEnum = 'manifest' | 'interactionModel' | 'hostedSkillDeployment' | 'hostedSkillProvisioning';
}
export declare namespace v1.skill {
    /**
     *
     * @interface
     */
    interface UpdateSkillWithPackageRequest {
        /**
         * The URL for the skill package.
         */
        'location': string;
    }
}
export declare namespace v1.skill {
    /**
     * Standardized, machine readable structure that wraps all the information about a specific occurrence of an error of the type specified by the code.
     * @interface
     */
    interface ValidationDetails {
        /**
         * Set of properties of the image provided by the customer.
         */
        'actualImageAttributes'?: v1.skill.ImageAttributes;
        /**
         * Number of items in an array provided by the customer.
         */
        'actualNumberOfItems'?: number;
        /**
         * Number of characters in a string provided by the customer.
         */
        'actualStringLength'?: number;
        /**
         * List of allowed content types for a resource.
         */
        'allowedContentTypes'?: Array<string>;
        /**
         * List of allowed data types for an instance.
         */
        'allowedDataTypes'?: Array<v1.skill.ValidationDataTypes>;
        /**
         * List of set of properties representing all possible allowed images.
         */
        'allowedImageAttributes'?: Array<v1.skill.ImageAttributes>;
        /**
         * Instance conflicting with another instance.
         */
        'conflictingInstance'?: v1.skill.Instance;
        /**
         * Format in which instance value is expected in.
         */
        'expectedFormat'?: v1.skill.Format;
        /**
         * Instance that is expected by a related instance.
         */
        'expectedInstance'?: v1.skill.Instance;
        /**
         * Regular expression that a string instance is expected to match.
         */
        'expectedRegexPattern'?: string;
        /**
         * Type of the agreement that the customer must be compliant to.
         */
        'agreementType'?: v1.skill.AgreementType;
        /**
         * Properties of a publicly known feature that has restricted access.
         */
        'feature'?: v1.skill.ValidationFeature;
        /**
         * Endpoint which has a different value for property named type when compared to original endpoint.
         */
        'inconsistentEndpoint'?: v1.skill.ValidationEndpoint;
        /**
         * Minimum allowed value of an integer instance.
         */
        'minimumIntegerValue'?: number;
        /**
         * Minimum allowed number of items in an array.
         */
        'minimumNumberOfItems'?: number;
        /**
         * Minimum allowed number of characters in a string.
         */
        'minimumStringLength'?: number;
        /**
         * Maximum allowed value of an integer instance.
         */
        'maximumIntegerValue'?: number;
        /**
         * Maximum allowed number of items in an array.
         */
        'maximumNumberOfItems'?: number;
        /**
         * Maximum allowed number of characters in a string.
         */
        'maximumStringLength'?: number;
        /**
         * An Endpoint instance
         */
        'originalEndpoint'?: v1.skill.ValidationEndpoint;
        /**
         * An Instance
         */
        'originalInstance'?: v1.skill.Instance;
        /**
         * Represents what is wrong in the request.
         */
        'reason'?: v1.skill.ValidationFailureReason;
        /**
         * Property required but missing in the object.
         */
        'requiredProperty'?: string;
        /**
         * Property not expected but present in the object.
         */
        'unexpectedProperty'?: string;
    }
}
export declare namespace v1.skill.validations {
    /**
     *
     * @interface
     */
    interface ResponseValidation {
        /**
         * Short, human readable title of the validation performed.
         */
        'title'?: string;
        /**
         * Human readable description of the validation performed. May include instructions to address validation failure.
         */
        'description'?: string;
        /**
         * Dot-delimited category.
         */
        'category'?: string;
        /**
         * Locale of the validation.
         */
        'locale'?: string;
        'importance'?: v1.skill.validations.ResponseValidationImportance;
        'status'?: v1.skill.validations.ResponseValidationStatus;
    }
}
export declare namespace v1.skill.validations {
    /**
     * String that specifies importance of the validation. Possible values are \"REQUIRED\" and \"RECOMMENDED\"
     * @enum
     */
    type ResponseValidationImportance = 'REQUIRED' | 'RECOMMENDED';
}
export declare namespace v1.skill.validations {
    /**
     * String that specifies status of the validation. Possible values are \"SUCCESSFUL\" and \"FAILED\"
     * @enum
     */
    type ResponseValidationStatus = 'SUCCESSFUL' | 'FAILED';
}
export declare namespace v1.skill.validations {
    /**
     *
     * @interface
     */
    interface ValidationsApiRequest {
        'locales': Array<string>;
    }
}
export declare namespace v1.skill.validations {
    /**
     *
     * @interface
     */
    interface ValidationsApiResponse {
        /**
         * Id of the validation resource.
         */
        'id'?: string;
        'status'?: v1.skill.validations.ValidationsApiResponseStatus;
        'result'?: v1.skill.validations.ValidationsApiResponseResult;
    }
}
export declare namespace v1.skill.validations {
    /**
     *
     * @interface
     */
    interface ValidationsApiResponseResult {
        'validations'?: Array<v1.skill.validations.ResponseValidation>;
        'error'?: v1.Error;
    }
}
export declare namespace v1.skill.validations {
    /**
     * String that specifies the current status of validation execution. Possible values are \"IN_PROGRESS\", \"SUCCESSFUL\", and \"FAILED\".
     * @enum
     */
    type ValidationsApiResponseStatus = 'IN_PROGRESS' | 'SUCCESSFUL' | 'FAILED';
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface CapabilityTestPlan {
        'id'?: string;
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface Endpoint {
        'endpointId'?: string;
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface EvaluateSHCapabilityRequest {
        'capabilityTestPlan': v1.smartHomeEvaluation.CapabilityTestPlan;
        'endpoint': v1.smartHomeEvaluation.Endpoint;
        'stage': v1.smartHomeEvaluation.Stage;
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @enum
     */
    type EvaluationEntityStatus = 'PASSED' | 'FAILED' | 'IN_PROGRESS' | 'ERROR';
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface EvaluationObject {
        'endTimestamp'?: string;
        'startTimestamp'?: string;
        'status'?: v1.smartHomeEvaluation.EvaluationEntityStatus;
        'endpointId'?: string;
        'id'?: string;
        'sourceTestPlanIds'?: Array<string>;
        'testPlanId'?: string;
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface GetSHCapabilityEvaluationResponse {
        'endTimestamp'?: string;
        'startTimestamp'?: string;
        'status'?: v1.smartHomeEvaluation.EvaluationEntityStatus;
        'error'?: v1.smartHomeEvaluation.SHCapabilityError;
        'input'?: v1.smartHomeEvaluation.EvaluateSHCapabilityRequest;
        'metrics'?: {
            [key: string]: v1.smartHomeEvaluation.SHEvaluationResultsMetric;
        };
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface ListSHCapabilityEvaluationsResponse {
        'paginationContextToken'?: v1.smartHomeEvaluation.PaginationContextToken;
        'evaluations'?: Array<v1.smartHomeEvaluation.EvaluationObject>;
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface ListSHTestPlanItem {
        'id'?: string;
        'name'?: string;
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface PagedResponse {
        'paginationContext'?: v1.smartHomeEvaluation.PaginationContext;
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface SHCapabilityDirective {
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface SHCapabilityError {
        'code'?: v1.smartHomeEvaluation.SHCapabilityErrorCode;
        'message'?: string;
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @enum
     */
    type SHCapabilityErrorCode = 'NO_SUCH_ENDPOINT' | 'NO_SUCH_SKILL_STAGE' | 'NO_SUCH_TEST_PLAN' | 'MULTIPLE_MATCHED_ENDPOINTS' | 'MULTIPLE_MATCHED_TEST_PLANS' | 'CAPABILITY_NOT_SUPPORTED' | 'DISCOVERY_FAILED' | 'TEST_CASE_TIME_OUT';
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface SHCapabilityResponse {
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface SHCapabilityState {
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface SHEvaluationResultsMetric {
        'errorTestCases'?: number;
        'failedTestCases'?: number;
        'passedTestCases'?: number;
        'totalTestCases'?: number;
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @enum
     */
    type Stage = 'development' | 'live';
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface TestCaseResult {
        'actualCapabilityStates'?: Array<v1.smartHomeEvaluation.SHCapabilityState>;
        'actualResponse'?: v1.smartHomeEvaluation.SHCapabilityResponse;
        'directive'?: v1.smartHomeEvaluation.SHCapabilityDirective;
        'error'?: v1.smartHomeEvaluation.SHCapabilityError;
        'expectedCapabilityStates'?: Array<v1.smartHomeEvaluation.SHCapabilityState>;
        'expectedResponse'?: v1.smartHomeEvaluation.SHCapabilityResponse;
        'name'?: string;
        'status'?: v1.smartHomeEvaluation.TestCaseResultStatus;
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @enum
     */
    type TestCaseResultStatus = 'PASSED' | 'FAILED' | 'ERROR';
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface PaginationContext {
        'nextToken'?: string;
        'totalCount'?: number;
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface PaginationContextToken {
        'nextToken'?: string;
    }
}
export declare namespace v1.vendorManagement {
    /**
     * Vendor Response Object.
     * @interface
     */
    interface Vendor {
        /**
         * Name of vendor.
         */
        'name'?: string;
        /**
         * Unique identifier of vendor associated with the API caller account.
         */
        'id'?: string;
        /**
         * Roles that user has for this vendor.
         */
        'roles'?: Array<string>;
    }
}
export declare namespace v1.vendorManagement {
    /**
     * List of Vendors.
     * @interface
     */
    interface Vendors {
        'vendors'?: Array<v1.vendorManagement.Vendor>;
    }
}
export declare namespace v2 {
    /**
     *
     * @interface
     */
    interface BadRequestError {
        /**
         * Human readable description of error.
         */
        'message'?: string;
        /**
         * An array of violation messages.
         */
        'violations'?: Array<v2.Error>;
    }
}
export declare namespace v2 {
    /**
     *
     * @interface
     */
    interface Error {
        /**
         * Error code that maps to an error message. Developers with different locales should be able to lookup the error description based on this code.
         */
        'code'?: string;
        /**
         * Readable description of error.
         */
        'message': string;
    }
}
export declare namespace v2.skill {
    /**
     *
     * @interface
     */
    interface Invocation {
        'invocationRequest'?: v2.skill.InvocationRequest;
        'invocationResponse'?: v2.skill.InvocationResponse;
        'metrics'?: v2.skill.Metrics;
    }
}
export declare namespace v2.skill {
    /**
     *
     * @interface
     */
    interface InvocationRequest {
        /**
         * Skill's Lambda or HTTPS endpoint.
         */
        'endpoint'?: string;
        /**
         * JSON payload that was sent to the skill's Lambda or HTTPS endpoint.
         */
        'body'?: {
            [key: string]: any;
        };
    }
}
export declare namespace v2.skill {
    /**
     *
     * @interface
     */
    interface InvocationResponse {
        /**
         * Payload that was returned by the skill's Lambda or HTTPS endpoint.
         */
        'body'?: {
            [key: string]: any;
        };
    }
}
export declare namespace v2.skill {
    /**
     *
     * @interface
     */
    interface Metrics {
        /**
         * How long, in milliseconds, it took the skill's Lambda or HTTPS endpoint to process the request.
         */
        'skillExecutionTimeInMilliseconds'?: number;
    }
}
export declare namespace v2.skill.invocations {
    /**
     * Region of endpoint to be called.
     * @enum
     */
    type EndPointRegions = 'NA' | 'EU' | 'FE' | 'default';
}
export declare namespace v2.skill.invocations {
    /**
     *
     * @interface
     */
    interface InvocationResponseResult {
        'skillExecutionInfo'?: v2.skill.Invocation;
        'error'?: v2.Error;
    }
}
export declare namespace v2.skill.invocations {
    /**
     * String that specifies the status of skill invocation. Possible values are \"SUCCESSFUL\", and \"FAILED\".
     * @enum
     */
    type InvocationResponseStatus = 'SUCCESSFUL' | 'FAILED';
}
export declare namespace v2.skill.invocations {
    /**
     *
     * @interface
     */
    interface InvocationsApiResponse {
        'status'?: v2.skill.invocations.InvocationResponseStatus;
        'result'?: v2.skill.invocations.InvocationResponseResult;
    }
}
export declare namespace v2.skill.invocations {
    /**
     *
     * @interface
     */
    interface SkillRequest {
        /**
         * ASK request body schema as defined in the public facing documentation (https://developer.amazon.com/en-US/docs/alexa/custom-skills/request-and-response-json-reference.html#request-body-syntax)
         */
        'body': any;
    }
}
export declare namespace v2.skill.invocations {
    /**
     *
     * @interface
     */
    interface InvocationsApiRequest {
        'endpointRegion': v2.skill.invocations.EndPointRegions;
        'skillRequest': v2.skill.invocations.SkillRequest;
    }
}
export declare namespace v2.skill.simulations {
    /**
     *
     * @interface
     */
    interface AlexaExecutionInfo {
        'alexaResponses'?: Array<v2.skill.simulations.AlexaResponse>;
        'consideredIntents'?: Array<v2.skill.simulations.Intent>;
    }
}
export declare namespace v2.skill.simulations {
    /**
     *
     * @interface
     */
    interface AlexaResponse {
        /**
         * The type of Alexa response
         */
        'type'?: string;
        /**
         * The detail information needs to exposed in this type of Alexa response.
         */
        'content'?: v2.skill.simulations.AlexaResponseContent;
    }
}
export declare namespace v2.skill.simulations {
    /**
     *
     * @interface
     */
    interface AlexaResponseContent {
        /**
         * The plain text from Alexa speech response.
         */
        'caption'?: string;
    }
}
export declare namespace v2.skill.simulations {
    /**
     * An enumeration indicating whether the user has explicitly confirmed or denied the entire intent. Possible values: \"NONE\", \"CONFIRMED\", \"DENIED\".
     * @enum
     */
    type ConfirmationStatusType = 'NONE' | 'CONFIRMED' | 'DENIED';
}
export declare namespace v2.skill.simulations {
    /**
     * Model of a virtual device used for simulation. This device object emulates attributes associated with a real Alexa enabled device.
     * @interface
     */
    interface Device {
        /**
         * A valid locale (e.g \"en-US\") for the virtual device used in simulation.
         */
        'locale': string;
    }
}
export declare namespace v2.skill.simulations {
    /**
     *
     * @interface
     */
    interface Input {
        /**
         * A string corresponding to the utterance text of what a customer would say to Alexa.
         */
        'content': string;
    }
}
export declare namespace v2.skill.simulations {
    /**
     *
     * @interface
     */
    interface Intent {
        'name'?: string;
        'confirmationStatus'?: v2.skill.simulations.ConfirmationStatusType;
        /**
         * A map of key-value pairs that further describes what the user meant based on a predefined intent schema. The map can be empty.
         */
        'slots'?: {
            [key: string]: v2.skill.simulations.Slot;
        };
    }
}
export declare namespace v2.skill.simulations {
    /**
     *
     * @interface
     */
    interface ResolutionsPerAuthorityItems {
        /**
         * The name of the authority for the slot values. For custom slot types, this authority label incorporates your skill ID and the slot type name.
         */
        'authority'?: string;
        'status'?: v2.skill.simulations.ResolutionsPerAuthorityStatus;
        /**
         * An array of resolved values for the slot.
         */
        'values'?: Array<v2.skill.simulations.ResolutionsPerAuthorityValueItems>;
    }
}
export declare namespace v2.skill.simulations {
    /**
     * An object representing the status of entity resolution for the slot.
     * @interface
     */
    interface ResolutionsPerAuthorityStatus {
        'code'?: v2.skill.simulations.ResolutionsPerAuthorityStatusCode;
    }
}
export declare namespace v2.skill.simulations {
    /**
     * A code indicating the results of attempting to resolve the user utterance against the defined slot types. This can be one of the following: ER_SUCCESS_MATCH: The spoken value matched a value or synonym explicitly defined in your custom slot type. ER_SUCCESS_NO_MATCH: The spoken value did not match any values or synonyms explicitly defined in your custom slot type. ER_ERROR_TIMEOUT: An error occurred due to a timeout. ER_ERROR_EXCEPTION: An error occurred due to an exception during processing.
     * @enum
     */
    type ResolutionsPerAuthorityStatusCode = 'ER_SUCCESS_MATCH' | 'ER_SUCCESS_NO_MATCH' | 'ER_ERROR_TIMEOUT' | 'ER_ERROR_EXCEPTION';
}
export declare namespace v2.skill.simulations {
    /**
     * An object representing the resolved value for the slot, based on the user's utterance and the slot type definition.
     * @interface
     */
    interface ResolutionsPerAuthorityValueItems {
        /**
         * The string for the resolved slot value.
         */
        'name'?: string;
        /**
         * The unique ID defined for the resolved slot value. This is based on the IDs defined in the slot type definition.
         */
        'id'?: string;
    }
}
export declare namespace v2.skill.simulations {
    /**
     * Session settings for running current simulation.
     * @interface
     */
    interface Session {
        'mode'?: v2.skill.simulations.SessionMode;
    }
}
export declare namespace v2.skill.simulations {
    /**
     * Indicate the session mode of the current simulation is using.
     * @enum
     */
    type SessionMode = 'DEFAULT' | 'FORCE_NEW_SESSION';
}
export declare namespace v2.skill.simulations {
    /**
     * Simulation settings for the current simulation request.
     * @interface
     */
    interface Simulation {
        'type'?: v2.skill.simulations.SimulationType;
    }
}
export declare namespace v2.skill.simulations {
    /**
     *
     * @interface
     */
    interface SimulationResult {
        'alexaExecutionInfo'?: v2.skill.simulations.AlexaExecutionInfo;
        'skillExecutionInfo'?: v2.skill.simulations.SkillExecutionInfo;
        'error'?: v2.Error;
    }
}
export declare namespace v2.skill.simulations {
    /**
     * String indicating the type of simulation request. Possible values are \"DEFAULT\" and \"NFI_ISOLATED_SIMULATION\". \"NFI_ISOLATED_SIMULATION\" is used to test the NFI(Name Free Interaction) enabled skills in isolation. This field is reserved for testing Name Free Interactions(NFI). Skills that are eligible to add NFI can only use this field. To learn more, visit https://developer.amazon.com/en-US/docs/alexa/custom-skills/understand-name-free-interaction-for-custom-skills.html
     * @enum
     */
    type SimulationType = 'DEFAULT' | 'NFI_ISOLATED_SIMULATION';
}
export declare namespace v2.skill.simulations {
    /**
     *
     * @interface
     */
    interface SimulationsApiRequest {
        'input': v2.skill.simulations.Input;
        'device': v2.skill.simulations.Device;
        'session'?: v2.skill.simulations.Session;
        'simulation'?: v2.skill.simulations.Simulation;
    }
}
export declare namespace v2.skill.simulations {
    /**
     *
     * @interface
     */
    interface SimulationsApiResponse {
        /**
         * Id of the simulation resource.
         */
        'id'?: string;
        'status'?: v2.skill.simulations.SimulationsApiResponseStatus;
        'result'?: v2.skill.simulations.SimulationResult;
    }
}
export declare namespace v2.skill.simulations {
    /**
     * String that specifies the current status of the simulation. Possible values are \"IN_PROGRESS\", \"SUCCESSFUL\", and \"FAILED\".
     * @enum
     */
    type SimulationsApiResponseStatus = 'IN_PROGRESS' | 'SUCCESSFUL' | 'FAILED';
}
export declare namespace v2.skill.simulations {
    /**
     *
     * @interface
     */
    interface SkillExecutionInfo {
        'invocations'?: Array<v2.skill.Invocation>;
    }
}
export declare namespace v2.skill.simulations {
    /**
     *
     * @interface
     */
    interface Slot {
        'name'?: string;
        'value'?: string;
        'confirmationStatus'?: v2.skill.simulations.ConfirmationStatusType;
        'resolutions'?: v2.skill.simulations.SlotResolutions;
    }
}
export declare namespace v2.skill.simulations {
    /**
     * A resolutions object representing the results of resolving the words captured from the user's utterance.
     * @interface
     */
    interface SlotResolutions {
        /**
         * An array of objects representing each possible authority for entity resolution. An authority represents the source for the data provided for the slot. For a custom slot type, the authority is the slot type you defined.
         */
        'resolutionsPerAuthority'?: Array<v2.skill.simulations.ResolutionsPerAuthorityItems>;
    }
}
export declare namespace v0.catalog.upload {
    /**
     * Request body for self-hosted catalog uploads.
     * @interface
     */
    interface CreateContentUploadResponse {
        /**
         * Unique identifier of the upload.
         */
        'id'?: string;
        /**
         * Provides a unique identifier of the catalog.
         */
        'catalogId'?: string;
        'status'?: v0.catalog.upload.UploadStatus;
        'createdDate'?: string;
        'lastUpdatedDate'?: string;
        'ingestionSteps'?: Array<v0.catalog.upload.UploadIngestionStep>;
        /**
         * Ordered list of presigned upload parts to perform a partitioned (multipart) file upload.
         */
        'presignedUploadParts'?: Array<v0.catalog.upload.PresignedUploadPart>;
    }
}
export declare namespace v0.catalog.upload {
    /**
     * Response object for get content upload request.
     * @interface
     */
    interface GetContentUploadResponse {
        /**
         * Unique identifier of the upload.
         */
        'id'?: string;
        /**
         * Provides a unique identifier of the catalog.
         */
        'catalogId'?: string;
        'status'?: v0.catalog.upload.UploadStatus;
        'createdDate'?: string;
        'lastUpdatedDate'?: string;
        'file'?: v0.catalog.upload.ContentUploadFileSummary;
        'ingestionSteps'?: Array<v0.catalog.upload.UploadIngestionStep>;
    }
}
export declare namespace v0.developmentEvents.subscriber {
    /**
     * Authorization for accessing AWS SNS endpoint.
     * @interface
     */
    interface EndpointAwsAuthorization {
        'type': 'AWS_IAM';
        /**
         * IAM Role arn to use/assumeRole for authorization.
         */
        'arn'?: string;
    }
}
export declare namespace v0.eventSchema.AlexaCustomerFeedbackEvent {
    /**
     * 'AlexaCustomerFeedbackEvent.SkillReviewPublish' event represents the publishing of a new/updated customer review for a skill.
     * @interface
     */
    interface SkillReviewPublish {
        'eventName': 'AlexaCustomerFeedbackEvent.SkillReviewPublish';
        /**
         * ISO 8601 timestamp for the instant when event was created.
         */
        'timestamp'?: string;
        'payload'?: v0.eventSchema.SkillReviewEventAttributes;
    }
}
export declare namespace v0.eventSchema.AlexaDevelopmentEvent {
    /**
     * 'AlexaDevelopmentEvent.InteractionModelUpdate' event represents the status of set/update interaction model request. The update request may complete either with `SUCCEEDED` or `FAILED` status.
     * @interface
     */
    interface InteractionModelUpdate {
        'eventName': 'AlexaDevelopmentEvent.InteractionModelUpdate';
        /**
         * ISO 8601 timestamp for the instant when event was created.
         */
        'timestamp'?: string;
        /**
         * A development notification includes a unique identifier that identifies the original request that resulted in the development notification. The requestId for original request is returned by Amazon APIs in response's 'X-Amzn-RequestId' header.
         */
        'requestId'?: string;
        'payload'?: v0.eventSchema.InteractionModelEventAttributes;
    }
}
export declare namespace v0.eventSchema.AlexaDevelopmentEvent {
    /**
     * 'AlexaDevelopmentEvent.ManifestUpdate' event represents the status of the update request on the Manifest. This event is generated when request to create a skill or update an existing skill is completed. The request may complete either with `SUCCEEDED` or `FAILED` status.
     * @interface
     */
    interface ManifestUpdate {
        'eventName': 'AlexaDevelopmentEvent.ManifestUpdate';
        /**
         * ISO 8601 timestamp for the instant when event was created.
         */
        'timestamp'?: string;
        /**
         * A development notification includes a unique identifier that identifies the original request that resulted in the development notification. The requestId for original request is returned by Amazon APIs in response's 'X-Amzn-RequestId' header.
         */
        'requestId'?: string;
        'payload'?: v0.eventSchema.SkillEventAttributes;
    }
}
export declare namespace v0.eventSchema.AlexaDevelopmentEvent {
    /**
     * 'AlexaDevelopmentEvent.SkillCertification' event represents the status of various validations of `certification workflow`. This step may complete either with `SUCCEEDED` or `FAILED` status.
     * @interface
     */
    interface SkillCertification {
        'eventName': 'AlexaDevelopmentEvent.SkillCertification';
        /**
         * ISO 8601 timestamp for the instant when event was created.
         */
        'timestamp'?: string;
        /**
         * A development notification includes a unique identifier that identifies the original request that resulted in the development notification. The requestId for original request is returned by Amazon APIs in response's 'X-Amzn-RequestId' header.
         */
        'requestId'?: string;
        'payload'?: v0.eventSchema.SkillEventAttributes;
    }
}
export declare namespace v0.eventSchema.AlexaDevelopmentEvent {
    /**
     * 'AlexaDevelopmentEvent.SkillPublish' event represents the status of publish to live operation. When a developer submits a skill for certification, it goes through `certification workflow` followed by publish to live workflow. This event is generated in publish workflow and may complete either with `SUCCEEDED` or `FAILED` status. If 'SUCCEEDED', users can see and enable latest version of the skill via Alexa Skill Store.
     * @interface
     */
    interface SkillPublish {
        'eventName': 'AlexaDevelopmentEvent.SkillPublish';
        /**
         * ISO 8601 timestamp for the instant when event was created.
         */
        'timestamp'?: string;
        /**
         * A development notification includes a unique identifier that identifies the original request that resulted in the development notification. The requestId for original request is returned by Amazon APIs in response's 'X-Amzn-RequestId' header.
         */
        'requestId'?: string;
        'payload'?: v0.eventSchema.SkillEventAttributes;
    }
}
export declare namespace v0.eventSchema {
    /**
     * Represents a set of attributes specific to interaction model of an Alexa Skill.
     * @interface
     */
    interface InteractionModelAttributes {
        /**
         * Unique identifier of an Alexa skill.
         */
        'skillId'?: string;
        /**
         * Unique identifier of vendor account to which this skill belongs.
         */
        'vendorId'?: string;
        /**
         * Locale of interaction model.
         */
        'locale'?: string;
    }
}
export declare namespace v1.catalog.upload {
    /**
     * Request body for self-hosted catalog uploads
     * @interface
     */
    interface Location {
        /**
         * self hosted url location.
         */
        'location'?: string;
    }
}
export declare namespace v1.catalog.upload {
    /**
     * Request body for self-hosted catalog uploads
     * @interface
     */
    interface PreSignedUrl {
        /**
         * Unique identifier for urls
         */
        'urlId': string;
        /**
         * List of (eTag, part number) pairs for each part of the file uploaded
         */
        'partETags'?: Array<v1.catalog.upload.PreSignedUrlItem>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * The type of dialog manager:  * AMAZON.Conversations - The Alexa Conversations (Coltrane) model for this skill.
     * @interface
     */
    interface AMAZONConversationsDialogManager {
        'type': 'AMAZON.Conversations';
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Skill use this interface to support functionality related to data store packages.
     * @interface
     */
    interface AlexaDataStorePackageManagerInterface {
        'type': 'ALEXA_DATASTORE_PACKAGEMANAGER';
        /**
         * List of DataStore packages that the developer authored.
         */
        'packages': Array<v1.skill.Manifest.DataStorePackage>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Used to declare that the skill uses the Alexa.Presentation.APL interface.
     * @interface
     */
    interface AlexaPresentationAplInterface {
        'type': 'ALEXA_PRESENTATION_APL';
        /**
         * List of supported viewports.
         */
        'supportedViewports'?: Array<v1.skill.Manifest.ViewportSpecification>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Used to declare that the skill uses the Alexa.Presentation.HTML interface.
     * @interface
     */
    interface AlexaPresentationHtmlInterface {
        'type': 'ALEXA_PRESENTATION_HTML';
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface AlexaSearch {
        'type': 'ALEXA_SEARCH';
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface AppLinkInterface {
        'type': 'APP_LINKS';
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface AppLinkV2Interface {
        'type': 'APP_LINKS_V2';
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface AudioInterface {
        'type': 'AUDIO_PLAYER';
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines client using Login With Amazon authentication provider, corresponds to LWA Security Profile.
     * @interface
     */
    interface AuthorizedClientLwa {
        'authenticationProvider': string;
        'applications'?: Array<v1.skill.Manifest.AuthorizedClientLwaApplication>;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Defines an android application for LWA authentication provider.
     * @interface
     */
    interface AuthorizedClientLwaApplicationAndroid {
        'type': string;
        'appStoreAppId'?: string;
        'clientId'?: string;
    }
}
export declare namespace v1.skill.Manifest.Custom {
    /**
     * The type of target runtime.
     * @interface
     */
    interface TargetRuntimeDevice {
        'type': 'DEVICE';
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Used to declare that the skill uses the Display interface. When a skill declares that it uses the Display interface the Display interface will be passed in the supportedInterfaces section of devices which meet any of the required minimum version attributes specified in the manifest. If the device does not meet any of the minimum versions specified in the manifest the Display interface will not be present in the supportedInterfaces section. If neither the minimumTemplateVersion nor the minimumApmlVersion attributes are specified in the manifes then the minimumTemplateVersion is defaulted to 1.0 and apmlVersion is omitted.
     * @interface
     */
    interface DisplayInterface {
        'type': 'RENDER_TEMPLATE';
        'minimumTemplateVersion'?: v1.skill.Manifest.DisplayInterfaceTemplateVersion;
        'minimumApmlVersion'?: v1.skill.Manifest.DisplayInterfaceApmlVersion;
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Skills using Gadget Controller can send directives to Echo Buttons. This is a legacy interface specific to Echo Buttons.
     * @interface
     */
    interface GadgetControllerInterface {
        'type': 'GADGET_CONTROLLER';
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface GameEngineInterface {
        'type': 'GAME_ENGINE';
    }
}
export declare namespace v1.skill.Manifest {
    /**
     *
     * @interface
     */
    interface VideoAppInterface {
        'type': 'VIDEO_APP';
    }
}
export declare namespace v1.skill.Manifest {
    /**
     * Feature for allowing for querying for available partner voice profiles, linking Alexa Speaker ID profiles to partner speaker profiles, and sending partner speaker profiles in directives.
     * @interface
     */
    interface VoiceProfileFeature {
        'name': 'VIDEO_VOICE_PROFILE';
        'version': string;
    }
}
export declare namespace v1.skill.evaluations {
    /**
     * The intent that Alexa selected for the utterance in the request.
     * @interface
     */
    interface ProfileNluSelectedIntent {
        'name'?: string;
        'confirmationStatus'?: v1.skill.evaluations.ConfirmationStatusType;
        /**
         * A map of key-value pairs that further describes what the user meant based on a predefined intent schema. The map can be empty.
         */
        'slots'?: {
            [key: string]: v1.skill.evaluations.Slot;
        };
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Supply slot values from catalog(s).
     * @interface
     */
    interface CatalogValueSupplier {
        'type': 'CatalogValueSupplier';
        'valueCatalog'?: v1.skill.interactionModel.ValueCatalog;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * The hasEntityResolutionMatch would allow Alexa to trigger a re-prompt when the status produced by ER is \"ER_SUCCESS_NO_MATCH\".
     * @interface
     */
    interface HasEntityResolutionMatch {
        'type': 'hasEntityResolutionMatch';
        /**
         * The prompt id that should be used if validation fails.
         */
        'prompt': string;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Supplies inline slot type values.
     * @interface
     */
    interface InlineValueSupplier {
        'type': 'InlineValueSupplier';
        /**
         * The list of slot type values.
         */
        'values'?: Array<v1.skill.interactionModel.TypeValue>;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Validates that slot value is greater than the specified value.
     * @interface
     */
    interface IsGreaterThan {
        'type': 'isGreaterThan';
        /**
         * The prompt id that should be used if validation fails.
         */
        'prompt': string;
        /**
         * Value to compare to.
         */
        'value': string;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Validates that slot value is greater than or equals to the specified value.
     * @interface
     */
    interface IsGreaterThanOrEqualTo {
        'type': 'isGreaterThanOrEqualTo';
        /**
         * The prompt id that should be used if validation fails.
         */
        'prompt': string;
        /**
         * Value to compare to.
         */
        'value': string;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Validates that the given date or time (as a slot value) is in a given interval. Unlike other range validations, duration based validations lets the developer define a dynamic range of date or time using ISO_8601 Duration Format. Based on the given 'start' and 'end' parameters an interval is created. The slot value given by the skill's user at runtime is then validated inside this interval. Both 'start' and 'end' parameters are in reference to the current date/time. Here the current date/time refers to the date/time when the skill's user made the request.
     * @interface
     */
    interface IsInDuration {
        'type': 'isInDuration';
        /**
         * The prompt id that should be used if validation fails.
         */
        'prompt': string;
        /**
         * * `AMAZON.DATE`: ISO 8601 Duration using Y, M or D components or ISO 8601 Calendar Date in YYYY-MM-DD format. * `AMAZON.TIME`: ISO 8601 Duration using H or M component or ISO 8601 24-Hour Clock Time in hh:mm format.
         */
        'start'?: string;
        /**
         * * `AMAZON.DATE`: ISO 8601 Duration using Y, M or D components or ISO 8601 Calendar Date in YYYY-MM-DD format. * `AMAZON.TIME`: ISO 8601 Duration using H or M component or ISO 8601 24-Hour Clock Time in hh:mm format.
         */
        'end'?: string;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Validates if the slot is in the specified set of values.
     * @interface
     */
    interface IsInSet {
        'type': 'isInSet';
        /**
         * The prompt id that should be used if validation fails.
         */
        'prompt': string;
        /**
         * List of values to check.
         */
        'values': Array<string>;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Validates that slot value is less than or equals to the specified value.
     * @interface
     */
    interface IsLessThan {
        'type': 'isLessThan';
        /**
         * The prompt id that should be used if validation fails.
         */
        'prompt': string;
        /**
         * Value to compare to.
         */
        'value': string;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Validates that slot value is less than or equals to the specified value.
     * @interface
     */
    interface IsLessThanOrEqualTo {
        'type': 'isLessThanOrEqualTo';
        /**
         * The prompt id that should be used if validation fails.
         */
        'prompt': string;
        /**
         * Value to compare to.
         */
        'value': string;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Validates that the given date or time (as a slot value) is not in a given interval. Unlike other range validations, duration based validations lets the developer define a dynamic range of date or time using ISO_8601 Duration Format. Based on the given 'start' and 'end' parameters an interval is created. The slot value given by the skill's user at runtime is then validated inside this interval. Both 'start' and 'end' parameters are in reference to the current date/time. Here the current date/time refers to the date/time when the skill's user made the request.
     * @interface
     */
    interface IsNotInDuration {
        'type': 'isNotInDuration';
        /**
         * The prompt id that should be used if validation fails.
         */
        'prompt': string;
        /**
         * * `AMAZON.DATE`: ISO 8601 Duration using Y, M or D components or ISO 8601 Calendar Date in YYYY-MM-DD format. * `AMAZON.TIME`: ISO 8601 Duration using H or M component or ISO 8601 24-Hour Clock Time in hh:mm format.
         */
        'start'?: string;
        /**
         * * `AMAZON.DATE`: ISO 8601 Duration using Y, M or D components or ISO 8601 Calendar Date in YYYY-MM-DD format. * `AMAZON.TIME`: ISO 8601 Duration using H or M component or ISO 8601 24-Hour Clock Time in hh:mm format.
         */
        'end'?: string;
    }
}
export declare namespace v1.skill.interactionModel {
    /**
     * Validates if the slot is not in the specified set of values.
     * @interface
     */
    interface IsNotInSet {
        'type': 'isNotInSet';
        /**
         * The prompt id that should be used if validation fails.
         */
        'prompt': string;
        /**
         * List of values to check.
         */
        'values': Array<string>;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Catalog the job is applied on.
     * @interface
     */
    interface Catalog {
        'type': 'Catalog';
        /**
         * Catalog identifier.
         */
        'id'?: string;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Definition for CatalogAutoRefresh job.
     * @interface
     */
    interface CatalogAutoRefresh {
        'type': 'CatalogAutoRefresh';
        /**
         * CatalogAutoRefresh can only have CatalogAutoRefresh trigger.
         */
        'trigger'?: v1.skill.interactionModel.jobs.Scheduled;
        /**
         * Current status of the job definition.
         */
        'status'?: string;
        /**
         * The resource that the job is act on. Only catalog is allowed.
         */
        'resource'?: v1.skill.interactionModel.jobs.Catalog;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Interaction model the job is applied on.
     * @interface
     */
    interface InteractionModel {
        'type': 'InteractionModel';
        /**
         * Skill identifier.
         */
        'id': string;
        /**
         * Locale identifier and default is empty list which means all available locales.
         */
        'locales': Array<string>;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Definition for ReferenceVersionUpdate job.
     * @interface
     */
    interface ReferenceVersionUpdate {
        'type': 'ReferenceVersionUpdate';
        /**
         * Can only have ReferencedResourceJobsComplete trigger.
         */
        'trigger'?: v1.skill.interactionModel.jobs.ReferencedResourceJobsComplete;
        /**
         * Current status of the job definition.
         */
        'status'?: string;
        /**
         * The resource that the job is act on. Only slot and interactionModel are allowed.
         */
        'resource'?: v1.skill.interactionModel.jobs.ResourceObject;
        /**
         * Referenced resources working with ReferencedResourceJobsComplete trigger.
         */
        'references'?: Array<v1.skill.interactionModel.jobs.ResourceObject>;
        /**
         * Whether publish development stage to live after the updates.
         */
        'publishToLive'?: boolean;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Dependent job condition when jobs will be executed.
     * @interface
     */
    interface ReferencedResourceJobsComplete {
        'type': 'ReferencedResourceJobsComplete';
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Time-based condition when jobs will be executed.
     * @interface
     */
    interface Scheduled {
        'type': 'Scheduled';
        /**
         * The cron-like attribute in UTC time to describe the hour of the day and currently can only be 0,4,8,12,16,20.
         */
        'hour': number;
        /**
         * If not null, this means the scheudule is weekly. the cron-like attribute in UTC time to describe the day of the week (0-6).
         */
        'dayOfWeek'?: number;
    }
}
export declare namespace v1.skill.interactionModel.jobs {
    /**
     * Slot type reference the job is applied on.
     * @interface
     */
    interface SlotTypeReference {
        'type': 'SlotTypeReference';
        /**
         * SlotTypeReference identifier.
         */
        'id'?: string;
    }
}
export declare namespace v1.skill.nlu.annotationSets {
    /**
     *
     * @interface
     */
    interface AnnotationSet {
        'locale'?: string;
        /**
         * Name of the NLU annotation set
         */
        'name'?: string;
        /**
         * Number of entries which represents number of utterances in each NLU annotation set content
         */
        'numberOfEntries'?: number;
        /**
         * The lastest updated timestamp for the NLU annotation set
         */
        'updatedTimestamp'?: string;
        /**
         * Identifier of the NLU annotation set.
         */
        'annotationId'?: string;
    }
}
export declare namespace v1.skill.nlu.annotationSets {
    /**
     *
     * @interface
     */
    interface GetNLUAnnotationSetPropertiesResponse {
        'locale'?: string;
        /**
         * Name of the NLU annotation set
         */
        'name'?: string;
        /**
         * Number of entries which represents number of utterances in each NLU annotation set content
         */
        'numberOfEntries'?: number;
        /**
         * The lastest updated timestamp for the NLU annotation set
         */
        'updatedTimestamp'?: string;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface Evaluation {
        'startTimestamp'?: string;
        'endTimestamp'?: string;
        'status'?: v1.skill.nlu.evaluations.Status;
        /**
         * Error message when evaluation job fails
         */
        'errorMessage'?: string;
        'inputs'?: v1.skill.nlu.evaluations.EvaluationInputs;
        /**
         * id of the job
         */
        'id'?: string;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface GetNLUEvaluationResponse {
        'startTimestamp'?: string;
        'endTimestamp'?: string;
        'status'?: v1.skill.nlu.evaluations.Status;
        /**
         * Error message when evaluation job fails
         */
        'errorMessage'?: string;
        'inputs'?: v1.skill.nlu.evaluations.EvaluationInputs;
        '_links'?: v1.skill.nlu.evaluations.GetNLUEvaluationResponseLinks;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     *
     * @interface
     */
    interface GetNLUEvaluationResultsResponse {
        'paginationContext'?: v1.skill.nlu.evaluations.PagedResultsResponsePaginationContext;
        '_links'?: v1.skill.nlu.evaluations.Links;
        /**
         * count of tests failed. A test fails when the expected intent and expected slots are not identical.
         */
        'totalFailed'?: number;
        'testCases'?: Array<v1.skill.nlu.evaluations.TestCase>;
    }
}
export declare namespace v1.skill.nlu.evaluations {
    /**
     * response body for a list evaluation API
     * @interface
     */
    interface ListNLUEvaluationsResponse {
        'paginationContext'?: v1.skill.nlu.evaluations.PaginationContext;
        '_links'?: v1.skill.nlu.evaluations.Links;
        'evaluations'?: Array<v1.skill.nlu.evaluations.Evaluation>;
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface EvaluateSHCapabilityResponse {
        'capabilityTestPlan': v1.smartHomeEvaluation.CapabilityTestPlan;
        'endpoint': v1.smartHomeEvaluation.Endpoint;
        'stage': v1.smartHomeEvaluation.Stage;
        'id'?: string;
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface GetSHCapabilityEvaluationResultsResponse {
        'paginationContext'?: v1.smartHomeEvaluation.PaginationContext;
        'testCaseResults'?: Array<v1.smartHomeEvaluation.TestCaseResult>;
    }
}
export declare namespace v1.smartHomeEvaluation {
    /**
     *
     * @interface
     */
    interface ListSHCapabilityTestPlansResponse {
        'paginationContext'?: v1.smartHomeEvaluation.PaginationContext;
        'testPlans'?: Array<v1.smartHomeEvaluation.ListSHTestPlanItem>;
    }
}
export declare namespace services.skillManagement {
    /**
     *
    */
    class SkillManagementServiceClient extends BaseServiceClient {
        private lwaServiceClient;
        private userAgent;
        constructor(apiConfiguration: ApiConfiguration, authenticationConfiguration: AuthenticationConfiguration, customUserAgent?: string);
        /**
         * Returns information about a particular catalog.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         */
        callGetCatalogV0(catalogId: string): Promise<ApiResponse>;
        /**
         * Returns information about a particular catalog.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         */
        getCatalogV0(catalogId: string): Promise<v0.catalog.CatalogDetails>;
        /**
         * Lists all the uploads for a particular catalog.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        callListUploadsForCatalogV0(catalogId: string, nextToken?: string, maxResults?: number): Promise<ApiResponse>;
        /**
         * Lists all the uploads for a particular catalog.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        listUploadsForCatalogV0(catalogId: string, nextToken?: string, maxResults?: number): Promise<v0.catalog.upload.ListUploadsResponse>;
        /**
         * Creates a new upload for a catalog and returns presigned upload parts for uploading the file.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {v0.catalog.upload.CreateContentUploadRequest} createContentUploadRequest Defines the request body for updateCatalog API.
         */
        callCreateContentUploadV0(catalogId: string, createContentUploadRequest: v0.catalog.upload.CreateContentUploadRequest): Promise<ApiResponse>;
        /**
         * Creates a new upload for a catalog and returns presigned upload parts for uploading the file.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {v0.catalog.upload.CreateContentUploadRequest} createContentUploadRequest Defines the request body for updateCatalog API.
         */
        createContentUploadV0(catalogId: string, createContentUploadRequest: v0.catalog.upload.CreateContentUploadRequest): Promise<v0.catalog.upload.CreateContentUploadResponse>;
        /**
         * Gets detailed information about an upload which was created for a specific catalog. Includes the upload's ingestion steps and a presigned url for downloading the file.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} uploadId Unique identifier of the upload.
         */
        callGetContentUploadByIdV0(catalogId: string, uploadId: string): Promise<ApiResponse>;
        /**
         * Gets detailed information about an upload which was created for a specific catalog. Includes the upload's ingestion steps and a presigned url for downloading the file.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} uploadId Unique identifier of the upload.
         */
        getContentUploadByIdV0(catalogId: string, uploadId: string): Promise<v0.catalog.upload.GetContentUploadResponse>;
        /**
         * Completes an upload. To be called after the file is uploaded to the backend data store using presigned url(s).
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} uploadId Unique identifier of the upload.
         * @param {v0.catalog.upload.CompleteUploadRequest} completeUploadRequestPayload Request payload to complete an upload.
         */
        callCompleteCatalogUploadV0(catalogId: string, uploadId: string, completeUploadRequestPayload: v0.catalog.upload.CompleteUploadRequest): Promise<ApiResponse>;
        /**
         * Completes an upload. To be called after the file is uploaded to the backend data store using presigned url(s).
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} uploadId Unique identifier of the upload.
         * @param {v0.catalog.upload.CompleteUploadRequest} completeUploadRequestPayload Request payload to complete an upload.
         */
        completeCatalogUploadV0(catalogId: string, uploadId: string, completeUploadRequestPayload: v0.catalog.upload.CompleteUploadRequest): Promise<void>;
        /**
         * Lists catalogs associated with a vendor.
         * @param {string} vendorId The vendor ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults
         */
        callListCatalogsForVendorV0(vendorId: string, nextToken?: string, maxResults?: number): Promise<ApiResponse>;
        /**
         * Lists catalogs associated with a vendor.
         * @param {string} vendorId The vendor ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults
         */
        listCatalogsForVendorV0(vendorId: string, nextToken?: string, maxResults?: number): Promise<v0.catalog.ListCatalogsResponse>;
        /**
         * Creates a new catalog based on information provided in the request.
         * @param {v0.catalog.CreateCatalogRequest} createCatalogRequest Defines the request body for createCatalog API.
         */
        callCreateCatalogV0(createCatalogRequest: v0.catalog.CreateCatalogRequest): Promise<ApiResponse>;
        /**
         * Creates a new catalog based on information provided in the request.
         * @param {v0.catalog.CreateCatalogRequest} createCatalogRequest Defines the request body for createCatalog API.
         */
        createCatalogV0(createCatalogRequest: v0.catalog.CreateCatalogRequest): Promise<v0.catalog.CatalogDetails>;
        /**
         * Lists the subscribers for a particular vendor.
         * @param {string} vendorId The vendor ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        callListSubscribersForDevelopmentEventsV0(vendorId: string, nextToken?: string, maxResults?: number): Promise<ApiResponse>;
        /**
         * Lists the subscribers for a particular vendor.
         * @param {string} vendorId The vendor ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        listSubscribersForDevelopmentEventsV0(vendorId: string, nextToken?: string, maxResults?: number): Promise<v0.developmentEvents.subscriber.ListSubscribersResponse>;
        /**
         * Creates a new subscriber resource for a vendor.
         * @param {v0.developmentEvents.subscriber.CreateSubscriberRequest} createSubscriberRequest Defines the request body for createSubscriber API.
         */
        callCreateSubscriberForDevelopmentEventsV0(createSubscriberRequest: v0.developmentEvents.subscriber.CreateSubscriberRequest): Promise<ApiResponse>;
        /**
         * Creates a new subscriber resource for a vendor.
         * @param {v0.developmentEvents.subscriber.CreateSubscriberRequest} createSubscriberRequest Defines the request body for createSubscriber API.
         */
        createSubscriberForDevelopmentEventsV0(createSubscriberRequest: v0.developmentEvents.subscriber.CreateSubscriberRequest): Promise<void>;
        /**
         * Deletes a specified subscriber.
         * @param {string} subscriberId Unique identifier of the subscriber.
         */
        callDeleteSubscriberForDevelopmentEventsV0(subscriberId: string): Promise<ApiResponse>;
        /**
         * Deletes a specified subscriber.
         * @param {string} subscriberId Unique identifier of the subscriber.
         */
        deleteSubscriberForDevelopmentEventsV0(subscriberId: string): Promise<void>;
        /**
         * Returns information about specified subscriber.
         * @param {string} subscriberId Unique identifier of the subscriber.
         */
        callGetSubscriberForDevelopmentEventsV0(subscriberId: string): Promise<ApiResponse>;
        /**
         * Returns information about specified subscriber.
         * @param {string} subscriberId Unique identifier of the subscriber.
         */
        getSubscriberForDevelopmentEventsV0(subscriberId: string): Promise<v0.developmentEvents.subscriber.SubscriberInfo>;
        /**
         * Updates the properties of a subscriber.
         * @param {string} subscriberId Unique identifier of the subscriber.
         * @param {v0.developmentEvents.subscriber.UpdateSubscriberRequest} updateSubscriberRequest Defines the request body for updateSubscriber API.
         */
        callSetSubscriberForDevelopmentEventsV0(subscriberId: string, updateSubscriberRequest: v0.developmentEvents.subscriber.UpdateSubscriberRequest): Promise<ApiResponse>;
        /**
         * Updates the properties of a subscriber.
         * @param {string} subscriberId Unique identifier of the subscriber.
         * @param {v0.developmentEvents.subscriber.UpdateSubscriberRequest} updateSubscriberRequest Defines the request body for updateSubscriber API.
         */
        setSubscriberForDevelopmentEventsV0(subscriberId: string, updateSubscriberRequest: v0.developmentEvents.subscriber.UpdateSubscriberRequest): Promise<void>;
        /**
         * Lists all the subscriptions for a vendor/subscriber depending on the query parameter.
         * @param {string} vendorId The vendor ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} subscriberId Unique identifier of the subscriber. If this query parameter is provided, the list would be filtered by the owning subscriberId.
         */
        callListSubscriptionsForDevelopmentEventsV0(vendorId: string, nextToken?: string, maxResults?: number, subscriberId?: string): Promise<ApiResponse>;
        /**
         * Lists all the subscriptions for a vendor/subscriber depending on the query parameter.
         * @param {string} vendorId The vendor ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} subscriberId Unique identifier of the subscriber. If this query parameter is provided, the list would be filtered by the owning subscriberId.
         */
        listSubscriptionsForDevelopmentEventsV0(vendorId: string, nextToken?: string, maxResults?: number, subscriberId?: string): Promise<v0.developmentEvents.subscription.ListSubscriptionsResponse>;
        /**
         * Creates a new subscription for a subscriber. This needs to be authorized by the client/vendor who created the subscriber and the vendor who publishes the event.
         * @param {v0.developmentEvents.subscription.CreateSubscriptionRequest} createSubscriptionRequest Request body for createSubscription API.
         */
        callCreateSubscriptionForDevelopmentEventsV0(createSubscriptionRequest?: v0.developmentEvents.subscription.CreateSubscriptionRequest): Promise<ApiResponse>;
        /**
         * Creates a new subscription for a subscriber. This needs to be authorized by the client/vendor who created the subscriber and the vendor who publishes the event.
         * @param {v0.developmentEvents.subscription.CreateSubscriptionRequest} createSubscriptionRequest Request body for createSubscription API.
         */
        createSubscriptionForDevelopmentEventsV0(createSubscriptionRequest?: v0.developmentEvents.subscription.CreateSubscriptionRequest): Promise<void>;
        /**
         * Deletes a particular subscription. Both, the vendor who created the subscriber and the vendor who publishes the event can delete this resource with appropriate authorization.
         * @param {string} subscriptionId Unique identifier of the subscription.
         */
        callDeleteSubscriptionForDevelopmentEventsV0(subscriptionId: string): Promise<ApiResponse>;
        /**
         * Deletes a particular subscription. Both, the vendor who created the subscriber and the vendor who publishes the event can delete this resource with appropriate authorization.
         * @param {string} subscriptionId Unique identifier of the subscription.
         */
        deleteSubscriptionForDevelopmentEventsV0(subscriptionId: string): Promise<void>;
        /**
         * Returns information about a particular subscription. Both, the vendor who created the subscriber and the vendor who publishes the event can retrieve this resource with appropriate authorization.
         * @param {string} subscriptionId Unique identifier of the subscription.
         */
        callGetSubscriptionForDevelopmentEventsV0(subscriptionId: string): Promise<ApiResponse>;
        /**
         * Returns information about a particular subscription. Both, the vendor who created the subscriber and the vendor who publishes the event can retrieve this resource with appropriate authorization.
         * @param {string} subscriptionId Unique identifier of the subscription.
         */
        getSubscriptionForDevelopmentEventsV0(subscriptionId: string): Promise<v0.developmentEvents.subscription.SubscriptionInfo>;
        /**
         * Updates the mutable properties of a subscription. This needs to be authorized by the client/vendor who created the subscriber and the vendor who publishes the event. The subscriberId cannot be updated.
         * @param {string} subscriptionId Unique identifier of the subscription.
         * @param {v0.developmentEvents.subscription.UpdateSubscriptionRequest} updateSubscriptionRequest Request body for updateSubscription API.
         */
        callSetSubscriptionForDevelopmentEventsV0(subscriptionId: string, updateSubscriptionRequest?: v0.developmentEvents.subscription.UpdateSubscriptionRequest): Promise<ApiResponse>;
        /**
         * Updates the mutable properties of a subscription. This needs to be authorized by the client/vendor who created the subscriber and the vendor who publishes the event. The subscriberId cannot be updated.
         * @param {string} subscriptionId Unique identifier of the subscription.
         * @param {v0.developmentEvents.subscription.UpdateSubscriptionRequest} updateSubscriptionRequest Request body for updateSubscription API.
         */
        setSubscriptionForDevelopmentEventsV0(subscriptionId: string, updateSubscriptionRequest?: v0.developmentEvents.subscription.UpdateSubscriptionRequest): Promise<void>;
        /**
         * Associate skill with catalog.
         * @param {string} skillId The skill ID.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         */
        callAssociateCatalogWithSkillV0(skillId: string, catalogId: string): Promise<ApiResponse>;
        /**
         * Associate skill with catalog.
         * @param {string} skillId The skill ID.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         */
        associateCatalogWithSkillV0(skillId: string, catalogId: string): Promise<void>;
        /**
         * Lists all the catalogs associated with a skill.
         * @param {string} skillId The skill ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults
         */
        callListCatalogsForSkillV0(skillId: string, nextToken?: string, maxResults?: number): Promise<ApiResponse>;
        /**
         * Lists all the catalogs associated with a skill.
         * @param {string} skillId The skill ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults
         */
        listCatalogsForSkillV0(skillId: string, nextToken?: string, maxResults?: number): Promise<v0.catalog.ListCatalogsResponse>;
        /**
         * Creates a new upload for a catalog and returns location to track the upload process.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {v1.catalog.upload.CatalogUploadBase} catalogUploadRequestBody Provides the request body for create content upload
         */
        callCreateCatalogUploadV1(catalogId: string, catalogUploadRequestBody: v1.catalog.upload.CatalogUploadBase): Promise<ApiResponse>;
        /**
         * Creates a new upload for a catalog and returns location to track the upload process.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {v1.catalog.upload.CatalogUploadBase} catalogUploadRequestBody Provides the request body for create content upload
         */
        createCatalogUploadV1(catalogId: string, catalogUploadRequestBody: v1.catalog.upload.CatalogUploadBase): Promise<void>;
        /**
         * Gets detailed information about an upload which was created for a specific catalog. Includes the upload's ingestion steps and a url for downloading the file.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} uploadId Unique identifier of the upload.
         */
        callGetContentUploadByIdV1(catalogId: string, uploadId: string): Promise<ApiResponse>;
        /**
         * Gets detailed information about an upload which was created for a specific catalog. Includes the upload's ingestion steps and a url for downloading the file.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} uploadId Unique identifier of the upload.
         */
        getContentUploadByIdV1(catalogId: string, uploadId: string): Promise<v1.catalog.upload.GetContentUploadResponse>;
        /**
         * Generates preSigned urls to upload data
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {v1.catalog.CreateContentUploadUrlRequest} generateCatalogUploadUrlRequestBody Request body to generate catalog upload url
         */
        callGenerateCatalogUploadUrlV1(catalogId: string, generateCatalogUploadUrlRequestBody: v1.catalog.CreateContentUploadUrlRequest): Promise<ApiResponse>;
        /**
         * Generates preSigned urls to upload data
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {v1.catalog.CreateContentUploadUrlRequest} generateCatalogUploadUrlRequestBody Request body to generate catalog upload url
         */
        generateCatalogUploadUrlV1(catalogId: string, generateCatalogUploadUrlRequestBody: v1.catalog.CreateContentUploadUrlRequest): Promise<v1.catalog.CreateContentUploadUrlResponse>;
        /**
         * The SMAPI Audit Logs API provides customers with an audit history of all SMAPI calls made by a developer or developers with permissions on that account.
         * @param {v1.auditLogs.AuditLogsRequest} getAuditLogsRequest Request object encompassing vendorId, optional request filters and optional pagination context.
         */
        callQueryDevelopmentAuditLogsV1(getAuditLogsRequest: v1.auditLogs.AuditLogsRequest): Promise<ApiResponse>;
        /**
         * The SMAPI Audit Logs API provides customers with an audit history of all SMAPI calls made by a developer or developers with permissions on that account.
         * @param {v1.auditLogs.AuditLogsRequest} getAuditLogsRequest Request object encompassing vendorId, optional request filters and optional pagination context.
         */
        queryDevelopmentAuditLogsV1(getAuditLogsRequest: v1.auditLogs.AuditLogsRequest): Promise<v1.auditLogs.AuditLogsResponse>;
        /**
         * Get the list of in-skill products for the vendor.
         * @param {string} vendorId The vendor ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {Array<string>} productId The list of in-skill product IDs that you wish to get the summary for. A maximum of 50 in-skill product IDs can be specified in a single listInSkillProducts call. Please note that this parameter must not be used with &#39;nextToken&#39; and/or &#39;maxResults&#39; parameter.
         * @param {string} stage Filter in-skill products by specified stage.
         * @param {string} type Type of in-skill product to filter on.
         * @param {string} referenceName Filter in-skill products by reference name.
         * @param {string} status Status of in-skill product.
         * @param {string} isAssociatedWithSkill Filter in-skill products by whether or not they are associated to a skill.
         */
        callGetIspListForVendorV1(vendorId: string, nextToken?: string, maxResults?: number, productId?: Array<string>, stage?: string, type?: string, referenceName?: string, status?: string, isAssociatedWithSkill?: string): Promise<ApiResponse>;
        /**
         * Get the list of in-skill products for the vendor.
         * @param {string} vendorId The vendor ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {Array<string>} productId The list of in-skill product IDs that you wish to get the summary for. A maximum of 50 in-skill product IDs can be specified in a single listInSkillProducts call. Please note that this parameter must not be used with &#39;nextToken&#39; and/or &#39;maxResults&#39; parameter.
         * @param {string} stage Filter in-skill products by specified stage.
         * @param {string} type Type of in-skill product to filter on.
         * @param {string} referenceName Filter in-skill products by reference name.
         * @param {string} status Status of in-skill product.
         * @param {string} isAssociatedWithSkill Filter in-skill products by whether or not they are associated to a skill.
         */
        getIspListForVendorV1(vendorId: string, nextToken?: string, maxResults?: number, productId?: Array<string>, stage?: string, type?: string, referenceName?: string, status?: string, isAssociatedWithSkill?: string): Promise<v1.isp.ListInSkillProductResponse>;
        /**
         * Creates a new in-skill product for given vendorId.
         * @param {v1.isp.CreateInSkillProductRequest} createInSkillProductRequest defines the request body for createInSkillProduct API.
         */
        callCreateIspForVendorV1(createInSkillProductRequest: v1.isp.CreateInSkillProductRequest): Promise<ApiResponse>;
        /**
         * Creates a new in-skill product for given vendorId.
         * @param {v1.isp.CreateInSkillProductRequest} createInSkillProductRequest defines the request body for createInSkillProduct API.
         */
        createIspForVendorV1(createInSkillProductRequest: v1.isp.CreateInSkillProductRequest): Promise<v1.isp.ProductResponse>;
        /**
         * Disassociates an in-skill product from a skill.
         * @param {string} productId The in-skill product ID.
         * @param {string} skillId The skill ID.
         */
        callDisassociateIspWithSkillV1(productId: string, skillId: string): Promise<ApiResponse>;
        /**
         * Disassociates an in-skill product from a skill.
         * @param {string} productId The in-skill product ID.
         * @param {string} skillId The skill ID.
         */
        disassociateIspWithSkillV1(productId: string, skillId: string): Promise<void>;
        /**
         * Associates an in-skill product with a skill.
         * @param {string} productId The in-skill product ID.
         * @param {string} skillId The skill ID.
         */
        callAssociateIspWithSkillV1(productId: string, skillId: string): Promise<ApiResponse>;
        /**
         * Associates an in-skill product with a skill.
         * @param {string} productId The in-skill product ID.
         * @param {string} skillId The skill ID.
         */
        associateIspWithSkillV1(productId: string, skillId: string): Promise<void>;
        /**
         * Deletes the in-skill product for given productId. Only development stage supported. Live in-skill products or in-skill products associated with a skill cannot be deleted by this API.
         * @param {string} productId The in-skill product ID.
         * @param {string} stage Stage for skill.
         * @param {string} ifMatch Request header that specified an entity tag. The server will update the resource only if the eTag matches with the resource&#39;s current eTag.
         */
        callDeleteIspForProductV1(productId: string, stage: string, ifMatch?: string): Promise<ApiResponse>;
        /**
         * Deletes the in-skill product for given productId. Only development stage supported. Live in-skill products or in-skill products associated with a skill cannot be deleted by this API.
         * @param {string} productId The in-skill product ID.
         * @param {string} stage Stage for skill.
         * @param {string} ifMatch Request header that specified an entity tag. The server will update the resource only if the eTag matches with the resource&#39;s current eTag.
         */
        deleteIspForProductV1(productId: string, stage: string, ifMatch?: string): Promise<void>;
        /**
         * Resets the entitlement(s) of the Product for the current user.
         * @param {string} productId The in-skill product ID.
         * @param {string} stage Stage for skill.
         */
        callResetEntitlementForProductV1(productId: string, stage: string): Promise<ApiResponse>;
        /**
         * Resets the entitlement(s) of the Product for the current user.
         * @param {string} productId The in-skill product ID.
         * @param {string} stage Stage for skill.
         */
        resetEntitlementForProductV1(productId: string, stage: string): Promise<void>;
        /**
         * Returns the in-skill product definition for given productId.
         * @param {string} productId The in-skill product ID.
         * @param {string} stage Stage for skill.
         */
        callGetIspDefinitionV1(productId: string, stage: string): Promise<ApiResponse>;
        /**
         * Returns the in-skill product definition for given productId.
         * @param {string} productId The in-skill product ID.
         * @param {string} stage Stage for skill.
         */
        getIspDefinitionV1(productId: string, stage: string): Promise<v1.isp.InSkillProductDefinitionResponse>;
        /**
         * Updates in-skill product definition for given productId. Only development stage supported.
         * @param {string} productId The in-skill product ID.
         * @param {string} stage Stage for skill.
         * @param {v1.isp.UpdateInSkillProductRequest} updateInSkillProductRequest defines the request body for updateInSkillProduct API.
         * @param {string} ifMatch Request header that specified an entity tag. The server will update the resource only if the eTag matches with the resource&#39;s current eTag.
         */
        callUpdateIspForProductV1(productId: string, stage: string, updateInSkillProductRequest: v1.isp.UpdateInSkillProductRequest, ifMatch?: string): Promise<ApiResponse>;
        /**
         * Updates in-skill product definition for given productId. Only development stage supported.
         * @param {string} productId The in-skill product ID.
         * @param {string} stage Stage for skill.
         * @param {v1.isp.UpdateInSkillProductRequest} updateInSkillProductRequest defines the request body for updateInSkillProduct API.
         * @param {string} ifMatch Request header that specified an entity tag. The server will update the resource only if the eTag matches with the resource&#39;s current eTag.
         */
        updateIspForProductV1(productId: string, stage: string, updateInSkillProductRequest: v1.isp.UpdateInSkillProductRequest, ifMatch?: string): Promise<void>;
        /**
         * Get the associated skills for the in-skill product.
         * @param {string} productId The in-skill product ID.
         * @param {string} stage Stage for skill.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        callGetIspAssociatedSkillsV1(productId: string, stage: string, nextToken?: string, maxResults?: number): Promise<ApiResponse>;
        /**
         * Get the associated skills for the in-skill product.
         * @param {string} productId The in-skill product ID.
         * @param {string} stage Stage for skill.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        getIspAssociatedSkillsV1(productId: string, stage: string, nextToken?: string, maxResults?: number): Promise<v1.isp.AssociatedSkillResponse>;
        /**
         * Get the summary information for an in-skill product.
         * @param {string} productId The in-skill product ID.
         * @param {string} stage Stage for skill.
         */
        callGetIspSummaryV1(productId: string, stage: string): Promise<ApiResponse>;
        /**
         * Get the summary information for an in-skill product.
         * @param {string} productId The in-skill product ID.
         * @param {string} stage Stage for skill.
         */
        getIspSummaryV1(productId: string, stage: string): Promise<v1.isp.InSkillProductSummaryResponse>;
        /**
         * Delete the catalog.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         */
        callDeleteInteractionModelCatalogV1(catalogId: string): Promise<ApiResponse>;
        /**
         * Delete the catalog.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         */
        deleteInteractionModelCatalogV1(catalogId: string): Promise<void>;
        /**
         * get the catalog definition
         * @param {string} catalogId Provides a unique identifier of the catalog.
         */
        callGetInteractionModelCatalogDefinitionV1(catalogId: string): Promise<ApiResponse>;
        /**
         * get the catalog definition
         * @param {string} catalogId Provides a unique identifier of the catalog.
         */
        getInteractionModelCatalogDefinitionV1(catalogId: string): Promise<v1.skill.interactionModel.catalog.CatalogDefinitionOutput>;
        /**
         * update description and vendorGuidance string for certain version of a catalog.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {v1.skill.interactionModel.catalog.UpdateRequest} updateRequest
         */
        callUpdateInteractionModelCatalogV1(catalogId: string, updateRequest: v1.skill.interactionModel.catalog.UpdateRequest): Promise<ApiResponse>;
        /**
         * update description and vendorGuidance string for certain version of a catalog.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {v1.skill.interactionModel.catalog.UpdateRequest} updateRequest
         */
        updateInteractionModelCatalogV1(catalogId: string, updateRequest: v1.skill.interactionModel.catalog.UpdateRequest): Promise<void>;
        /**
         * Get the status of catalog resource and its sub-resources for a given catalogId.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} updateRequestId The identifier for slotType version creation process
         */
        callGetInteractionModelCatalogUpdateStatusV1(catalogId: string, updateRequestId: string): Promise<ApiResponse>;
        /**
         * Get the status of catalog resource and its sub-resources for a given catalogId.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} updateRequestId The identifier for slotType version creation process
         */
        getInteractionModelCatalogUpdateStatusV1(catalogId: string, updateRequestId: string): Promise<v1.skill.interactionModel.catalog.CatalogStatus>;
        /**
         * List all the historical versions of the given catalogId.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {string} sortDirection Sets the sorting direction of the result items. When set to &#39;asc&#39; these items are returned in ascending order of sortField value and when set to &#39;desc&#39; these items are returned in descending order of sortField value.
         * @param {string} sortField Sets the field on which the sorting would be applied.
         */
        callListInteractionModelCatalogVersionsV1(catalogId: string, maxResults?: number, nextToken?: string, sortDirection?: string, sortField?: string): Promise<ApiResponse>;
        /**
         * List all the historical versions of the given catalogId.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {string} sortDirection Sets the sorting direction of the result items. When set to &#39;asc&#39; these items are returned in ascending order of sortField value and when set to &#39;desc&#39; these items are returned in descending order of sortField value.
         * @param {string} sortField Sets the field on which the sorting would be applied.
         */
        listInteractionModelCatalogVersionsV1(catalogId: string, maxResults?: number, nextToken?: string, sortDirection?: string, sortField?: string): Promise<v1.skill.interactionModel.version.ListCatalogEntityVersionsResponse>;
        /**
         * Create a new version of catalog entity for the given catalogId.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {v1.skill.interactionModel.version.VersionData} catalog
         */
        callCreateInteractionModelCatalogVersionV1(catalogId: string, catalog: v1.skill.interactionModel.version.VersionData): Promise<ApiResponse>;
        /**
         * Create a new version of catalog entity for the given catalogId.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {v1.skill.interactionModel.version.VersionData} catalog
         */
        createInteractionModelCatalogVersionV1(catalogId: string, catalog: v1.skill.interactionModel.version.VersionData): Promise<void>;
        /**
         * Delete catalog version.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} version Version for interaction model.
         */
        callDeleteInteractionModelCatalogVersionV1(catalogId: string, version: string): Promise<ApiResponse>;
        /**
         * Delete catalog version.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} version Version for interaction model.
         */
        deleteInteractionModelCatalogVersionV1(catalogId: string, version: string): Promise<void>;
        /**
         * Get catalog version data of given catalog version.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} version Version for interaction model.
         */
        callGetInteractionModelCatalogVersionV1(catalogId: string, version: string): Promise<ApiResponse>;
        /**
         * Get catalog version data of given catalog version.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} version Version for interaction model.
         */
        getInteractionModelCatalogVersionV1(catalogId: string, version: string): Promise<v1.skill.interactionModel.version.CatalogVersionData>;
        /**
         * Update description and vendorGuidance string for certain version of a catalog.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} version Version for interaction model.
         * @param {v1.skill.interactionModel.version.CatalogUpdate} catalogUpdate
         */
        callUpdateInteractionModelCatalogVersionV1(catalogId: string, version: string, catalogUpdate?: v1.skill.interactionModel.version.CatalogUpdate): Promise<ApiResponse>;
        /**
         * Update description and vendorGuidance string for certain version of a catalog.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} version Version for interaction model.
         * @param {v1.skill.interactionModel.version.CatalogUpdate} catalogUpdate
         */
        updateInteractionModelCatalogVersionV1(catalogId: string, version: string, catalogUpdate?: v1.skill.interactionModel.version.CatalogUpdate): Promise<void>;
        /**
         * Get catalog values from the given catalogId & version.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} version Version for interaction model.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         */
        callGetInteractionModelCatalogValuesV1(catalogId: string, version: string, maxResults?: number, nextToken?: string): Promise<ApiResponse>;
        /**
         * Get catalog values from the given catalogId & version.
         * @param {string} catalogId Provides a unique identifier of the catalog.
         * @param {string} version Version for interaction model.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         */
        getInteractionModelCatalogValuesV1(catalogId: string, version: string, maxResults?: number, nextToken?: string): Promise<v1.skill.interactionModel.version.CatalogValues>;
        /**
         * List all catalogs for the vendor.
         * @param {string} vendorId The vendor ID.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {string} sortDirection Sets the sorting direction of the result items. When set to &#39;asc&#39; these items are returned in ascending order of sortField value and when set to &#39;desc&#39; these items are returned in descending order of sortField value.
         */
        callListInteractionModelCatalogsV1(vendorId: string, maxResults?: number, nextToken?: string, sortDirection?: string): Promise<ApiResponse>;
        /**
         * List all catalogs for the vendor.
         * @param {string} vendorId The vendor ID.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {string} sortDirection Sets the sorting direction of the result items. When set to &#39;asc&#39; these items are returned in ascending order of sortField value and when set to &#39;desc&#39; these items are returned in descending order of sortField value.
         */
        listInteractionModelCatalogsV1(vendorId: string, maxResults?: number, nextToken?: string, sortDirection?: string): Promise<v1.skill.interactionModel.catalog.ListCatalogResponse>;
        /**
         * Create a new version of catalog within the given catalogId.
         * @param {v1.skill.interactionModel.catalog.DefinitionData} catalog
         */
        callCreateInteractionModelCatalogV1(catalog: v1.skill.interactionModel.catalog.DefinitionData): Promise<ApiResponse>;
        /**
         * Create a new version of catalog within the given catalogId.
         * @param {v1.skill.interactionModel.catalog.DefinitionData} catalog
         */
        createInteractionModelCatalogV1(catalog: v1.skill.interactionModel.catalog.DefinitionData): Promise<v1.skill.interactionModel.catalog.CatalogResponse>;
        /**
         * Retrieve a list of jobs associated with the vendor.
         * @param {string} vendorId The vendor ID.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         */
        callListJobDefinitionsForInteractionModelV1(vendorId: string, maxResults?: number, nextToken?: string): Promise<ApiResponse>;
        /**
         * Retrieve a list of jobs associated with the vendor.
         * @param {string} vendorId The vendor ID.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         */
        listJobDefinitionsForInteractionModelV1(vendorId: string, maxResults?: number, nextToken?: string): Promise<v1.skill.interactionModel.jobs.ListJobDefinitionsResponse>;
        /**
         * Delete the job definition for a given jobId.
         * @param {string} jobId The identifier for dynamic jobs.
         */
        callDeleteJobDefinitionForInteractionModelV1(jobId: string): Promise<ApiResponse>;
        /**
         * Delete the job definition for a given jobId.
         * @param {string} jobId The identifier for dynamic jobs.
         */
        deleteJobDefinitionForInteractionModelV1(jobId: string): Promise<void>;
        /**
         * Cancel the next execution for the given job.
         * @param {string} jobId The identifier for dynamic jobs.
         * @param {string} executionId The identifier for dynamic job executions. Currently only allowed for scheduled executions.
         */
        callCancelNextJobExecutionForInteractionModelV1(jobId: string, executionId: string): Promise<ApiResponse>;
        /**
         * Cancel the next execution for the given job.
         * @param {string} jobId The identifier for dynamic jobs.
         * @param {string} executionId The identifier for dynamic job executions. Currently only allowed for scheduled executions.
         */
        cancelNextJobExecutionForInteractionModelV1(jobId: string, executionId: string): Promise<void>;
        /**
         * List the execution history associated with the job definition, with default sortField to be the executions' timestamp.
         * @param {string} jobId The identifier for dynamic jobs.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {string} sortDirection Sets the sorting direction of the result items. When set to &#39;asc&#39; these items are returned in ascending order of sortField value and when set to &#39;desc&#39; these items are returned in descending order of sortField value.
         */
        callListJobExecutionsForInteractionModelV1(jobId: string, maxResults?: number, nextToken?: string, sortDirection?: string): Promise<ApiResponse>;
        /**
         * List the execution history associated with the job definition, with default sortField to be the executions' timestamp.
         * @param {string} jobId The identifier for dynamic jobs.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {string} sortDirection Sets the sorting direction of the result items. When set to &#39;asc&#39; these items are returned in ascending order of sortField value and when set to &#39;desc&#39; these items are returned in descending order of sortField value.
         */
        listJobExecutionsForInteractionModelV1(jobId: string, maxResults?: number, nextToken?: string, sortDirection?: string): Promise<v1.skill.interactionModel.jobs.GetExecutionsResponse>;
        /**
         * Get the job definition for a given jobId.
         * @param {string} jobId The identifier for dynamic jobs.
         */
        callGetJobDefinitionForInteractionModelV1(jobId: string): Promise<ApiResponse>;
        /**
         * Get the job definition for a given jobId.
         * @param {string} jobId The identifier for dynamic jobs.
         */
        getJobDefinitionForInteractionModelV1(jobId: string): Promise<v1.skill.interactionModel.jobs.JobDefinition>;
        /**
         * Update the JobStatus to Enable or Disable a job.
         * @param {string} jobId The identifier for dynamic jobs.
         * @param {v1.skill.interactionModel.jobs.UpdateJobStatusRequest} updateJobStatusRequest Request to update Job Definition status.
         */
        callSetJobStatusForInteractionModelV1(jobId: string, updateJobStatusRequest: v1.skill.interactionModel.jobs.UpdateJobStatusRequest): Promise<ApiResponse>;
        /**
         * Update the JobStatus to Enable or Disable a job.
         * @param {string} jobId The identifier for dynamic jobs.
         * @param {v1.skill.interactionModel.jobs.UpdateJobStatusRequest} updateJobStatusRequest Request to update Job Definition status.
         */
        setJobStatusForInteractionModelV1(jobId: string, updateJobStatusRequest: v1.skill.interactionModel.jobs.UpdateJobStatusRequest): Promise<void>;
        /**
         * Creates a new Job Definition from the Job Definition request provided. This can be either a CatalogAutoRefresh, which supports time-based configurations for catalogs, or a ReferencedResourceVersionUpdate, which is used for slotTypes and Interaction models to be automatically updated on the dynamic update of their referenced catalog.
         * @param {v1.skill.interactionModel.jobs.CreateJobDefinitionRequest} createJobDefinitionRequest Request to create a new Job Definition.
         */
        callCreateJobDefinitionForInteractionModelV1(createJobDefinitionRequest: v1.skill.interactionModel.jobs.CreateJobDefinitionRequest): Promise<ApiResponse>;
        /**
         * Creates a new Job Definition from the Job Definition request provided. This can be either a CatalogAutoRefresh, which supports time-based configurations for catalogs, or a ReferencedResourceVersionUpdate, which is used for slotTypes and Interaction models to be automatically updated on the dynamic update of their referenced catalog.
         * @param {v1.skill.interactionModel.jobs.CreateJobDefinitionRequest} createJobDefinitionRequest Request to create a new Job Definition.
         */
        createJobDefinitionForInteractionModelV1(createJobDefinitionRequest: v1.skill.interactionModel.jobs.CreateJobDefinitionRequest): Promise<v1.skill.interactionModel.jobs.CreateJobDefinitionResponse>;
        /**
         * List all slot types for the vendor.
         * @param {string} vendorId The vendor ID.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {string} sortDirection Sets the sorting direction of the result items. When set to &#39;asc&#39; these items are returned in ascending order of sortField value and when set to &#39;desc&#39; these items are returned in descending order of sortField value.
         */
        callListInteractionModelSlotTypesV1(vendorId: string, maxResults?: number, nextToken?: string, sortDirection?: string): Promise<ApiResponse>;
        /**
         * List all slot types for the vendor.
         * @param {string} vendorId The vendor ID.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {string} sortDirection Sets the sorting direction of the result items. When set to &#39;asc&#39; these items are returned in ascending order of sortField value and when set to &#39;desc&#39; these items are returned in descending order of sortField value.
         */
        listInteractionModelSlotTypesV1(vendorId: string, maxResults?: number, nextToken?: string, sortDirection?: string): Promise<v1.skill.interactionModel.type.ListSlotTypeResponse>;
        /**
         * Create a new version of slot type within the given slotTypeId.
         * @param {v1.skill.interactionModel.type.DefinitionData} slotType
         */
        callCreateInteractionModelSlotTypeV1(slotType: v1.skill.interactionModel.type.DefinitionData): Promise<ApiResponse>;
        /**
         * Create a new version of slot type within the given slotTypeId.
         * @param {v1.skill.interactionModel.type.DefinitionData} slotType
         */
        createInteractionModelSlotTypeV1(slotType: v1.skill.interactionModel.type.DefinitionData): Promise<v1.skill.interactionModel.type.SlotTypeResponse>;
        /**
         * Delete the slot type.
         * @param {string} slotTypeId The identifier for a slot type.
         */
        callDeleteInteractionModelSlotTypeV1(slotTypeId: string): Promise<ApiResponse>;
        /**
         * Delete the slot type.
         * @param {string} slotTypeId The identifier for a slot type.
         */
        deleteInteractionModelSlotTypeV1(slotTypeId: string): Promise<void>;
        /**
         * Get the slot type definition.
         * @param {string} slotTypeId The identifier for a slot type.
         */
        callGetInteractionModelSlotTypeDefinitionV1(slotTypeId: string): Promise<ApiResponse>;
        /**
         * Get the slot type definition.
         * @param {string} slotTypeId The identifier for a slot type.
         */
        getInteractionModelSlotTypeDefinitionV1(slotTypeId: string): Promise<v1.skill.interactionModel.type.SlotTypeDefinitionOutput>;
        /**
         * Update description and vendorGuidance string for certain version of a slot type.
         * @param {string} slotTypeId The identifier for a slot type.
         * @param {v1.skill.interactionModel.type.UpdateRequest} updateRequest
         */
        callUpdateInteractionModelSlotTypeV1(slotTypeId: string, updateRequest: v1.skill.interactionModel.type.UpdateRequest): Promise<ApiResponse>;
        /**
         * Update description and vendorGuidance string for certain version of a slot type.
         * @param {string} slotTypeId The identifier for a slot type.
         * @param {v1.skill.interactionModel.type.UpdateRequest} updateRequest
         */
        updateInteractionModelSlotTypeV1(slotTypeId: string, updateRequest: v1.skill.interactionModel.type.UpdateRequest): Promise<void>;
        /**
         * Get the status of slot type resource and its sub-resources for a given slotTypeId.
         * @param {string} slotTypeId The identifier for a slot type.
         * @param {string} updateRequestId The identifier for slotType version creation process
         */
        callGetInteractionModelSlotTypeBuildStatusV1(slotTypeId: string, updateRequestId: string): Promise<ApiResponse>;
        /**
         * Get the status of slot type resource and its sub-resources for a given slotTypeId.
         * @param {string} slotTypeId The identifier for a slot type.
         * @param {string} updateRequestId The identifier for slotType version creation process
         */
        getInteractionModelSlotTypeBuildStatusV1(slotTypeId: string, updateRequestId: string): Promise<v1.skill.interactionModel.type.SlotTypeStatus>;
        /**
         * List all slot type versions for the slot type id.
         * @param {string} slotTypeId The identifier for a slot type.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {string} sortDirection Sets the sorting direction of the result items. When set to &#39;asc&#39; these items are returned in ascending order of sortField value and when set to &#39;desc&#39; these items are returned in descending order of sortField value.
         */
        callListInteractionModelSlotTypeVersionsV1(slotTypeId: string, maxResults?: number, nextToken?: string, sortDirection?: string): Promise<ApiResponse>;
        /**
         * List all slot type versions for the slot type id.
         * @param {string} slotTypeId The identifier for a slot type.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {string} sortDirection Sets the sorting direction of the result items. When set to &#39;asc&#39; these items are returned in ascending order of sortField value and when set to &#39;desc&#39; these items are returned in descending order of sortField value.
         */
        listInteractionModelSlotTypeVersionsV1(slotTypeId: string, maxResults?: number, nextToken?: string, sortDirection?: string): Promise<v1.skill.interactionModel.typeVersion.ListSlotTypeVersionResponse>;
        /**
         * Create a new version of slot type entity for the given slotTypeId.
         * @param {string} slotTypeId The identifier for a slot type.
         * @param {v1.skill.interactionModel.typeVersion.VersionData} slotType
         */
        callCreateInteractionModelSlotTypeVersionV1(slotTypeId: string, slotType: v1.skill.interactionModel.typeVersion.VersionData): Promise<ApiResponse>;
        /**
         * Create a new version of slot type entity for the given slotTypeId.
         * @param {string} slotTypeId The identifier for a slot type.
         * @param {v1.skill.interactionModel.typeVersion.VersionData} slotType
         */
        createInteractionModelSlotTypeVersionV1(slotTypeId: string, slotType: v1.skill.interactionModel.typeVersion.VersionData): Promise<void>;
        /**
         * Delete slot type version.
         * @param {string} slotTypeId The identifier for a slot type.
         * @param {string} version Version for interaction model.
         */
        callDeleteInteractionModelSlotTypeVersionV1(slotTypeId: string, version: string): Promise<ApiResponse>;
        /**
         * Delete slot type version.
         * @param {string} slotTypeId The identifier for a slot type.
         * @param {string} version Version for interaction model.
         */
        deleteInteractionModelSlotTypeVersionV1(slotTypeId: string, version: string): Promise<void>;
        /**
         * Get slot type version data of given slot type version.
         * @param {string} slotTypeId The identifier for a slot type.
         * @param {string} version Version for interaction model.
         */
        callGetInteractionModelSlotTypeVersionV1(slotTypeId: string, version: string): Promise<ApiResponse>;
        /**
         * Get slot type version data of given slot type version.
         * @param {string} slotTypeId The identifier for a slot type.
         * @param {string} version Version for interaction model.
         */
        getInteractionModelSlotTypeVersionV1(slotTypeId: string, version: string): Promise<v1.skill.interactionModel.typeVersion.SlotTypeVersionData>;
        /**
         * Update description and vendorGuidance string for certain version of a slot type.
         * @param {string} slotTypeId The identifier for a slot type.
         * @param {string} version Version for interaction model.
         * @param {v1.skill.interactionModel.typeVersion.SlotTypeUpdate} slotTypeUpdate
         */
        callUpdateInteractionModelSlotTypeVersionV1(slotTypeId: string, version: string, slotTypeUpdate: v1.skill.interactionModel.typeVersion.SlotTypeUpdate): Promise<ApiResponse>;
        /**
         * Update description and vendorGuidance string for certain version of a slot type.
         * @param {string} slotTypeId The identifier for a slot type.
         * @param {string} version Version for interaction model.
         * @param {v1.skill.interactionModel.typeVersion.SlotTypeUpdate} slotTypeUpdate
         */
        updateInteractionModelSlotTypeVersionV1(slotTypeId: string, version: string, slotTypeUpdate: v1.skill.interactionModel.typeVersion.SlotTypeUpdate): Promise<void>;
        /**
         * Get status for given exportId
         * @param {string} exportId The Export ID.
         */
        callGetStatusOfExportRequestV1(exportId: string): Promise<ApiResponse>;
        /**
         * Get status for given exportId
         * @param {string} exportId The Export ID.
         */
        getStatusOfExportRequestV1(exportId: string): Promise<v1.skill.ExportResponse>;
        /**
         * Get the list of skills for the vendor.
         * @param {string} vendorId The vendor ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {Array<string>} skillId The list of skillIds that you wish to get the summary for. A maximum of 10 skillIds can be specified to get the skill summary in single listSkills call. Please note that this parameter must not be used with &#39;nextToken&#39; or/and &#39;maxResults&#39; parameter.
         */
        callListSkillsForVendorV1(vendorId: string, nextToken?: string, maxResults?: number, skillId?: Array<string>): Promise<ApiResponse>;
        /**
         * Get the list of skills for the vendor.
         * @param {string} vendorId The vendor ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {Array<string>} skillId The list of skillIds that you wish to get the summary for. A maximum of 10 skillIds can be specified to get the skill summary in single listSkills call. Please note that this parameter must not be used with &#39;nextToken&#39; or/and &#39;maxResults&#39; parameter.
         */
        listSkillsForVendorV1(vendorId: string, nextToken?: string, maxResults?: number, skillId?: Array<string>): Promise<v1.skill.ListSkillResponse>;
        /**
         * Get status for given importId.
         * @param {string} importId The Import ID.
         */
        callGetImportStatusV1(importId: string): Promise<ApiResponse>;
        /**
         * Get status for given importId.
         * @param {string} importId The Import ID.
         */
        getImportStatusV1(importId: string): Promise<v1.skill.ImportResponse>;
        /**
         * Creates a new import for a skill.
         * @param {v1.skill.CreateSkillWithPackageRequest} createSkillWithPackageRequest Defines the request body for createPackage API.
         */
        callCreateSkillPackageV1(createSkillWithPackageRequest: v1.skill.CreateSkillWithPackageRequest): Promise<ApiResponse>;
        /**
         * Creates a new import for a skill.
         * @param {v1.skill.CreateSkillWithPackageRequest} createSkillWithPackageRequest Defines the request body for createPackage API.
         */
        createSkillPackageV1(createSkillWithPackageRequest: v1.skill.CreateSkillWithPackageRequest): Promise<void>;
        /**
         * Creates a new skill for given vendorId.
         * @param {v1.skill.CreateSkillRequest} createSkillRequest Defines the request body for createSkill API.
         */
        callCreateSkillForVendorV1(createSkillRequest: v1.skill.CreateSkillRequest): Promise<ApiResponse>;
        /**
         * Creates a new skill for given vendorId.
         * @param {v1.skill.CreateSkillRequest} createSkillRequest Defines the request body for createSkill API.
         */
        createSkillForVendorV1(createSkillRequest: v1.skill.CreateSkillRequest): Promise<v1.skill.CreateSkillResponse>;
        /**
         * GetResourceSchema API provides schema for skill related resources. The schema returned by this API will be specific to vendor because it considers public beta features allowed for the vendor.
         * @param {string} resource Name of the ASK resource for which schema is requested.
         * @param {string} vendorId The vendor ID.
         * @param {string} operation This parameter is required when resource is manifest because skill manifest schema differs based on operation. For example, submit for certification schema has more validations than create skill schema.
         */
        callGetResourceSchemaV1(resource: string, vendorId: string, operation?: string): Promise<ApiResponse>;
        /**
         * GetResourceSchema API provides schema for skill related resources. The schema returned by this API will be specific to vendor because it considers public beta features allowed for the vendor.
         * @param {string} resource Name of the ASK resource for which schema is requested.
         * @param {string} vendorId The vendor ID.
         * @param {string} operation This parameter is required when resource is manifest because skill manifest schema differs based on operation. For example, submit for certification schema has more validations than create skill schema.
         */
        getResourceSchemaV1(resource: string, vendorId: string, operation?: string): Promise<v1.skill.resourceSchema.GetResourceSchemaResponse>;
        /**
         * Get Alexa hosted skill's metadata
         * @param {string} skillId The skill ID.
         */
        callGetAlexaHostedSkillMetadataV1(skillId: string): Promise<ApiResponse>;
        /**
         * Get Alexa hosted skill's metadata
         * @param {string} skillId The skill ID.
         */
        getAlexaHostedSkillMetadataV1(skillId: string): Promise<v1.skill.AlexaHosted.HostedSkillMetadata>;
        /**
         * Generates hosted skill repository credentials to access the hosted skill repository.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.AlexaHosted.HostedSkillRepositoryCredentialsRequest} hostedSkillRepositoryCredentialsRequest defines the request body for hosted skill repository credentials
         */
        callGenerateCredentialsForAlexaHostedSkillV1(skillId: string, hostedSkillRepositoryCredentialsRequest: v1.skill.AlexaHosted.HostedSkillRepositoryCredentialsRequest): Promise<ApiResponse>;
        /**
         * Generates hosted skill repository credentials to access the hosted skill repository.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.AlexaHosted.HostedSkillRepositoryCredentialsRequest} hostedSkillRepositoryCredentialsRequest defines the request body for hosted skill repository credentials
         */
        generateCredentialsForAlexaHostedSkillV1(skillId: string, hostedSkillRepositoryCredentialsRequest: v1.skill.AlexaHosted.HostedSkillRepositoryCredentialsRequest): Promise<v1.skill.AlexaHosted.HostedSkillRepositoryCredentialsList>;
        /**
         * End a beta test for a given Alexa skill. System will revoke the entitlement of each tester and send access-end notification email to them.
         * @param {string} skillId The skill ID.
         */
        callEndBetaTestV1(skillId: string): Promise<ApiResponse>;
        /**
         * End a beta test for a given Alexa skill. System will revoke the entitlement of each tester and send access-end notification email to them.
         * @param {string} skillId The skill ID.
         */
        endBetaTestV1(skillId: string): Promise<void>;
        /**
         * Get beta test for a given Alexa skill.
         * @param {string} skillId The skill ID.
         */
        callGetBetaTestV1(skillId: string): Promise<ApiResponse>;
        /**
         * Get beta test for a given Alexa skill.
         * @param {string} skillId The skill ID.
         */
        getBetaTestV1(skillId: string): Promise<v1.skill.betaTest.BetaTest>;
        /**
         * Create a beta test for a given Alexa skill.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.betaTest.TestBody} createTestBody JSON object containing the details of a beta test used to create the test.
         */
        callCreateBetaTestV1(skillId: string, createTestBody?: v1.skill.betaTest.TestBody): Promise<ApiResponse>;
        /**
         * Create a beta test for a given Alexa skill.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.betaTest.TestBody} createTestBody JSON object containing the details of a beta test used to create the test.
         */
        createBetaTestV1(skillId: string, createTestBody?: v1.skill.betaTest.TestBody): Promise<void>;
        /**
         * Update a beta test for a given Alexa skill.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.betaTest.TestBody} createTestBody JSON object containing the details of a beta test used to create the test.
         */
        callUpdateBetaTestV1(skillId: string, createTestBody?: v1.skill.betaTest.TestBody): Promise<ApiResponse>;
        /**
         * Update a beta test for a given Alexa skill.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.betaTest.TestBody} createTestBody JSON object containing the details of a beta test used to create the test.
         */
        updateBetaTestV1(skillId: string, createTestBody?: v1.skill.betaTest.TestBody): Promise<void>;
        /**
         * Start a beta test for a given Alexa skill. System will send invitation emails to each tester in the test, and add entitlement on the acceptance.
         * @param {string} skillId The skill ID.
         */
        callStartBetaTestV1(skillId: string): Promise<ApiResponse>;
        /**
         * Start a beta test for a given Alexa skill. System will send invitation emails to each tester in the test, and add entitlement on the acceptance.
         * @param {string} skillId The skill ID.
         */
        startBetaTestV1(skillId: string): Promise<void>;
        /**
         * Add testers to a beta test for the given Alexa skill.  System will send invitation email to each tester and add entitlement on the acceptance.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.betaTest.testers.TestersList} testersRequest JSON object containing the email address of beta testers.
         */
        callAddTestersToBetaTestV1(skillId: string, testersRequest: v1.skill.betaTest.testers.TestersList): Promise<ApiResponse>;
        /**
         * Add testers to a beta test for the given Alexa skill.  System will send invitation email to each tester and add entitlement on the acceptance.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.betaTest.testers.TestersList} testersRequest JSON object containing the email address of beta testers.
         */
        addTestersToBetaTestV1(skillId: string, testersRequest: v1.skill.betaTest.testers.TestersList): Promise<void>;
        /**
         * List all testers in a beta test for the given Alexa skill.
         * @param {string} skillId The skill ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 500 results, you can add this parameter to your request. The response might contain fewer results than maxResults, but it will never contain more.
         */
        callGetListOfTestersV1(skillId: string, nextToken?: string, maxResults?: number): Promise<ApiResponse>;
        /**
         * List all testers in a beta test for the given Alexa skill.
         * @param {string} skillId The skill ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 500 results, you can add this parameter to your request. The response might contain fewer results than maxResults, but it will never contain more.
         */
        getListOfTestersV1(skillId: string, nextToken?: string, maxResults?: number): Promise<v1.skill.betaTest.testers.ListTestersResponse>;
        /**
         * Remove testers from a beta test for the given Alexa skill.  System will send access end email to each tester and remove entitlement for them.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.betaTest.testers.TestersList} testersRequest JSON object containing the email address of beta testers.
         */
        callRemoveTestersFromBetaTestV1(skillId: string, testersRequest: v1.skill.betaTest.testers.TestersList): Promise<ApiResponse>;
        /**
         * Remove testers from a beta test for the given Alexa skill.  System will send access end email to each tester and remove entitlement for them.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.betaTest.testers.TestersList} testersRequest JSON object containing the email address of beta testers.
         */
        removeTestersFromBetaTestV1(skillId: string, testersRequest: v1.skill.betaTest.testers.TestersList): Promise<void>;
        /**
         * Request feedback from the testers in a beta test for the given Alexa skill.  System will send notification emails to testers to request feedback.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.betaTest.testers.TestersList} testersRequest JSON object containing the email address of beta testers.
         */
        callRequestFeedbackFromTestersV1(skillId: string, testersRequest: v1.skill.betaTest.testers.TestersList): Promise<ApiResponse>;
        /**
         * Request feedback from the testers in a beta test for the given Alexa skill.  System will send notification emails to testers to request feedback.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.betaTest.testers.TestersList} testersRequest JSON object containing the email address of beta testers.
         */
        requestFeedbackFromTestersV1(skillId: string, testersRequest: v1.skill.betaTest.testers.TestersList): Promise<void>;
        /**
         * Send reminder to the testers in a beta test for the given Alexa skill.  System will send invitation email to each tester and add entitlement on the acceptance.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.betaTest.testers.TestersList} testersRequest JSON object containing the email address of beta testers.
         */
        callSendReminderToTestersV1(skillId: string, testersRequest: v1.skill.betaTest.testers.TestersList): Promise<ApiResponse>;
        /**
         * Send reminder to the testers in a beta test for the given Alexa skill.  System will send invitation email to each tester and add entitlement on the acceptance.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.betaTest.testers.TestersList} testersRequest JSON object containing the email address of beta testers.
         */
        sendReminderToTestersV1(skillId: string, testersRequest: v1.skill.betaTest.testers.TestersList): Promise<void>;
        /**
         * Gets a specific certification resource. The response contains the review tracking information for a skill to show how much time the skill is expected to remain under review by Amazon. Once the review is complete, the response also contains the outcome of the review. Old certifications may not be available, however any ongoing certification would always give a response. If the certification is unavailable the result will return a 404 HTTP status code.
         * @param {string} skillId The skill ID.
         * @param {string} certificationId Id of the certification. Reserved word identifier of mostRecent can be used to get the most recent certification for the skill. Note that the behavior of the API in this case would be the same as when the actual certification id of the most recent certification is used in the request.
         * @param {string} acceptLanguage User&#39;s locale/language in context.
         */
        callGetCertificationReviewV1(skillId: string, certificationId: string, acceptLanguage?: string): Promise<ApiResponse>;
        /**
         * Gets a specific certification resource. The response contains the review tracking information for a skill to show how much time the skill is expected to remain under review by Amazon. Once the review is complete, the response also contains the outcome of the review. Old certifications may not be available, however any ongoing certification would always give a response. If the certification is unavailable the result will return a 404 HTTP status code.
         * @param {string} skillId The skill ID.
         * @param {string} certificationId Id of the certification. Reserved word identifier of mostRecent can be used to get the most recent certification for the skill. Note that the behavior of the API in this case would be the same as when the actual certification id of the most recent certification is used in the request.
         * @param {string} acceptLanguage User&#39;s locale/language in context.
         */
        getCertificationReviewV1(skillId: string, certificationId: string, acceptLanguage?: string): Promise<v1.skill.certification.CertificationResponse>;
        /**
         * Get list of all certifications available for a skill, including information about past certifications and any ongoing certification. The default sort order is descending on skillSubmissionTimestamp for Certifications.
         * @param {string} skillId The skill ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        callGetCertificationsListV1(skillId: string, nextToken?: string, maxResults?: number): Promise<ApiResponse>;
        /**
         * Get list of all certifications available for a skill, including information about past certifications and any ongoing certification. The default sort order is descending on skillSubmissionTimestamp for Certifications.
         * @param {string} skillId The skill ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        getCertificationsListV1(skillId: string, nextToken?: string, maxResults?: number): Promise<v1.skill.certification.ListCertificationsResponse>;
        /**
         * Get the client credentials for the skill.
         * @param {string} skillId The skill ID.
         */
        callGetSkillCredentialsV1(skillId: string): Promise<ApiResponse>;
        /**
         * Get the client credentials for the skill.
         * @param {string} skillId The skill ID.
         */
        getSkillCredentialsV1(skillId: string): Promise<v1.skill.SkillCredentials>;
        /**
         * Delete the skill and model for given skillId.
         * @param {string} skillId The skill ID.
         */
        callDeleteSkillV1(skillId: string): Promise<ApiResponse>;
        /**
         * Delete the skill and model for given skillId.
         * @param {string} skillId The skill ID.
         */
        deleteSkillV1(skillId: string): Promise<void>;
        /**
         * Deletes an existing experiment for a skill.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         */
        callDeleteExperimentV1(skillId: string, experimentId: string): Promise<ApiResponse>;
        /**
         * Deletes an existing experiment for a skill.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         */
        deleteExperimentV1(skillId: string, experimentId: string): Promise<void>;
        /**
         * Updates the exposure of an experiment that is in CREATED or RUNNING state.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         * @param {v1.skill.experiment.UpdateExposureRequest} updateExposureRequest Defines the request body for updating the exposure percentage of a running experiment.
         */
        callUpdateExposureV1(skillId: string, experimentId: string, updateExposureRequest: v1.skill.experiment.UpdateExposureRequest): Promise<ApiResponse>;
        /**
         * Updates the exposure of an experiment that is in CREATED or RUNNING state.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         * @param {v1.skill.experiment.UpdateExposureRequest} updateExposureRequest Defines the request body for updating the exposure percentage of a running experiment.
         */
        updateExposureV1(skillId: string, experimentId: string, updateExposureRequest: v1.skill.experiment.UpdateExposureRequest): Promise<void>;
        /**
         * Retrieves an existing experiment for a skill.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         */
        callGetExperimentV1(skillId: string, experimentId: string): Promise<ApiResponse>;
        /**
         * Retrieves an existing experiment for a skill.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         */
        getExperimentV1(skillId: string, experimentId: string): Promise<v1.skill.experiment.GetExperimentResponse>;
        /**
         * Gets a list of all metric snapshots associated with this experiment id. The metric snapshots represent the metric data available for a time range.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        callListExperimentMetricSnapshotsV1(skillId: string, experimentId: string, nextToken?: string, maxResults?: number): Promise<ApiResponse>;
        /**
         * Gets a list of all metric snapshots associated with this experiment id. The metric snapshots represent the metric data available for a time range.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        listExperimentMetricSnapshotsV1(skillId: string, experimentId: string, nextToken?: string, maxResults?: number): Promise<v1.skill.experiment.ListExperimentMetricSnapshotsResponse>;
        /**
         * Gets a list of all metric data associated with this experiment's metric snapshot.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         * @param {string} metricSnapshotId Identifies the experiment metric snapshot in a skill experiment. The metric snapshot represents metric data for a date range.
         */
        callGetExperimentMetricSnapshotV1(skillId: string, experimentId: string, metricSnapshotId: string): Promise<ApiResponse>;
        /**
         * Gets a list of all metric data associated with this experiment's metric snapshot.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         * @param {string} metricSnapshotId Identifies the experiment metric snapshot in a skill experiment. The metric snapshot represents metric data for a date range.
         */
        getExperimentMetricSnapshotV1(skillId: string, experimentId: string, metricSnapshotId: string): Promise<v1.skill.experiment.GetExperimentMetricSnapshotResponse>;
        /**
         * Updates an existing experiment for a skill. Can only be called while the experiment is in CREATED state.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         * @param {v1.skill.experiment.UpdateExperimentRequest} updateExperimentRequest Defines the request body for updating an experiment.
         */
        callUpdateExperimentV1(skillId: string, experimentId: string, updateExperimentRequest: v1.skill.experiment.UpdateExperimentRequest): Promise<ApiResponse>;
        /**
         * Updates an existing experiment for a skill. Can only be called while the experiment is in CREATED state.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         * @param {v1.skill.experiment.UpdateExperimentRequest} updateExperimentRequest Defines the request body for updating an experiment.
         */
        updateExperimentV1(skillId: string, experimentId: string, updateExperimentRequest: v1.skill.experiment.UpdateExperimentRequest): Promise<void>;
        /**
         * Retrieves the current state of the experiment.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         */
        callGetExperimentStateV1(skillId: string, experimentId: string): Promise<ApiResponse>;
        /**
         * Retrieves the current state of the experiment.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         */
        getExperimentStateV1(skillId: string, experimentId: string): Promise<v1.skill.experiment.GetExperimentStateResponse>;
        /**
         * Requests an action on the experiment to move it to the targetState. Acceptable targetState values are: * `ENABLED`: Experiment configurations are deployed and customer overrides are enabled. Actual experiment has not started yet but customers with overrides set to T1 will see the T1 behavior. Initial state must be CREATED. * `RUNNING`: Starts the experiment with the configured exposure. Skill customers selected to be in the experiment will start contributing to the metric data. Initial state must be CREATED or ENABLED. * `STOPPED`: Stops the experiment by removing the experiment configurations. All customer treatment overrides are removed. Initial state must be ENABLED or RUNNING.              Final state for ENDPOINT_BASED experiments, no further action is taken by ASK. It is expected that the skill builder updates their endpoint code to make T1 the default live behavior.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         * @param {v1.skill.experiment.ManageExperimentStateRequest} manageExperimentStateRequest Defines the request body for performing an experiment action to move it to a target state.
         */
        callManageExperimentStateV1(skillId: string, experimentId: string, manageExperimentStateRequest: v1.skill.experiment.ManageExperimentStateRequest): Promise<ApiResponse>;
        /**
         * Requests an action on the experiment to move it to the targetState. Acceptable targetState values are: * `ENABLED`: Experiment configurations are deployed and customer overrides are enabled. Actual experiment has not started yet but customers with overrides set to T1 will see the T1 behavior. Initial state must be CREATED. * `RUNNING`: Starts the experiment with the configured exposure. Skill customers selected to be in the experiment will start contributing to the metric data. Initial state must be CREATED or ENABLED. * `STOPPED`: Stops the experiment by removing the experiment configurations. All customer treatment overrides are removed. Initial state must be ENABLED or RUNNING.              Final state for ENDPOINT_BASED experiments, no further action is taken by ASK. It is expected that the skill builder updates their endpoint code to make T1 the default live behavior.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         * @param {v1.skill.experiment.ManageExperimentStateRequest} manageExperimentStateRequest Defines the request body for performing an experiment action to move it to a target state.
         */
        manageExperimentStateV1(skillId: string, experimentId: string, manageExperimentStateRequest: v1.skill.experiment.ManageExperimentStateRequest): Promise<void>;
        /**
         * Retrieves the current user's customer treatment override for an existing A/B Test experiment. The current user must be under the same skill vendor of the requested skill id to have access to the resource.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         */
        callGetCustomerTreatmentOverrideV1(skillId: string, experimentId: string): Promise<ApiResponse>;
        /**
         * Retrieves the current user's customer treatment override for an existing A/B Test experiment. The current user must be under the same skill vendor of the requested skill id to have access to the resource.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         */
        getCustomerTreatmentOverrideV1(skillId: string, experimentId: string): Promise<v1.skill.experiment.GetCustomerTreatmentOverrideResponse>;
        /**
         * Adds the requesting user's customer treatment override to an existing experiment. The current user must be under the same skill vendor of the requested skill id to have access to the resource. Only the current user can attempt to add the override of their own customer account to an experiment. Can only be called before the experiment is enabled.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         * @param {v1.skill.experiment.SetCustomerTreatmentOverrideRequest} setCustomerTreatmentOverrideRequest Defines the request body for adding this customer&#39;s treatment override to an experiment.
         */
        callSetCustomerTreatmentOverrideV1(skillId: string, experimentId: string, setCustomerTreatmentOverrideRequest: v1.skill.experiment.SetCustomerTreatmentOverrideRequest): Promise<ApiResponse>;
        /**
         * Adds the requesting user's customer treatment override to an existing experiment. The current user must be under the same skill vendor of the requested skill id to have access to the resource. Only the current user can attempt to add the override of their own customer account to an experiment. Can only be called before the experiment is enabled.
         * @param {string} skillId The skill ID.
         * @param {string} experimentId Identifies the experiment in a skill.
         * @param {v1.skill.experiment.SetCustomerTreatmentOverrideRequest} setCustomerTreatmentOverrideRequest Defines the request body for adding this customer&#39;s treatment override to an experiment.
         */
        setCustomerTreatmentOverrideV1(skillId: string, experimentId: string, setCustomerTreatmentOverrideRequest: v1.skill.experiment.SetCustomerTreatmentOverrideRequest): Promise<void>;
        /**
         * Gets a list of all experiments associated with this skill id.
         * @param {string} skillId The skill ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        callListExperimentsV1(skillId: string, nextToken?: string, maxResults?: number): Promise<ApiResponse>;
        /**
         * Gets a list of all experiments associated with this skill id.
         * @param {string} skillId The skill ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        listExperimentsV1(skillId: string, nextToken?: string, maxResults?: number): Promise<v1.skill.experiment.ListExperimentsResponse>;
        /**
         * Create a new experiment for a skill.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.experiment.CreateExperimentRequest} createExperimentRequest Defines the request body for creating an experiment.
         */
        callCreateExperimentV1(skillId: string, createExperimentRequest: v1.skill.experiment.CreateExperimentRequest): Promise<ApiResponse>;
        /**
         * Create a new experiment for a skill.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.experiment.CreateExperimentRequest} createExperimentRequest Defines the request body for creating an experiment.
         */
        createExperimentV1(skillId: string, createExperimentRequest: v1.skill.experiment.CreateExperimentRequest): Promise<void>;
        /**
         *
         * @param {string} skillId The skill ID.
         * @param {string} stage The stage of the skill to be used for evaluation. An error will be returned if this skill stage is not enabled on the account used for evaluation.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} sortDirection Sets the sorting direction of the result items. When set to &#39;asc&#39; these items are returned in ascending order of sortField value and when set to &#39;desc&#39; these items are returned in descending order of sortField value.
         * @param {string} sortField Sets the field on which the sorting would be applied.
         * @param {Array<v1.skill.history.LocaleInQuery>} locale
         * @param {Array<v1.skill.history.DialogActName>} dialogActName A filter used to retrieve items where the dialogAct name is equal to the given value. * &#x60;Dialog.ElicitSlot&#x60;: Alexa asked the user for the value of a specific slot. (https://developer.amazon.com/docs/custom-skills/dialog-interface-reference.html#elicitslot) * &#x60;Dialog.ConfirmSlot&#x60;: Alexa confirmed the value of a specific slot before continuing with the dialog. (https://developer.amazon.com/docs/custom-skills/dialog-interface-reference.html#confirmslot) * &#x60;Dialog.ConfirmIntent&#x60;: Alexa confirmed the all the information the user has provided for the intent before the skill took action. (https://developer.amazon.com/docs/custom-skills/dialog-interface-reference.html#confirmintent)
         * @param {Array<v1.skill.history.IntentConfidenceBin>} intentConfidenceBin
         * @param {Array<string>} intentName A filter used to retrieve items where the intent name is equal to the given value.
         * @param {Array<string>} intentSlotsName A filter used to retrieve items where the one of the slot names is equal to the given value.
         * @param {Array<v1.skill.history.InteractionType>} interactionType
         * @param {Array<v1.skill.history.PublicationStatus>} publicationStatus
         * @param {Array<string>} utteranceText A filter used to retrieve items where the utterance text contains the given phrase. Each filter value can be at-least 1 character and at-most 100 characters long.
         */
        callGetUtteranceDataV1(skillId: string, stage: string, nextToken?: string, maxResults?: number, sortDirection?: string, sortField?: string, locale?: Array<v1.skill.history.LocaleInQuery>, dialogActName?: Array<v1.skill.history.DialogActName>, intentConfidenceBin?: Array<v1.skill.history.IntentConfidenceBin>, intentName?: Array<string>, intentSlotsName?: Array<string>, interactionType?: Array<v1.skill.history.InteractionType>, publicationStatus?: Array<v1.skill.history.PublicationStatus>, utteranceText?: Array<string>): Promise<ApiResponse>;
        /**
         *
         * @param {string} skillId The skill ID.
         * @param {string} stage The stage of the skill to be used for evaluation. An error will be returned if this skill stage is not enabled on the account used for evaluation.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} sortDirection Sets the sorting direction of the result items. When set to &#39;asc&#39; these items are returned in ascending order of sortField value and when set to &#39;desc&#39; these items are returned in descending order of sortField value.
         * @param {string} sortField Sets the field on which the sorting would be applied.
         * @param {Array<v1.skill.history.LocaleInQuery>} locale
         * @param {Array<v1.skill.history.DialogActName>} dialogActName A filter used to retrieve items where the dialogAct name is equal to the given value. * &#x60;Dialog.ElicitSlot&#x60;: Alexa asked the user for the value of a specific slot. (https://developer.amazon.com/docs/custom-skills/dialog-interface-reference.html#elicitslot) * &#x60;Dialog.ConfirmSlot&#x60;: Alexa confirmed the value of a specific slot before continuing with the dialog. (https://developer.amazon.com/docs/custom-skills/dialog-interface-reference.html#confirmslot) * &#x60;Dialog.ConfirmIntent&#x60;: Alexa confirmed the all the information the user has provided for the intent before the skill took action. (https://developer.amazon.com/docs/custom-skills/dialog-interface-reference.html#confirmintent)
         * @param {Array<v1.skill.history.IntentConfidenceBin>} intentConfidenceBin
         * @param {Array<string>} intentName A filter used to retrieve items where the intent name is equal to the given value.
         * @param {Array<string>} intentSlotsName A filter used to retrieve items where the one of the slot names is equal to the given value.
         * @param {Array<v1.skill.history.InteractionType>} interactionType
         * @param {Array<v1.skill.history.PublicationStatus>} publicationStatus
         * @param {Array<string>} utteranceText A filter used to retrieve items where the utterance text contains the given phrase. Each filter value can be at-least 1 character and at-most 100 characters long.
         */
        getUtteranceDataV1(skillId: string, stage: string, nextToken?: string, maxResults?: number, sortDirection?: string, sortField?: string, locale?: Array<v1.skill.history.LocaleInQuery>, dialogActName?: Array<v1.skill.history.DialogActName>, intentConfidenceBin?: Array<v1.skill.history.IntentConfidenceBin>, intentName?: Array<string>, intentSlotsName?: Array<string>, interactionType?: Array<v1.skill.history.InteractionType>, publicationStatus?: Array<v1.skill.history.PublicationStatus>, utteranceText?: Array<string>): Promise<v1.skill.history.IntentRequests>;
        /**
         * Creates a new import for a skill with given skillId.
         * @param {v1.skill.UpdateSkillWithPackageRequest} updateSkillWithPackageRequest Defines the request body for updatePackage API.
         * @param {string} skillId The skill ID.
         * @param {string} ifMatch Request header that specified an entity tag. The server will update the resource only if the eTag matches with the resource&#39;s current eTag.
         */
        callImportSkillPackageV1(updateSkillWithPackageRequest: v1.skill.UpdateSkillWithPackageRequest, skillId: string, ifMatch?: string): Promise<ApiResponse>;
        /**
         * Creates a new import for a skill with given skillId.
         * @param {v1.skill.UpdateSkillWithPackageRequest} updateSkillWithPackageRequest Defines the request body for updatePackage API.
         * @param {string} skillId The skill ID.
         * @param {string} ifMatch Request header that specified an entity tag. The server will update the resource only if the eTag matches with the resource&#39;s current eTag.
         */
        importSkillPackageV1(updateSkillWithPackageRequest: v1.skill.UpdateSkillWithPackageRequest, skillId: string, ifMatch?: string): Promise<void>;
        /**
         * This is a synchronous API that invokes the Lambda or third party HTTPS endpoint for a given skill. A successful response will contain information related to what endpoint was called, payload sent to and received from the endpoint. In cases where requests to this API results in an error, the response will contain an error code and a description of the problem. In cases where invoking the skill endpoint specifically fails, the response will contain a status attribute indicating that a failure occurred and details about what was sent to the endpoint. The skill must belong to and be enabled by the user of this API. Also, note that calls to the skill endpoint will timeout after 10 seconds.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.invocations.InvokeSkillRequest} invokeSkillRequest Payload sent to the skill invocation API.
         */
        callInvokeSkillV1(skillId: string, invokeSkillRequest: v1.skill.invocations.InvokeSkillRequest): Promise<ApiResponse>;
        /**
         * This is a synchronous API that invokes the Lambda or third party HTTPS endpoint for a given skill. A successful response will contain information related to what endpoint was called, payload sent to and received from the endpoint. In cases where requests to this API results in an error, the response will contain an error code and a description of the problem. In cases where invoking the skill endpoint specifically fails, the response will contain a status attribute indicating that a failure occurred and details about what was sent to the endpoint. The skill must belong to and be enabled by the user of this API. Also, note that calls to the skill endpoint will timeout after 10 seconds.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.invocations.InvokeSkillRequest} invokeSkillRequest Payload sent to the skill invocation API.
         */
        invokeSkillV1(skillId: string, invokeSkillRequest: v1.skill.invocations.InvokeSkillRequest): Promise<v1.skill.invocations.InvokeSkillResponse>;
        /**
         * Get analytic metrics report of skill usage.
         * @param {string} skillId The skill ID.
         * @param {string} startTime The start time of query.
         * @param {string} endTime The end time of query (The maximum time duration is 1 week)
         * @param {string} period The aggregation period to use when retrieving the metric, follows ISO_8601#Durations format.
         * @param {string} metric A distinct set of logic which predictably returns a set of data.
         * @param {string} stage The stage of the skill (live, development).
         * @param {string} skillType The type of the skill (custom, smartHome and flashBriefing).
         * @param {string} intent The intent of the skill.
         * @param {string} locale The locale for the skill. e.g. en-GB, en-US, de-DE and etc.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         */
        callGetSkillMetricsV1(skillId: string, startTime: string, endTime: string, period: string, metric: string, stage: string, skillType: string, intent?: string, locale?: string, maxResults?: number, nextToken?: string): Promise<ApiResponse>;
        /**
         * Get analytic metrics report of skill usage.
         * @param {string} skillId The skill ID.
         * @param {string} startTime The start time of query.
         * @param {string} endTime The end time of query (The maximum time duration is 1 week)
         * @param {string} period The aggregation period to use when retrieving the metric, follows ISO_8601#Durations format.
         * @param {string} metric A distinct set of logic which predictably returns a set of data.
         * @param {string} stage The stage of the skill (live, development).
         * @param {string} skillType The type of the skill (custom, smartHome and flashBriefing).
         * @param {string} intent The intent of the skill.
         * @param {string} locale The locale for the skill. e.g. en-GB, en-US, de-DE and etc.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         */
        getSkillMetricsV1(skillId: string, startTime: string, endTime: string, period: string, metric: string, stage: string, skillType: string, intent?: string, locale?: string, maxResults?: number, nextToken?: string): Promise<v1.skill.metrics.GetMetricDataResponse>;
        /**
         *
         * @param {string} skillId The skill ID.
         * @param {string} annotationId Identifier of the NLU annotation set.
         * @param {string} accept Standard HTTP. Pass &#x60;application/json&#x60; or &#x60;test/csv&#x60; for GET calls.
         */
        callGetAnnotationsForNLUAnnotationSetsV1(skillId: string, annotationId: string, accept: string): Promise<ApiResponse>;
        /**
         *
         * @param {string} skillId The skill ID.
         * @param {string} annotationId Identifier of the NLU annotation set.
         * @param {string} accept Standard HTTP. Pass &#x60;application/json&#x60; or &#x60;test/csv&#x60; for GET calls.
         */
        getAnnotationsForNLUAnnotationSetsV1(skillId: string, annotationId: string, accept: string): Promise<void>;
        /**
         * API which replaces the annotations in NLU annotation set.
         * @param {string} skillId The skill ID.
         * @param {string} annotationId Identifier of the NLU annotation set.
         * @param {string} contentType Standard HTTP. Pass &#x60;application/json&#x60; or &#x60;test/csv&#x60; for POST calls with a json/csv body.
         * @param {v1.skill.nlu.annotationSets.UpdateNLUAnnotationSetAnnotationsRequest} updateNLUAnnotationSetAnnotationsRequest Payload sent to the update NLU annotation set API.
         */
        callUpdateAnnotationsForNLUAnnotationSetsV1(skillId: string, annotationId: string, contentType: string, updateNLUAnnotationSetAnnotationsRequest: v1.skill.nlu.annotationSets.UpdateNLUAnnotationSetAnnotationsRequest): Promise<ApiResponse>;
        /**
         * API which replaces the annotations in NLU annotation set.
         * @param {string} skillId The skill ID.
         * @param {string} annotationId Identifier of the NLU annotation set.
         * @param {string} contentType Standard HTTP. Pass &#x60;application/json&#x60; or &#x60;test/csv&#x60; for POST calls with a json/csv body.
         * @param {v1.skill.nlu.annotationSets.UpdateNLUAnnotationSetAnnotationsRequest} updateNLUAnnotationSetAnnotationsRequest Payload sent to the update NLU annotation set API.
         */
        updateAnnotationsForNLUAnnotationSetsV1(skillId: string, annotationId: string, contentType: string, updateNLUAnnotationSetAnnotationsRequest: v1.skill.nlu.annotationSets.UpdateNLUAnnotationSetAnnotationsRequest): Promise<void>;
        /**
         * API which deletes the NLU annotation set. Developers cannot get/list the deleted annotation set.
         * @param {string} skillId The skill ID.
         * @param {string} annotationId Identifier of the NLU annotation set.
         */
        callDeletePropertiesForNLUAnnotationSetsV1(skillId: string, annotationId: string): Promise<ApiResponse>;
        /**
         * API which deletes the NLU annotation set. Developers cannot get/list the deleted annotation set.
         * @param {string} skillId The skill ID.
         * @param {string} annotationId Identifier of the NLU annotation set.
         */
        deletePropertiesForNLUAnnotationSetsV1(skillId: string, annotationId: string): Promise<void>;
        /**
         * Return the properties for an NLU annotation set.
         * @param {string} skillId The skill ID.
         * @param {string} annotationId Identifier of the NLU annotation set.
         */
        callGetPropertiesForNLUAnnotationSetsV1(skillId: string, annotationId: string): Promise<ApiResponse>;
        /**
         * Return the properties for an NLU annotation set.
         * @param {string} skillId The skill ID.
         * @param {string} annotationId Identifier of the NLU annotation set.
         */
        getPropertiesForNLUAnnotationSetsV1(skillId: string, annotationId: string): Promise<v1.skill.nlu.annotationSets.GetNLUAnnotationSetPropertiesResponse>;
        /**
         * API which updates the NLU annotation set properties. Currently, the only data can be updated is annotation set name.
         * @param {string} skillId The skill ID.
         * @param {string} annotationId Identifier of the NLU annotation set.
         * @param {v1.skill.nlu.annotationSets.UpdateNLUAnnotationSetPropertiesRequest} updateNLUAnnotationSetPropertiesRequest Payload sent to the update NLU annotation set properties API.
         */
        callUpdatePropertiesForNLUAnnotationSetsV1(skillId: string, annotationId: string, updateNLUAnnotationSetPropertiesRequest: v1.skill.nlu.annotationSets.UpdateNLUAnnotationSetPropertiesRequest): Promise<ApiResponse>;
        /**
         * API which updates the NLU annotation set properties. Currently, the only data can be updated is annotation set name.
         * @param {string} skillId The skill ID.
         * @param {string} annotationId Identifier of the NLU annotation set.
         * @param {v1.skill.nlu.annotationSets.UpdateNLUAnnotationSetPropertiesRequest} updateNLUAnnotationSetPropertiesRequest Payload sent to the update NLU annotation set properties API.
         */
        updatePropertiesForNLUAnnotationSetsV1(skillId: string, annotationId: string, updateNLUAnnotationSetPropertiesRequest: v1.skill.nlu.annotationSets.UpdateNLUAnnotationSetPropertiesRequest): Promise<void>;
        /**
         * API which requests all the NLU annotation sets for a skill. Returns the annotationId and properties for each NLU annotation set. Developers can filter the results using locale. Supports paging of results.
         * @param {string} skillId The skill ID.
         * @param {string} locale filter to NLU annotation set created using this locale
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. Defaults to 10. If more results are present, the response will contain a nextToken and a _link.next href.
         */
        callListNLUAnnotationSetsV1(skillId: string, locale?: string, nextToken?: string, maxResults?: number): Promise<ApiResponse>;
        /**
         * API which requests all the NLU annotation sets for a skill. Returns the annotationId and properties for each NLU annotation set. Developers can filter the results using locale. Supports paging of results.
         * @param {string} skillId The skill ID.
         * @param {string} locale filter to NLU annotation set created using this locale
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. Defaults to 10. If more results are present, the response will contain a nextToken and a _link.next href.
         */
        listNLUAnnotationSetsV1(skillId: string, locale?: string, nextToken?: string, maxResults?: number): Promise<v1.skill.nlu.annotationSets.ListNLUAnnotationSetsResponse>;
        /**
         * This is an API that creates a new NLU annotation set with properties and returns the annotationId.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.nlu.annotationSets.CreateNLUAnnotationSetRequest} createNLUAnnotationSetRequest Payload sent to the create NLU annotation set API.
         */
        callCreateNLUAnnotationSetV1(skillId: string, createNLUAnnotationSetRequest: v1.skill.nlu.annotationSets.CreateNLUAnnotationSetRequest): Promise<ApiResponse>;
        /**
         * This is an API that creates a new NLU annotation set with properties and returns the annotationId.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.nlu.annotationSets.CreateNLUAnnotationSetRequest} createNLUAnnotationSetRequest Payload sent to the create NLU annotation set API.
         */
        createNLUAnnotationSetV1(skillId: string, createNLUAnnotationSetRequest: v1.skill.nlu.annotationSets.CreateNLUAnnotationSetRequest): Promise<v1.skill.nlu.annotationSets.CreateNLUAnnotationSetResponse>;
        /**
         * API which requests top level information about the evaluation like the current state of the job, status of the evaluation (if complete). Also returns data used to start the job, like the number of test cases, stage, locale, and start time. This should be considered the 'cheap' operation while getResultForNLUEvaluations is 'expensive'.
         * @param {string} skillId The skill ID.
         * @param {string} evaluationId Identifier of the evaluation.
         */
        callGetNLUEvaluationV1(skillId: string, evaluationId: string): Promise<ApiResponse>;
        /**
         * API which requests top level information about the evaluation like the current state of the job, status of the evaluation (if complete). Also returns data used to start the job, like the number of test cases, stage, locale, and start time. This should be considered the 'cheap' operation while getResultForNLUEvaluations is 'expensive'.
         * @param {string} skillId The skill ID.
         * @param {string} evaluationId Identifier of the evaluation.
         */
        getNLUEvaluationV1(skillId: string, evaluationId: string): Promise<v1.skill.nlu.evaluations.GetNLUEvaluationResponse>;
        /**
         * Paginated API which returns the test case results of an evaluation. This should be considered the 'expensive' operation while getNluEvaluation is 'cheap'.
         * @param {string} skillId The skill ID.
         * @param {string} evaluationId Identifier of the evaluation.
         * @param {string} sortField
         * @param {string} testCaseStatus only returns test cases with this status
         * @param {string} actualIntentName only returns test cases with intents which resolve to this intent
         * @param {string} expectedIntentName only returns test cases with intents which are expected to be this intent
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. Defaults to 1000. If more results are present, the response will contain a nextToken and a _link.next href.
         */
        callGetResultForNLUEvaluationsV1(skillId: string, evaluationId: string, sortField?: string, testCaseStatus?: string, actualIntentName?: string, expectedIntentName?: string, nextToken?: string, maxResults?: number): Promise<ApiResponse>;
        /**
         * Paginated API which returns the test case results of an evaluation. This should be considered the 'expensive' operation while getNluEvaluation is 'cheap'.
         * @param {string} skillId The skill ID.
         * @param {string} evaluationId Identifier of the evaluation.
         * @param {string} sortField
         * @param {string} testCaseStatus only returns test cases with this status
         * @param {string} actualIntentName only returns test cases with intents which resolve to this intent
         * @param {string} expectedIntentName only returns test cases with intents which are expected to be this intent
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. Defaults to 1000. If more results are present, the response will contain a nextToken and a _link.next href.
         */
        getResultForNLUEvaluationsV1(skillId: string, evaluationId: string, sortField?: string, testCaseStatus?: string, actualIntentName?: string, expectedIntentName?: string, nextToken?: string, maxResults?: number): Promise<v1.skill.nlu.evaluations.GetNLUEvaluationResultsResponse>;
        /**
         * API which requests recently run nlu evaluations started by a vendor for a skill. Returns the evaluation id and some of the parameters used to start the evaluation. Developers can filter the results using locale and stage. Supports paging of results.
         * @param {string} skillId The skill ID.
         * @param {string} locale filter to evaluations started using this locale
         * @param {string} stage filter to evaluations started using this stage
         * @param {string} annotationId filter to evaluations started using this annotationId
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. Defaults to 10. If more results are present, the response will contain a nextToken and a _link.next href.
         */
        callListNLUEvaluationsV1(skillId: string, locale?: string, stage?: string, annotationId?: string, nextToken?: string, maxResults?: number): Promise<ApiResponse>;
        /**
         * API which requests recently run nlu evaluations started by a vendor for a skill. Returns the evaluation id and some of the parameters used to start the evaluation. Developers can filter the results using locale and stage. Supports paging of results.
         * @param {string} skillId The skill ID.
         * @param {string} locale filter to evaluations started using this locale
         * @param {string} stage filter to evaluations started using this stage
         * @param {string} annotationId filter to evaluations started using this annotationId
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. Defaults to 10. If more results are present, the response will contain a nextToken and a _link.next href.
         */
        listNLUEvaluationsV1(skillId: string, locale?: string, stage?: string, annotationId?: string, nextToken?: string, maxResults?: number): Promise<v1.skill.nlu.evaluations.ListNLUEvaluationsResponse>;
        /**
         * This is an asynchronous API that starts an evaluation against the NLU model built by the skill's interaction model. The operation outputs an evaluationId which allows the retrieval of the current status of the operation and the results upon completion. This operation is unified, meaning both internal and external skill developers may use it evaluate NLU models.
         * @param {v1.skill.nlu.evaluations.EvaluateNLURequest} evaluateNLURequest Payload sent to the evaluate NLU API.
         * @param {string} skillId The skill ID.
         */
        callCreateNLUEvaluationsV1(evaluateNLURequest: v1.skill.nlu.evaluations.EvaluateNLURequest, skillId: string): Promise<ApiResponse>;
        /**
         * This is an asynchronous API that starts an evaluation against the NLU model built by the skill's interaction model. The operation outputs an evaluationId which allows the retrieval of the current status of the operation and the results upon completion. This operation is unified, meaning both internal and external skill developers may use it evaluate NLU models.
         * @param {v1.skill.nlu.evaluations.EvaluateNLURequest} evaluateNLURequest Payload sent to the evaluate NLU API.
         * @param {string} skillId The skill ID.
         */
        createNLUEvaluationsV1(evaluateNLURequest: v1.skill.nlu.evaluations.EvaluateNLURequest, skillId: string): Promise<v1.skill.nlu.evaluations.EvaluateResponse>;
        /**
         * If the skill is in certified stage, initiate publishing immediately or set a date at which the skill can publish at.
         * @param {string} skillId The skill ID.
         * @param {string} acceptLanguage User&#39;s locale/language in context.
         * @param {v1.skill.publication.PublishSkillRequest} publishSkillRequest Defines the request body for publish skill API.
         */
        callPublishSkillV1(skillId: string, acceptLanguage: string, publishSkillRequest?: v1.skill.publication.PublishSkillRequest): Promise<ApiResponse>;
        /**
         * If the skill is in certified stage, initiate publishing immediately or set a date at which the skill can publish at.
         * @param {string} skillId The skill ID.
         * @param {string} acceptLanguage User&#39;s locale/language in context.
         * @param {v1.skill.publication.PublishSkillRequest} publishSkillRequest Defines the request body for publish skill API.
         */
        publishSkillV1(skillId: string, acceptLanguage: string, publishSkillRequest?: v1.skill.publication.PublishSkillRequest): Promise<v1.skill.publication.SkillPublicationResponse>;
        /**
         * Retrieves the latest skill publishing details of the certified stage of the skill. The publishesAtDate and status of skill publishing.
         * @param {string} skillId The skill ID.
         * @param {string} acceptLanguage User&#39;s locale/language in context.
         */
        callGetSkillPublicationsV1(skillId: string, acceptLanguage: string): Promise<ApiResponse>;
        /**
         * Retrieves the latest skill publishing details of the certified stage of the skill. The publishesAtDate and status of skill publishing.
         * @param {string} skillId The skill ID.
         * @param {string} acceptLanguage User&#39;s locale/language in context.
         */
        getSkillPublicationsV1(skillId: string, acceptLanguage: string): Promise<v1.skill.publication.SkillPublicationResponse>;
        /**
         * Submit a target skill version to rollback to. Only one rollback or publish operation can be outstanding for a given skillId.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.CreateRollbackRequest} createRollbackRequest defines the request body to create a rollback request
         */
        callRollbackSkillV1(skillId: string, createRollbackRequest: v1.skill.CreateRollbackRequest): Promise<ApiResponse>;
        /**
         * Submit a target skill version to rollback to. Only one rollback or publish operation can be outstanding for a given skillId.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.CreateRollbackRequest} createRollbackRequest defines the request body to create a rollback request
         */
        rollbackSkillV1(skillId: string, createRollbackRequest: v1.skill.CreateRollbackRequest): Promise<v1.skill.CreateRollbackResponse>;
        /**
         * Get the rollback status of a skill given an associated rollbackRequestId. Use ~latest in place of rollbackRequestId to get the latest rollback status.
         * @param {string} skillId The skill ID.
         * @param {string} rollbackRequestId Defines the identifier for a rollback request. If set to ~latest, request returns the status of the latest rollback request.
         */
        callGetRollbackForSkillV1(skillId: string, rollbackRequestId: string): Promise<ApiResponse>;
        /**
         * Get the rollback status of a skill given an associated rollbackRequestId. Use ~latest in place of rollbackRequestId to get the latest rollback status.
         * @param {string} skillId The skill ID.
         * @param {string} rollbackRequestId Defines the identifier for a rollback request. If set to ~latest, request returns the status of the latest rollback request.
         */
        getRollbackForSkillV1(skillId: string, rollbackRequestId: string): Promise<v1.skill.RollbackRequestStatus>;
        /**
         * This is an asynchronous API that simulates a skill execution in the Alexa eco-system given an utterance text of what a customer would say to Alexa. A successful response will contain a header with the location of the simulation resource. In cases where requests to this API results in an error, the response will contain an error code and a description of the problem. The skill being simulated must be in development stage, and it must also belong to and be enabled by the user of this API. Concurrent requests per user is currently not supported.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.simulations.SimulationsApiRequest} simulationsApiRequest Payload sent to the skill simulation API.
         */
        callSimulateSkillV1(skillId: string, simulationsApiRequest: v1.skill.simulations.SimulationsApiRequest): Promise<ApiResponse>;
        /**
         * This is an asynchronous API that simulates a skill execution in the Alexa eco-system given an utterance text of what a customer would say to Alexa. A successful response will contain a header with the location of the simulation resource. In cases where requests to this API results in an error, the response will contain an error code and a description of the problem. The skill being simulated must be in development stage, and it must also belong to and be enabled by the user of this API. Concurrent requests per user is currently not supported.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.simulations.SimulationsApiRequest} simulationsApiRequest Payload sent to the skill simulation API.
         */
        simulateSkillV1(skillId: string, simulationsApiRequest: v1.skill.simulations.SimulationsApiRequest): Promise<v1.skill.simulations.SimulationsApiResponse>;
        /**
         * This API gets the result of a previously executed simulation. A successful response will contain the status of the executed simulation. If the simulation successfully completed, the response will also contain information related to skill invocation. In cases where requests to this API results in an error, the response will contain an error code and a description of the problem. In cases where the simulation failed, the response will contain a status attribute indicating that a failure occurred and details about what was sent to the skill endpoint. Note that simulation results are stored for 10 minutes. A request for an expired simulation result will return a 404 HTTP status code.
         * @param {string} skillId The skill ID.
         * @param {string} simulationId Id of the simulation.
         */
        callGetSkillSimulationV1(skillId: string, simulationId: string): Promise<ApiResponse>;
        /**
         * This API gets the result of a previously executed simulation. A successful response will contain the status of the executed simulation. If the simulation successfully completed, the response will also contain information related to skill invocation. In cases where requests to this API results in an error, the response will contain an error code and a description of the problem. In cases where the simulation failed, the response will contain a status attribute indicating that a failure occurred and details about what was sent to the skill endpoint. Note that simulation results are stored for 10 minutes. A request for an expired simulation result will return a 404 HTTP status code.
         * @param {string} skillId The skill ID.
         * @param {string} simulationId Id of the simulation.
         */
        getSkillSimulationV1(skillId: string, simulationId: string): Promise<v1.skill.simulations.SimulationsApiResponse>;
        /**
         * Get top level information and status of a Smart Home capability evaluation.
         * @param {string} skillId The skill ID.
         * @param {string} evaluationId A unique ID to identify each Smart Home capability evaluation.
         */
        callGetSmartHomeCapabilityEvaluationV1(skillId: string, evaluationId: string): Promise<ApiResponse>;
        /**
         * Get top level information and status of a Smart Home capability evaluation.
         * @param {string} skillId The skill ID.
         * @param {string} evaluationId A unique ID to identify each Smart Home capability evaluation.
         */
        getSmartHomeCapabilityEvaluationV1(skillId: string, evaluationId: string): Promise<v1.smartHomeEvaluation.GetSHCapabilityEvaluationResponse>;
        /**
         * Get test case results for an evaluation run.
         * @param {string} skillId The skill ID.
         * @param {string} evaluationId A unique ID to identify each Smart Home capability evaluation.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         */
        callGetSmarthomeCapablityEvaluationResultsV1(skillId: string, evaluationId: string, maxResults?: number, nextToken?: string): Promise<ApiResponse>;
        /**
         * Get test case results for an evaluation run.
         * @param {string} skillId The skill ID.
         * @param {string} evaluationId A unique ID to identify each Smart Home capability evaluation.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         */
        getSmarthomeCapablityEvaluationResultsV1(skillId: string, evaluationId: string, maxResults?: number, nextToken?: string): Promise<v1.smartHomeEvaluation.GetSHCapabilityEvaluationResultsResponse>;
        /**
         * List Smart Home capability evaluation runs for a skill.
         * @param {string} skillId The skill ID.
         * @param {string} stage The stage of the skill to be used for evaluation. An error will be returned if this skill stage is not enabled on the account used for evaluation.
         * @param {string} startTimestampFrom The begnning of the start time to query evaluation result.
         * @param {string} startTimestampTo The end of the start time to query evaluation result.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         */
        callListSmarthomeCapabilityEvaluationsV1(skillId: string, stage: string, startTimestampFrom?: string, startTimestampTo?: string, maxResults?: number, nextToken?: string): Promise<ApiResponse>;
        /**
         * List Smart Home capability evaluation runs for a skill.
         * @param {string} skillId The skill ID.
         * @param {string} stage The stage of the skill to be used for evaluation. An error will be returned if this skill stage is not enabled on the account used for evaluation.
         * @param {string} startTimestampFrom The begnning of the start time to query evaluation result.
         * @param {string} startTimestampTo The end of the start time to query evaluation result.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         */
        listSmarthomeCapabilityEvaluationsV1(skillId: string, stage: string, startTimestampFrom?: string, startTimestampTo?: string, maxResults?: number, nextToken?: string): Promise<v1.smartHomeEvaluation.ListSHCapabilityEvaluationsResponse>;
        /**
         * Start a capability evaluation against a Smart Home skill.
         * @param {string} skillId The skill ID.
         * @param {v1.smartHomeEvaluation.EvaluateSHCapabilityRequest} evaluateSHCapabilityPayload Payload sent to start a capability evaluation against a Smart Home skill.
         */
        callCreateSmarthomeCapabilityEvaluationV1(skillId: string, evaluateSHCapabilityPayload?: v1.smartHomeEvaluation.EvaluateSHCapabilityRequest): Promise<ApiResponse>;
        /**
         * Start a capability evaluation against a Smart Home skill.
         * @param {string} skillId The skill ID.
         * @param {v1.smartHomeEvaluation.EvaluateSHCapabilityRequest} evaluateSHCapabilityPayload Payload sent to start a capability evaluation against a Smart Home skill.
         */
        createSmarthomeCapabilityEvaluationV1(skillId: string, evaluateSHCapabilityPayload?: v1.smartHomeEvaluation.EvaluateSHCapabilityRequest): Promise<v1.smartHomeEvaluation.EvaluateSHCapabilityResponse>;
        /**
         * List all the test plan names and ids for a given skill ID.
         * @param {string} skillId The skill ID.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         */
        callListSmarthomeCapabilityTestPlansV1(skillId: string, maxResults?: number, nextToken?: string): Promise<ApiResponse>;
        /**
         * List all the test plan names and ids for a given skill ID.
         * @param {string} skillId The skill ID.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         */
        listSmarthomeCapabilityTestPlansV1(skillId: string, maxResults?: number, nextToken?: string): Promise<v1.smartHomeEvaluation.ListSHCapabilityTestPlansResponse>;
        /**
         * Returns the ssl certificate sets currently associated with this skill. Sets consist of one ssl certificate blob associated with a region as well as the default certificate for the skill.
         * @param {string} skillId The skill ID.
         */
        callGetSSLCertificatesV1(skillId: string): Promise<ApiResponse>;
        /**
         * Returns the ssl certificate sets currently associated with this skill. Sets consist of one ssl certificate blob associated with a region as well as the default certificate for the skill.
         * @param {string} skillId The skill ID.
         */
        getSSLCertificatesV1(skillId: string): Promise<v1.skill.SSLCertificatePayload>;
        /**
         * Updates the ssl certificates associated with this skill.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.SSLCertificatePayload} sslCertificatePayload Defines the input/output of the ssl certificates api for a skill.
         */
        callSetSSLCertificatesV1(skillId: string, sslCertificatePayload: v1.skill.SSLCertificatePayload): Promise<ApiResponse>;
        /**
         * Updates the ssl certificates associated with this skill.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.SSLCertificatePayload} sslCertificatePayload Defines the input/output of the ssl certificates api for a skill.
         */
        setSSLCertificatesV1(skillId: string, sslCertificatePayload: v1.skill.SSLCertificatePayload): Promise<void>;
        /**
         * Deletes the enablement for given skillId/stage and customerId (retrieved from Auth token).
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         */
        callDeleteSkillEnablementV1(skillId: string, stage: string): Promise<ApiResponse>;
        /**
         * Deletes the enablement for given skillId/stage and customerId (retrieved from Auth token).
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         */
        deleteSkillEnablementV1(skillId: string, stage: string): Promise<void>;
        /**
         * Checks whether an enablement exist for given skillId/stage and customerId (retrieved from Auth token)
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         */
        callGetSkillEnablementStatusV1(skillId: string, stage: string): Promise<ApiResponse>;
        /**
         * Checks whether an enablement exist for given skillId/stage and customerId (retrieved from Auth token)
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         */
        getSkillEnablementStatusV1(skillId: string, stage: string): Promise<void>;
        /**
         * Creates/Updates the enablement for given skillId/stage and customerId (retrieved from Auth token)
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         */
        callSetSkillEnablementV1(skillId: string, stage: string): Promise<ApiResponse>;
        /**
         * Creates/Updates the enablement for given skillId/stage and customerId (retrieved from Auth token)
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         */
        setSkillEnablementV1(skillId: string, stage: string): Promise<void>;
        /**
         * Creates a new export for a skill with given skillId and stage.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         */
        callCreateExportRequestForSkillV1(skillId: string, stage: string): Promise<ApiResponse>;
        /**
         * Creates a new export for a skill with given skillId and stage.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         */
        createExportRequestForSkillV1(skillId: string, stage: string): Promise<void>;
        /**
         * Get the list of in-skill products for the skillId.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        callGetIspListForSkillIdV1(skillId: string, stage: string, nextToken?: string, maxResults?: number): Promise<ApiResponse>;
        /**
         * Get the list of in-skill products for the skillId.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        getIspListForSkillIdV1(skillId: string, stage: string, nextToken?: string, maxResults?: number): Promise<v1.isp.ListInSkillProductResponse>;
        /**
         * This is a synchronous API that profiles an utterance against interaction model.
         * @param {v1.skill.evaluations.ProfileNluRequest} profileNluRequest Payload sent to the profile nlu API.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {string} locale The locale for the model requested e.g. en-GB, en-US, de-DE.
         */
        callProfileNluV1(profileNluRequest: v1.skill.evaluations.ProfileNluRequest, skillId: string, stage: string, locale: string): Promise<ApiResponse>;
        /**
         * This is a synchronous API that profiles an utterance against interaction model.
         * @param {v1.skill.evaluations.ProfileNluRequest} profileNluRequest Payload sent to the profile nlu API.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {string} locale The locale for the model requested e.g. en-GB, en-US, de-DE.
         */
        profileNluV1(profileNluRequest: v1.skill.evaluations.ProfileNluRequest, skillId: string, stage: string, locale: string): Promise<v1.skill.evaluations.ProfileNluResponse>;
        /**
         * List private distribution accounts.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        callListPrivateDistributionAccountsV1(skillId: string, stage: string, nextToken?: string, maxResults?: number): Promise<ApiResponse>;
        /**
         * List private distribution accounts.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        listPrivateDistributionAccountsV1(skillId: string, stage: string, nextToken?: string, maxResults?: number): Promise<v1.skill.Private.ListPrivateDistributionAccountsResponse>;
        /**
         * Remove an id from the private distribution accounts.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {string} id ARN that a skill can be privately distributed to.
         */
        callDeletePrivateDistributionAccountIdV1(skillId: string, stage: string, id: string): Promise<ApiResponse>;
        /**
         * Remove an id from the private distribution accounts.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {string} id ARN that a skill can be privately distributed to.
         */
        deletePrivateDistributionAccountIdV1(skillId: string, stage: string, id: string): Promise<void>;
        /**
         * Add an id to the private distribution accounts.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {string} id ARN that a skill can be privately distributed to.
         */
        callSetPrivateDistributionAccountIdV1(skillId: string, stage: string, id: string): Promise<ApiResponse>;
        /**
         * Add an id to the private distribution accounts.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {string} id ARN that a skill can be privately distributed to.
         */
        setPrivateDistributionAccountIdV1(skillId: string, stage: string, id: string): Promise<void>;
        /**
         * Delete AccountLinking information of a skill for the given stage.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         */
        callDeleteAccountLinkingInfoV1(skillId: string, stageV2: string): Promise<ApiResponse>;
        /**
         * Delete AccountLinking information of a skill for the given stage.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         */
        deleteAccountLinkingInfoV1(skillId: string, stageV2: string): Promise<void>;
        /**
         * Get AccountLinking information for the skill.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         */
        callGetAccountLinkingInfoV1(skillId: string, stageV2: string): Promise<ApiResponse>;
        /**
         * Get AccountLinking information for the skill.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         */
        getAccountLinkingInfoV1(skillId: string, stageV2: string): Promise<v1.skill.accountLinking.AccountLinkingResponse>;
        /**
         * Create AccountLinking information for the skill.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         * @param {v1.skill.accountLinking.AccountLinkingRequest} accountLinkingRequest The fields required to create accountLinking partner.
         * @param {string} ifMatch Request header that specified an entity tag. The server will update the resource only if the eTag matches with the resource&#39;s current eTag.
         */
        callUpdateAccountLinkingInfoV1(skillId: string, stageV2: string, accountLinkingRequest: v1.skill.accountLinking.AccountLinkingRequest, ifMatch?: string): Promise<ApiResponse>;
        /**
         * Create AccountLinking information for the skill.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         * @param {v1.skill.accountLinking.AccountLinkingRequest} accountLinkingRequest The fields required to create accountLinking partner.
         * @param {string} ifMatch Request header that specified an entity tag. The server will update the resource only if the eTag matches with the resource&#39;s current eTag.
         */
        updateAccountLinkingInfoV1(skillId: string, stageV2: string, accountLinkingRequest: v1.skill.accountLinking.AccountLinkingRequest, ifMatch?: string): Promise<void>;
        /**
         * Creates a new clone locale workflow for a skill with given skillId, source locale, and target locales. In a single workflow, a locale can be cloned to multiple target locales. However, only one such workflow can be started at any time.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill on which locales can be cloned. Currently only &#x60;development&#x60; stage is supported. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage.
         * @param {v1.skill.CloneLocaleRequest} cloneLocaleRequest Defines the request body for the cloneLocale API.
         */
        callCloneLocaleV1(skillId: string, stageV2: string, cloneLocaleRequest: v1.skill.CloneLocaleRequest): Promise<ApiResponse>;
        /**
         * Creates a new clone locale workflow for a skill with given skillId, source locale, and target locales. In a single workflow, a locale can be cloned to multiple target locales. However, only one such workflow can be started at any time.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill on which locales can be cloned. Currently only &#x60;development&#x60; stage is supported. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage.
         * @param {v1.skill.CloneLocaleRequest} cloneLocaleRequest Defines the request body for the cloneLocale API.
         */
        cloneLocaleV1(skillId: string, stageV2: string, cloneLocaleRequest: v1.skill.CloneLocaleRequest): Promise<void>;
        /**
         * Returns the status of a clone locale workflow associated with the unique identifier of cloneLocaleRequestId.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill on which locales can be cloned. Currently only &#x60;development&#x60; stage is supported. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage.
         * @param {string} cloneLocaleRequestId Defines the identifier for a clone locale workflow. If set to ~latest, request returns the status of the latest clone locale workflow.
         */
        callGetCloneLocaleStatusV1(skillId: string, stageV2: string, cloneLocaleRequestId: string): Promise<ApiResponse>;
        /**
         * Returns the status of a clone locale workflow associated with the unique identifier of cloneLocaleRequestId.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill on which locales can be cloned. Currently only &#x60;development&#x60; stage is supported. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage.
         * @param {string} cloneLocaleRequestId Defines the identifier for a clone locale workflow. If set to ~latest, request returns the status of the latest clone locale workflow.
         */
        getCloneLocaleStatusV1(skillId: string, stageV2: string, cloneLocaleRequestId: string): Promise<v1.skill.CloneLocaleStatusResponse>;
        /**
         * Gets the `InteractionModel` for the skill in the given stage. The path params **skillId**, **stage** and **locale** are required.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         * @param {string} locale The locale for the model requested e.g. en-GB, en-US, de-DE.
         */
        callGetInteractionModelV1(skillId: string, stageV2: string, locale: string): Promise<ApiResponse>;
        /**
         * Gets the `InteractionModel` for the skill in the given stage. The path params **skillId**, **stage** and **locale** are required.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         * @param {string} locale The locale for the model requested e.g. en-GB, en-US, de-DE.
         */
        getInteractionModelV1(skillId: string, stageV2: string, locale: string): Promise<v1.skill.interactionModel.InteractionModelData>;
        /**
         * Get the latest metadata for the interaction model resource for the given stage.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         * @param {string} locale The locale for the model requested e.g. en-GB, en-US, de-DE.
         */
        callGetInteractionModelMetadataV1(skillId: string, stageV2: string, locale: string): Promise<ApiResponse>;
        /**
         * Get the latest metadata for the interaction model resource for the given stage.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         * @param {string} locale The locale for the model requested e.g. en-GB, en-US, de-DE.
         */
        getInteractionModelMetadataV1(skillId: string, stageV2: string, locale: string): Promise<void>;
        /**
         * Creates an `InteractionModel` for the skill.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         * @param {string} locale The locale for the model requested e.g. en-GB, en-US, de-DE.
         * @param {v1.skill.interactionModel.InteractionModelData} interactionModel
         * @param {string} ifMatch Request header that specified an entity tag. The server will update the resource only if the eTag matches with the resource&#39;s current eTag.
         */
        callSetInteractionModelV1(skillId: string, stageV2: string, locale: string, interactionModel: v1.skill.interactionModel.InteractionModelData, ifMatch?: string): Promise<ApiResponse>;
        /**
         * Creates an `InteractionModel` for the skill.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         * @param {string} locale The locale for the model requested e.g. en-GB, en-US, de-DE.
         * @param {v1.skill.interactionModel.InteractionModelData} interactionModel
         * @param {string} ifMatch Request header that specified an entity tag. The server will update the resource only if the eTag matches with the resource&#39;s current eTag.
         */
        setInteractionModelV1(skillId: string, stageV2: string, locale: string, interactionModel: v1.skill.interactionModel.InteractionModelData, ifMatch?: string): Promise<void>;
        /**
         * Get the list of interactionModel versions of a skill for the vendor.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         * @param {string} locale The locale for the model requested e.g. en-GB, en-US, de-DE.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} sortDirection Sets the sorting direction of the result items. When set to &#39;asc&#39; these items are returned in ascending order of sortField value and when set to &#39;desc&#39; these items are returned in descending order of sortField value.
         * @param {string} sortField Sets the field on which the sorting would be applied.
         */
        callListInteractionModelVersionsV1(skillId: string, stageV2: string, locale: string, nextToken?: string, maxResults?: number, sortDirection?: string, sortField?: string): Promise<ApiResponse>;
        /**
         * Get the list of interactionModel versions of a skill for the vendor.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         * @param {string} locale The locale for the model requested e.g. en-GB, en-US, de-DE.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         * @param {string} sortDirection Sets the sorting direction of the result items. When set to &#39;asc&#39; these items are returned in ascending order of sortField value and when set to &#39;desc&#39; these items are returned in descending order of sortField value.
         * @param {string} sortField Sets the field on which the sorting would be applied.
         */
        listInteractionModelVersionsV1(skillId: string, stageV2: string, locale: string, nextToken?: string, maxResults?: number, sortDirection?: string, sortField?: string): Promise<v1.skill.interactionModel.version.ListResponse>;
        /**
         * Gets the specified version `InteractionModel` of a skill for the vendor. Use `~current` as version parameter to get the current version model.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         * @param {string} locale The locale for the model requested e.g. en-GB, en-US, de-DE.
         * @param {string} version Version for interaction model.
         */
        callGetInteractionModelVersionV1(skillId: string, stageV2: string, locale: string, version: string): Promise<ApiResponse>;
        /**
         * Gets the specified version `InteractionModel` of a skill for the vendor. Use `~current` as version parameter to get the current version model.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         * @param {string} locale The locale for the model requested e.g. en-GB, en-US, de-DE.
         * @param {string} version Version for interaction model.
         */
        getInteractionModelVersionV1(skillId: string, stageV2: string, locale: string, version: string): Promise<v1.skill.interactionModel.InteractionModelData>;
        /**
         * Returns the skill manifest for given skillId and stage.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         */
        callGetSkillManifestV1(skillId: string, stageV2: string): Promise<ApiResponse>;
        /**
         * Returns the skill manifest for given skillId and stage.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         */
        getSkillManifestV1(skillId: string, stageV2: string): Promise<v1.skill.Manifest.SkillManifestEnvelope>;
        /**
         * Updates skill manifest for given skillId and stage.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         * @param {v1.skill.Manifest.SkillManifestEnvelope} updateSkillRequest Defines the request body for updateSkill API.
         * @param {string} ifMatch Request header that specified an entity tag. The server will update the resource only if the eTag matches with the resource&#39;s current eTag.
         */
        callUpdateSkillManifestV1(skillId: string, stageV2: string, updateSkillRequest: v1.skill.Manifest.SkillManifestEnvelope, ifMatch?: string): Promise<ApiResponse>;
        /**
         * Updates skill manifest for given skillId and stage.
         * @param {string} skillId The skill ID.
         * @param {string} stageV2 Stages of a skill including the new certified stage. * &#x60;development&#x60; - skills which are currently in development corresponds to this stage. * &#x60;certified&#x60; -  skills which have completed certification and ready for publishing corresponds to this stage. * &#x60;live&#x60; - skills which are currently live corresponds to this stage.
         * @param {v1.skill.Manifest.SkillManifestEnvelope} updateSkillRequest Defines the request body for updateSkill API.
         * @param {string} ifMatch Request header that specified an entity tag. The server will update the resource only if the eTag matches with the resource&#39;s current eTag.
         */
        updateSkillManifestV1(skillId: string, stageV2: string, updateSkillRequest: v1.skill.Manifest.SkillManifestEnvelope, ifMatch?: string): Promise<void>;
        /**
         * This is an asynchronous API which allows a skill developer to execute various validations against their skill.
         * @param {v1.skill.validations.ValidationsApiRequest} validationsApiRequest Payload sent to the skill validation API.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         */
        callSubmitSkillValidationV1(validationsApiRequest: v1.skill.validations.ValidationsApiRequest, skillId: string, stage: string): Promise<ApiResponse>;
        /**
         * This is an asynchronous API which allows a skill developer to execute various validations against their skill.
         * @param {v1.skill.validations.ValidationsApiRequest} validationsApiRequest Payload sent to the skill validation API.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         */
        submitSkillValidationV1(validationsApiRequest: v1.skill.validations.ValidationsApiRequest, skillId: string, stage: string): Promise<v1.skill.validations.ValidationsApiResponse>;
        /**
         * This API gets the result of a previously executed validation. A successful response will contain the status of the executed validation. If the validation successfully completed, the response will also contain information related to executed validations. In cases where requests to this API results in an error, the response will contain a description of the problem. In cases where the validation failed, the response will contain a status attribute indicating that a failure occurred. Note that validation results are stored for 60 minutes. A request for an expired validation result will return a 404 HTTP status code.
         * @param {string} skillId The skill ID.
         * @param {string} validationId Id of the validation. Reserved word identifier of mostRecent can be used to get the most recent validation for the skill and stage. Note that the behavior of the API in this case would be the same as when the actual validation id of the most recent validation is used in the request.
         * @param {string} stage Stage for skill.
         * @param {string} acceptLanguage User&#39;s locale/language in context.
         */
        callGetSkillValidationsV1(skillId: string, validationId: string, stage: string, acceptLanguage?: string): Promise<ApiResponse>;
        /**
         * This API gets the result of a previously executed validation. A successful response will contain the status of the executed validation. If the validation successfully completed, the response will also contain information related to executed validations. In cases where requests to this API results in an error, the response will contain a description of the problem. In cases where the validation failed, the response will contain a status attribute indicating that a failure occurred. Note that validation results are stored for 60 minutes. A request for an expired validation result will return a 404 HTTP status code.
         * @param {string} skillId The skill ID.
         * @param {string} validationId Id of the validation. Reserved word identifier of mostRecent can be used to get the most recent validation for the skill and stage. Note that the behavior of the API in this case would be the same as when the actual validation id of the most recent validation is used in the request.
         * @param {string} stage Stage for skill.
         * @param {string} acceptLanguage User&#39;s locale/language in context.
         */
        getSkillValidationsV1(skillId: string, validationId: string, stage: string, acceptLanguage?: string): Promise<v1.skill.validations.ValidationsApiResponse>;
        /**
         * Get the status of skill resource and its sub-resources for a given skillId.
         * @param {string} skillId The skill ID.
         * @param {string} resource Resource name for which status information is desired. It is an optional, filtering parameter and can be used more than once, to retrieve status for all the desired (sub)resources only, in single API call. If this parameter is not specified, status for all the resources/sub-resources will be returned.
         */
        callGetSkillStatusV1(skillId: string, resource?: string): Promise<ApiResponse>;
        /**
         * Get the status of skill resource and its sub-resources for a given skillId.
         * @param {string} skillId The skill ID.
         * @param {string} resource Resource name for which status information is desired. It is an optional, filtering parameter and can be used more than once, to retrieve status for all the desired (sub)resources only, in single API call. If this parameter is not specified, status for all the resources/sub-resources will be returned.
         */
        getSkillStatusV1(skillId: string, resource?: string): Promise<v1.skill.SkillStatus>;
        /**
         * Submit the skill for certification.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.SubmitSkillForCertificationRequest} submitSkillForCertificationRequest Defines the request body for submitSkillForCertification API.
         */
        callSubmitSkillForCertificationV1(skillId: string, submitSkillForCertificationRequest?: v1.skill.SubmitSkillForCertificationRequest): Promise<ApiResponse>;
        /**
         * Submit the skill for certification.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.SubmitSkillForCertificationRequest} submitSkillForCertificationRequest Defines the request body for submitSkillForCertification API.
         */
        submitSkillForCertificationV1(skillId: string, submitSkillForCertificationRequest?: v1.skill.SubmitSkillForCertificationRequest): Promise<void>;
        /**
         * Retrieve a list of all skill versions associated with this skill id
         * @param {string} skillId The skill ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        callListVersionsForSkillV1(skillId: string, nextToken?: string, maxResults?: number): Promise<ApiResponse>;
        /**
         * Retrieve a list of all skill versions associated with this skill id
         * @param {string} skillId The skill ID.
         * @param {string} nextToken When response to this API call is truncated (that is, isTruncated response element value is true), the response also includes the nextToken element. The value of nextToken can be used in the next request as the continuation-token to list the next set of objects. The continuation token is an opaque value that Skill Management API understands. Token has expiry of 24 hours.
         * @param {number} maxResults Sets the maximum number of results returned in the response body. If you want to retrieve fewer than upper limit of 50 results, you can add this parameter to your request. maxResults should not exceed the upper limit. The response might contain fewer results than maxResults, but it will never contain more. If there are additional results that satisfy the search criteria, but these results were not returned, the response contains isTruncated &#x3D; true.
         */
        listVersionsForSkillV1(skillId: string, nextToken?: string, maxResults?: number): Promise<v1.skill.ListSkillVersionsResponse>;
        /**
         * Withdraws the skill from certification.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.WithdrawRequest} withdrawRequest The reason and message (in case of OTHER) to withdraw a skill.
         */
        callWithdrawSkillFromCertificationV1(skillId: string, withdrawRequest: v1.skill.WithdrawRequest): Promise<ApiResponse>;
        /**
         * Withdraws the skill from certification.
         * @param {string} skillId The skill ID.
         * @param {v1.skill.WithdrawRequest} withdrawRequest The reason and message (in case of OTHER) to withdraw a skill.
         */
        withdrawSkillFromCertificationV1(skillId: string, withdrawRequest: v1.skill.WithdrawRequest): Promise<void>;
        /**
         * Creates a new uploadUrl.
         */
        callCreateUploadUrlV1(): Promise<ApiResponse>;
        /**
         * Creates a new uploadUrl.
         */
        createUploadUrlV1(): Promise<v1.skill.UploadResponse>;
        /**
         * Get the list of Vendor information.
         */
        callGetVendorListV1(): Promise<ApiResponse>;
        /**
         * Get the list of Vendor information.
         */
        getVendorListV1(): Promise<v1.vendorManagement.Vendors>;
        /**
         * Get the current user permissions about Alexa hosted skill features.
         * @param {string} vendorId vendorId
         * @param {string} hostedSkillPermissionType The permission of a hosted skill feature that customer needs to check.
         */
        callGetAlexaHostedSkillUserPermissionsV1(vendorId: string, hostedSkillPermissionType: string): Promise<ApiResponse>;
        /**
         * Get the current user permissions about Alexa hosted skill features.
         * @param {string} vendorId vendorId
         * @param {string} hostedSkillPermissionType The permission of a hosted skill feature that customer needs to check.
         */
        getAlexaHostedSkillUserPermissionsV1(vendorId: string, hostedSkillPermissionType: string): Promise<v1.skill.AlexaHosted.HostedSkillPermission>;
        /**
         * This is a synchronous API that invokes the Lambda or third party HTTPS endpoint for a given skill. A successful response will contain information related to what endpoint was called, payload sent to and received from the endpoint. In cases where requests to this API results in an error, the response will contain an error code and a description of the problem. In cases where invoking the skill endpoint specifically fails, the response will contain a status attribute indicating that a failure occurred and details about what was sent to the endpoint. The skill must belong to and be enabled by the user of this API. Also,  note that calls to the skill endpoint will timeout after 10 seconds. This  API is currently designed in a way that allows extension to an asynchronous  API if a significantly bigger timeout is required.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {v2.skill.invocations.InvocationsApiRequest} invocationsApiRequest Payload sent to the skill invocation API.
         */
        callInvokeSkillEndPointV2(skillId: string, stage: string, invocationsApiRequest?: v2.skill.invocations.InvocationsApiRequest): Promise<ApiResponse>;
        /**
         * This is a synchronous API that invokes the Lambda or third party HTTPS endpoint for a given skill. A successful response will contain information related to what endpoint was called, payload sent to and received from the endpoint. In cases where requests to this API results in an error, the response will contain an error code and a description of the problem. In cases where invoking the skill endpoint specifically fails, the response will contain a status attribute indicating that a failure occurred and details about what was sent to the endpoint. The skill must belong to and be enabled by the user of this API. Also,  note that calls to the skill endpoint will timeout after 10 seconds. This  API is currently designed in a way that allows extension to an asynchronous  API if a significantly bigger timeout is required.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {v2.skill.invocations.InvocationsApiRequest} invocationsApiRequest Payload sent to the skill invocation API.
         */
        invokeSkillEndPointV2(skillId: string, stage: string, invocationsApiRequest?: v2.skill.invocations.InvocationsApiRequest): Promise<v2.skill.invocations.InvocationsApiResponse>;
        /**
         * This is an asynchronous API that simulates a skill execution in the Alexa eco-system given an utterance text of what a customer would say to Alexa. A successful response will contain a header with the location of the simulation resource. In cases where requests to this API results in an error, the response will contain an error code and a description of the problem. The skill being simulated must belong to and be enabled by the user of this API. Concurrent requests per user is currently not supported.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {v2.skill.simulations.SimulationsApiRequest} simulationsApiRequest Payload sent to the skill simulation API.
         */
        callSimulateSkillV2(skillId: string, stage: string, simulationsApiRequest: v2.skill.simulations.SimulationsApiRequest): Promise<ApiResponse>;
        /**
         * This is an asynchronous API that simulates a skill execution in the Alexa eco-system given an utterance text of what a customer would say to Alexa. A successful response will contain a header with the location of the simulation resource. In cases where requests to this API results in an error, the response will contain an error code and a description of the problem. The skill being simulated must belong to and be enabled by the user of this API. Concurrent requests per user is currently not supported.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {v2.skill.simulations.SimulationsApiRequest} simulationsApiRequest Payload sent to the skill simulation API.
         */
        simulateSkillV2(skillId: string, stage: string, simulationsApiRequest: v2.skill.simulations.SimulationsApiRequest): Promise<v2.skill.simulations.SimulationsApiResponse>;
        /**
         * This API gets the result of a previously executed simulation. A successful response will contain the status of the executed simulation. If the simulation successfully completed, the response will also contain information related to skill invocation. In cases where requests to this API results in an error, the response will contain an error code and a description of the problem. In cases where the simulation failed, the response will contain a status attribute indicating that a failure occurred and details about what was sent to the skill endpoint. Note that simulation results are stored for 10 minutes. A request for an expired simulation result will return a 404 HTTP status code.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {string} simulationId Id of the simulation.
         */
        callGetSkillSimulationV2(skillId: string, stage: string, simulationId: string): Promise<ApiResponse>;
        /**
         * This API gets the result of a previously executed simulation. A successful response will contain the status of the executed simulation. If the simulation successfully completed, the response will also contain information related to skill invocation. In cases where requests to this API results in an error, the response will contain an error code and a description of the problem. In cases where the simulation failed, the response will contain a status attribute indicating that a failure occurred and details about what was sent to the skill endpoint. Note that simulation results are stored for 10 minutes. A request for an expired simulation result will return a 404 HTTP status code.
         * @param {string} skillId The skill ID.
         * @param {string} stage Stage for skill.
         * @param {string} simulationId Id of the simulation.
         */
        getSkillSimulationV2(skillId: string, stage: string, simulationId: string): Promise<v2.skill.simulations.SimulationsApiResponse>;
    }
}
export declare namespace services {
    /**
     * Helper class that instantiates an ServiceClient implementation automatically resolving its
     * required ApiConfiguration.
     * @export
     * @class ServiceClientFactory
     */
    class ServiceClientFactory {
        protected apiConfiguration: ApiConfiguration;
        constructor(apiConfiguration: ApiConfiguration);
    }
}
